/*
 *= CMU (UNIVERSAL RADIO COMMUNICATION TESTER VISA) ===========================
 * LabWindows/CVI 5.0 Instrument Driver
 * Original Release : June, 1999
 * By : ROHDE & SCHWARZ FRANCE
 *      CONTACTS :
 *
 *              Franois Ribiere
 *              Telephone : 00 33 1 41 36 10 83
 *              Fax       : 00 33 1 41 36 11 10
 *              e-Mail    : Francois.Ribiere@rsf.rohde-schwarz.com
 *
 *              Rohde & Schwarz France
 *              Parc Tertiaire de Meudon
 *              9-11, rue Jeanne Braconnier
 *              92366 Meudon-la-Foret Cedex
 *
 * Version : V3.65.1
 *
 * ----------------------------------------------------------------------------
 *                              REVISION HISTORY
 * ----------------------------------------------------------------------------
 *  Date     | Author     | Description
 *   Release |    Company |
 * ----------------------------------------------------------------------------
 *  02.05.00 | F.KONEY    | Release for CMU FW Version >= 2.03
 *  V1.00    |        RSF | Delivery version 1.00
 * ----------------------------------------------------------------------------
 *  24.05.00 | F.RIBIERE  | Addition :
 *           |            |   Function RSCMU_Base_SensTempSyst
 *           |            |   Define RSCMU_AMPSMS_NSIG
 *           |            |   Define RSCMU_AMPSMS_SIG
 *           |            |
 *           |            | Modification :
 *           |            |   define WR_BUFFER_SIZE pass to 512 bytes
 *           |            |   define RD_BUFFER_SIZE pass to 512 bytes
 *           |            |   define RD_BUFFER_SIZE_ARRAY pass to 32767 bytes
 *           |            |   RSCMU_Base_SystRemAddrSec -> K29 Option is now available (AMPS)
 *           |            |   RSCMU_Read -> STBBuf and FGrpBuf are now 512 bytes sized
 *           |            |
 *  V1.01    |            |   Delivery Version 1.01
 * ----------------------------------------------------------------------------
 *  08.06.00 | F.RIBIERE  |  Addition :
 *           |            |   define RSCMU_TMO_VALUE
 *           |            |
 *  V1.02    |            |   Delivery Version 1.02
 * ----------------------------------------------------------------------------
 *  21.06.00 | F.KONEY    | Modifications:
 *  V1.03RC01|        IS3I| - New function RSCMU_Query_Array
 *           |            |   Must be used instead of RSCMU_Query in functions
 *           |            |   requested array data
 *           |            | - function RSCMU_RF_NSig_ConfRfanPowMtim become
 *           |            |   RSCMU_RF_NSig_ConfRfanPowRtim
 *           |            | - bug fixed in RSCMU_RF_NSig_SensSpecFreqBand
 *           |            |   function.
 *           |            | Addition : new functions have been implemented :
 *           |            |   RSCMU_Base_StatOperEvenSadd
 *           |            |   RSCMU_Base_SystMqu
 *           |            |   RSCMU_Base_SystMquItem
 *           |            |   RSCMU_Base_StatOperEvenSadd
 *           |            |   RSCMU_Base_StatOperSymb
 *           |            |   RSCMU_Base_StatOperSymbEnab
 *           |            |   RSCMU_Audio_NSig_StopAfan
 *           |            |   RSCMU_Audio_NSig_ContAfan
 *           |            |   RSCMU_Audio_NSig_ConfAfanContErep
 *           |            |   RSCMU_Audio_NSig_SampAfan
 *           |            |   RSCMU_Audio_NSig_FetcAfanStat
 *           |            |   RSCMU_RF_NSig_SensLevMode
 *           |            |   RSCMU_RF_NSig_SourRfgFhopFreq
 *           |            |   RSCMU_RF_NSig_SourRfgFhopStat
 *           |            |   RSCMU_RF_NSig_SourRfgFhopFreqMode
 *           |            |   RSCMU_RF_NSig_SourRfgPulsStat
 * ----------------------------------------------------------------------------
 *  21.07.00 | S.BLANCHON |  Release for CMU FW Version >= 2.10
 *  V1.10    |            |  Delivery Version 1.10
 * ----------------------------------------------------------------------------
 *  10.00    | F.RIBIERE  |  Modifications:
 *  V1.12RC02|            |     RSCMU_Bae_SystRemAddrSec
 *           |            |        Add CDMA Option
 *           |            |        Patch for Bug on List of secondary Address
 *           |            |     Init_RF_NSig: Pb of Trace for Visual C compatibility
 *           |            |     Init_Audio_NSig: Pb of Trace for Visual C compatibility
 *           |            |     RSCMU_Trace_ON: Pb of Trace for Visual C compatibility
 *           |            |     RSCMU_Trace_OFF: Pb of Trace for Visual C compatibility
 *           |            |     Increase the Number of chars of DrvVersion in RSCMU_SESSION_Globals structure
 *           |            |  Addition:
 *           |            |     VXI Plug and Play Standard Functions
 * ----------------------------------------------------------------------------
 *  25.10.00 | J. SIMA    |  Additions:
 *  V1.12    |            |     VXIplug&play support
 *           |            |  Modifications:
 *           |            |     Removed compiler warnings MSVC++ Level 1 except for parameter checking macros
 *           |            |  Delivery Version:
 *           |            |     1.12
 * ----------------------------------------------------------------------------
 *  6.11.00  | M. Koutny  | Modifications:
 *  V1.13    |            |     Order of controls in FP panels of following functions:
 *           |            |        RSCMU_RF_NSig_SensSpecFreqBand
 *           |            |        RSCMU_Init_RF_NSig
 *           |            |        RSCMU_RF_NSig_SourRfgFhopStat
 *           |            |        RSCMU_Audio_NSig_FetcAfanStat
 * ----------------------------------------------------------------------------
 *  7.12.00  | M. Koutny  | Modifications:
 *  V1.14    |            |       .FP changed - Base_SystRemAddrSec ... Function
 *           |            |       Group Name control allows to select all
 *           |            |       available function groups.
 * ----------------------------------------------------------------------------
 *  3.01.01  | Z.RYKALA   | Additions:
 *           |            |     RSCMU_RF_NSig_GetResourceName
 *  V1.15    |            |     (This function is used only in LabVIEW 5.x and higher)
 * ----------------------------------------------------------------------------
 *  11.00    | F.RIBIERE  |  Modifications:
 *  V1.15    |            |     Change the name of the Base driver only RSCMU now
 *           |            |     for VXIPNP compatibility
 *           |            |   Integration of Version Number in the global structure for more flexibility
 *           |            |   Bug fixed in RSCMU_RF_NSig_ReadArrPow Function
 *           |            |   Bug fixed in RSCMU_RF_NSig_FetchArrPow Function
 *           |            |   Bug fixed in RSCMU_RF_NSig_SampleArrPow Function
 *           |            |  Addition:
 *           |            |      RSCMU_SetCmuVersion forces the CMU firmware Version and its Type
 *           |            |      RSCMU_Audio_NSig_ConfAfanFiltVBPFreq
 *           |            |      RSCMU_Audio_NSig_ConfAfanFiltVBPBW
 *           |            |      RSCMU_Audio_NSig_ConfAfanFiltWeight
 *           |            |      RSCMU_Audio_NSig_ConfAfanFiltBPass
 *           |            |      RSCMU_Audio_NSig_ReadAfanWF_VBP
 *           |            |      RSCMU_Audio_NSig_FetcAfanWF_VBP
 *           |            |      RSCMU_Audio_NSig_SampAfanWF_VBP
 * ----------------------------------------------------------------------------
 *  01.01    | J. SIMA    |
 *  V1.16    |            |
 * ----------------------------------------------------------------------------
 *  02.01    | F.RIBIERE  |  Modifications:*  V1.17    |            |   RS232 now available
 *           |            |   RSCMU_init
 * ----------------------------------------------------------------------------
 *  03.2001  | C. PETIT   |  Modifications:
 *  V3.00RC1 | F. RIBIERE |  - parameters position rectified in .FP for functions
 *           |            |    RSCMU_Audio_NSig_ConfAfanFiltVBPFreq and
 *           |            |    RSCMU_Audio_NSig_ConfAfanFiltVBPBW
 *           |            |  - RSCMU_Base_SystRemAddrSec supress all BS secondary
 *           |            |    address. Now GSM850 available
 *           |            |
 *           |            |  Addition:
 *           |            |  - Functions for Audio AF input level
 *           |            |  - Functions for Audio AUXiliary output generator
 *           |            |  - RSCMU_Audio_NSig_ConfAfanMtr
 *           |            |  - Test object Multitone
 *           |            |  - Constants for audio channels, multitone results,
 *           |            |    measurement time mode and level mode.
 *           |            |  - Constants for mode values moved from K2G to the
 *           |            |    base and constant RSCMU_VALUE_IVAL added.
 *           |            |  - New expand RSCMU200_V3_00 for the version manager
 *           |            |  - New error messages and error table reorganized
 *           |            |  - Structure RSCMU_tTestTones added in structure
 *           |            |    RSCMU_Audio_NSig_Globals to define test tones.
 * ----------------------------------------------------------------------------
 *  03.2001  | F. RIBIERE |  Modifications:
 *  V3x00.d01|            |  - RSCMU_Init_Base new Identification possible
 * ----------------------------------------------------------------------------
 *  04.2001  | C. PETIT   |  Modifications:
 *  V3x00RC02|            |  - RSCMU_Base_RevisionQuery (Version in toupper)
 * ----------------------------------------------------------------------------
 *  05.2001  | C. PETIT   |  Modifications:
 *  V3x00RC03|            |  - new matching values constants (OFF and NRAM have
 *           |            |    also been changed)
 *           |            |  - RSCMU_GetMatchingValue (integrates the values)
 *           |            |  - FW version error messages grouped in the .H and
 *           |            |    new FW 2.16 error message
 * ----------------------------------------------------------------------------
 *  05.2001  | C. PETIT   |  Modifications:
 *  V3x00RC04|            |  - Addings of the modifications of J. SIMA and
 *           |            |    F. RIBIERE from version 1.17 to 1.20:
 *           |            |
 *           |            |  - Automatic assignment of secondary address
 *           |            |    in specific Init functions.
 *           |            |    If secondary address is not assigned before
 *           |            |    calling specific Init function, this function
 *           |            |    tries to assign first free secondary address.
 *           |            |  - RSCMU_Base_SystRemAddrSec
 *           |            |    Removed _GSM, _TDMA and _AMPS macros from
 *           |            |    Removed two blanks in front of "  CDMA_PCS_MS_Sig"
 * ----------------------------------------------------------------------------
 *  05.2001  | C. PETIT   |  RELEASE VERSION FOR OFFICIAL FIRMWARE 3.00
 *  V3.00    |            |
 * ----------------------------------------------------------------------------
 *  06.2001  | C. PETIT   |  Modifications:
 *  V3.01    |            |  - Timeout ajusted for Reset in RSCMU_Init_Base
 * ----------------------------------------------------------------------------
 *  06.2001  | C. PETIT   |  Modifications:
 *  V3.01RC2 |            |  - Version manager added for FW 3.01
 * ----------------------------------------------------------------------------
 *  06.2001  | C. PETIT   |  Modifications:
 *  V3.01RC3 |            |  - RSCMU_BaseSystRemAddrSec (bug fixed in the mapping)
 * ----------------------------------------------------------------------------
 *  07.2001  | C. PETIT   |  Addings:
 *  V3.01RC4 |            |  - Management for bluetooth V2.62
 * ----------------------------------------------------------------------------
 *  07.2001  | C. PETIT   |  Addings:
 *  V3.01RC5 |            |  - RSCMU_Audio_NSig_ConfMultLimUppDef
 *           |            |    RSCMU_Audio_NSig_ConfMultLimUppSwitch
 *           |            |    RSCMU_Audio_NSig_ConfMultLimLowDef
 *           |            |    RSCMU_Audio_NSig_ConfMultLimLowSwitch
 *           |            |    => functions to lower to number of arguments
 *           |            |    in the limit lines definition
 *           |            |  - Structure RSCMU_MultitoneLimits
 *           |            |
 *           |            |  Modifications:
 *           |            |  - RSCMU_Audio_NSig_ConfMultLimUpp
 *           |            |    RSCMU_Audio_NSig_ConfMultLimLow
 *           |            |    => arguments for limits removed
 * ----------------------------------------------------------------------------
 *  07.2001  | C. PETIT   |  Modifications:
 *  V3.01RC6 |            |  - bad states for Underflow and Overflow corrected
 *           |            |    in RSCMU_GetMatchingValue
 * ----------------------------------------------------------------------------
 *  08.2001  | C. PETIT   |  Addings:
 *  V3.05RC1 |            |  - macros added for FW 3.05 in .H (error messages
 *           |            |    and firmware version number)
 *           |            |  - New constants for WCDMA 1900 FDD sessions
 * ----------------------------------------------------------------------------
 *  09.2001  | C. PETIT   |  Modifications:
 *  V3.05RC2 |            |  - RSCMU_CurrentVersion "S" detected in engineering
 *           |            |    versions.
 * ----------------------------------------------------------------------------
 *  09.2001  | C. PETIT   |  Addings:
 *  V3.05RC3 |            |  - State TLOW taken in account in local function
 *           |            |    RSCMU_GetSensMeasStatVal
 * ----------------------------------------------------------------------------
 *  10.2001  | C. PETIT   |  Addings:
 *  V3.05RC4 |            |  - New function RSCMU_SystGtrmComp in Class Utility
 *           |            |
 * ----------------------------------------------------------------------------
 *  10.2001  | C. PETIT   |  Modifications:
 *  V3.05RC5 |            |  - RSCMU_Base_SystRemAddrSec CDMA2000 and WCDMA
 *           |            |    included (.FP,.C) + constants for CDMA200 (.H)
 *           |            |  - Firmware number 2.50 added for CDMA2000.
 * ----------------------------------------------------------------------------
 *  10.2001  | C. PETIT   |  Modifications:
 *  V3.05RC6 |            |  - Firmware number 2.50 added for CDMA2000.
 * ----------------------------------------------------------------------------
 *  10.2001  | C. PETIT   |  Modifications:
 *  V3.05RC7 |            |  - all unreferenced variables removed
 *           |            |  - RSCMU_RF_NSig_Fetc/SampArrSpec debugged
 * ----------------------------------------------------------------------------
 *  01.2002  | C. PETIT   |  Modifications:
 *  V3.05RC8 |            |  - Version 3.10 implemented. This version is not yet
 *           |            |    official so this version keeps the 3.05 number
 * ----------------------------------------------------------------------------
 *  01.2002  | F.RIBIERE  |  Modifications:
 *  V3.05RC9 |            |  - RSCMU_Init_Base
 *           |            |  - RSCMU_SESSION_Globals structure
 * ----------------------------------------------------------------------------
 *  02.2002  | F.RIBIERE  |  Modifications:
 *  V3.05RC10|            |  - Add V2.53 checking in Rscmu200.h
 *           |            |  - Add V3.07 checking in Rscmu200.h
 *           |            |  - RSCMU_Audio_NSig_ConfAfanFiltBPass syntax error
 *           |            |  - RSCMU_Audio_NSig_ConfMultFiltBpasDcc syntax error
 *           |            |  - RSCMU_Audio_NSig_ConfMultFiltBpasAcc syntax error
 * ----------------------------------------------------------------------------
 *  04.2002  | F.RIBIERE  |  Modifications:
 *  V3.05RC11|            |  - rscmu200.h -> Add #pragma pack (1) compiler
 *           |            |    directive for Visual Basic compatibility
 * ----------------------------------------------------------------------------
 *  05.2002  | F.RIBIERE  |  Some additional features:
 *  V3.07RC01|            |  - RSCMU_Base_SystGtrmComp
 *           |            |  - In the RF function group, a new power measurement
 *           |            |    using different narrow-band filters is available
 *           |            |    (subsystem NPOWer).
 * ----------------------------------------------------------------------------
 *  02.07.02 | S.BLANCHON | Release according to the revision of the operating
 *  V3.07    |            | manual, stock no. 1100.4903.12-08-. including
 *           |            | some additional features available in CMU GSM-MS
 *           |            | firmware V3.07.
 * ----------------------------------------------------------------------------
 *  26.07.02 | W.STELZL   | Bugfix in RSCMU_Init_RF_NSig: CMU FW Version Set added
 *  V3.07    |            | Bugfixes in NPower
 *           |            |
 * ----------------------------------------------------------------------------
 *  08.2002  | JM GAYET   |  Some additional features:
 *  V3.07RC02|            |  - rscm200.h -> creates FW 3.09 requires for CDMA2K
 *           |            |  - RSCMU_RF_NSig_ConfNpowContRepStat prototype missing rscm200.h
 *           |            |  - RSCMU_ConfContDef : Function prototype requires to be exported
 *           |            |  - RSCMU_RF_NSig_SensNpowBwid : correct arguments 2 and 3 in FP panel
 * ----------------------------------------------------------------------------
 *  08.2002  | J. SIMA    |  Modifications:
 *  V3.08    |            |  - Renamed macro _REMVXIPNP to more self-descriptive
 *           |            |    _REMOVE_VXIPNP_FUNCTIONS_
 * ----------------------------------------------------------------------------
 *  10.2002  | J. KOMINEK |  Modifications:
 *  V3.08.4  |            |  - Code Cleanup
 *           |            |  - new status checking mechanism using the viReadSTB function if
 *           |            |    GPIB is used
 *           |            |  - fixed function RSCMU_Base_SystTim: bad command string
 *           |            |  - fixed functions RSCMU_Base_StatOperCmuSumCmu,
 *           |            |                    RSCMU_Base_StatOperCmuSumCmuCond,
 *           |            |                    RSCMU_Base_StatOperCmuSumCmuPtr,
 *           |            |                    RSCMU_Base_StatOperCmuSumCmuNtr,
 *           |            |                    RSCMU_Base_StatOperCmuSumCmuEnab: bad
 *           |            |                    range checking of subregister
 *           |            |  - fixed function RSCMU_Base_SystMqu: now correctly
 *           |            |    returns all items
 *           |            |  - fixed function RSCMU_Base_SystCommkSerAppl
 *           |            |  - changed API of functions RSCMU_RF_NSig_FetcArrSpec and
 *           |            |    RSCMU_RF_NSig_SampArrSpec: initFreq should be ViReal64*
 *           |            |    instead of ViInt32*
 *           |            |  - fixed label/value pairs of the parameters of function
 *           |            |    RSCMU_RF_NSig_SourRfgBand
 *           |            |  - new functions: RSCMU_checkVersion, RSCMU_atof, RSCMU_atofArray,
 *           |            |    RSCMU_setViInt32, RSCMU_getViInt32, RSCMU_setViReal64,
 *           |            |    RSCMU_setViReal64Unit, RSCMU_getViReal64, RSCMU_sendCmd,
 *           |            |    RSCMU_setViString, RSCMU_getViString, RSCMU_setEnum, RSCMU_getEnum,
 *           |            |    RSCMU_checkIndexInList, RSCMU_checkIndexInRealList,
 *           |            |    RSCMU_getIndexFromString, RSCMU_WinBatchWrite,RSCMU_WinBatchRead,
 *           |            |    RSCMU_sysStatus, RSCMU_setCheckStatus, RSCMU_ReadDataUnknownLength,
 *           |            |    RSCMU_viWrite, RSCMU_viRead
 * ----------------------------------------------------------------------------
 *  10.2002  | J. KOMINEK |  Modifications:
 *  V3.08.5  |            |  - Minor changes in the compiler directives
 * ----------------------------------------------------------------------------
 *  10.2002  | J. KOMINEK |  Modifications:
 *  V3.08.6  |            |  - Minor changes in a, RSCMU_Init_RF_NSig,
 *           |            |    RSCMU_Init_Audio_NSig
 *           |            |  - fixed RSCMU_Query_Array: missing memory deallocation
 * ----------------------------------------------------------------------------
 *  01.2003  | w.bleichner|  copy from RSCMU200 V3.08.06
 *  V3.08.00 |            |
 * ----------------------------------------------------------------------------
 *  02.2003  | J.KOMINEK  |  removed #pragma pack(1)
 *  V3.08.01 |            |
 * ----------------------------------------------------------------------------
 *  08.2003  | H. SUCHA   |  Modifications:
 *  V3.40.02 |            |  - RSCMU300_SepBufSTB removed.
 *           |            |  - driver completly redesigned to call CMU200 functions
 *           |            |  - Audio group removed
 *           |            |
 * ----------------------------------------------------------------------------
 *  11.2004  | w.bleichner|  new Versions
 *  V3.40.03 |            |
 * ----------------------------------------------------------------------------
 * 05.2005,  | M Koutny   | - I/O conversion specification fixed:
 * V3.40.05  |            |     Input: "%le" for ViReal64, "%ld" for ViInt32
 *           |            |     Output: "%.12f" for ViReal64, "%ld" for ViInt32
 *           |            | - System locale are set to default "C"
 *           |            |
 * ----------------------------------------------------------------------------
 *  10.2005  | w.bleichner|  new Versions
 *  V3.65.00 | J.Kominek  |  - New CHM help with SCPI commands index added 
 * ----------------------------------------------------------------------------
 *  07.2007  | J.Kominek  |  New installer, added .NET wrappers, fixed installation issue             
 *  V3.65.1  |            |  with rscmu200 ver. 4.30 driver 
 *===========================================================================*/

/****************************************************************************/
/* WARNING:                                                                 */
/* ======================================================================== */
/* When using the new functinality of the status checking please try to not */
/* use the RSMU_Read and RSMU_Write functions. If it is neccessary call     */
/* RSCMU300_setCheckStatus function to restore your desired checking status.   */
/* After each call of the RSCMU300_Read function the status checking is always */
/* off. This note does not regards to RSCMU300_Query and RSCMU300_QueryArray      */
/* functions.                                                               */
/****************************************************************************/

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <time.h>
#include <ctype.h>
#include <locale.h>
#include <visa.h>
//Don't change the order of the next includes!!!
#include "rscmu200.h"
#include "rscmu300.h"

/*---------------------------------------------------------------------------*/
/*
/*---------------------------------------------------------------------------*/
typedef enum {
  RSCMU300_READ,
  RSCMU300_FETC,
  RSCMU300_SAMP
} MeasCommand;

/*****************************************************************************/
/*========== CLASS: BASIC UNIT ==============================================*/
/*****************************************************************************/
/*****************************************************************************/

/*
 * ----------------------------------------------------------------------------
 * Initialize
 * ----------------------------------------------------------------------------
 */

/*===========================================================================*/
/* Function: Initialize
/* Purpose : This function opens the instrument, queries the instrument
/*           for its ID, and initializes the instrument to a known state.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_Init_Base (ViPSession  instrSession,
                                   ViInt32     SCPIConnection,
                                   ViInt32     ConnectionNb,
                                   ViInt32     PrimAddr,
                                   ViBoolean   IDQuery,
                                   ViBoolean   reset,
                                   ViChar      errorMessage[])
{
    return RSCMU_Init_Base (instrSession, SCPIConnection, ConnectionNb, PrimAddr, IDQuery, reset, errorMessage);
}

/*
 *-----------------------------------------------------------------------------
 * STATUS FUNCTIONS
 * ------------------
 *  The STATus functions control the SCPI-defined status reporting
 *  structures.
 *  The purpose and definition of status registers is given in
 *  chapter 5, section "Status Reporting System". Unless otherwise
 *  stated, all the following commands are SCPI-confirmed.
 *
 *-----------------------------------------------------------------------------
 *    OPERATION REGISTERS
 *    These functions control the SCPI-defined Operation registers.
 *-----------------------------------------------------------------------------
 *
 *-----------------------------------------------------------------------------
 *      STATus OPERation Register
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Event Part
/* Purpose : This function queries and deletes the contents of the EVENt
/*           part of the STATus:OPERation register.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_Base_StatOper (ViSession  instrSession,
                                       ViInt32   *eventPart,
                                       ViChar     errorMessage[])
{
    return RSCMU_Base_StatOper (instrSession, eventPart, errorMessage);
}

/*===========================================================================*/
/* Function: Condition Part
/* Purpose : This function queries the contents of the CONDition part of
/*           the STATus:OPERation register.
/*           Reading this register is nondestructive.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_Base_StatOperCond (ViSession  instrSession,
                                           ViInt32   *conditionPart,
                                           ViChar     errorMessage[])
{
    return RSCMU_Base_StatOperCond (instrSession, conditionPart, errorMessage);
}

/*===========================================================================*/
/* Function: Set Positive Part
/* Purpose : This Function sets a number to be interpreted as a bit pattern
/*           in the PTRansition part of the STATus:OPERation register.
/*           If a bit is set the corresponding 0-to-1 transition in the
/*           CONDition part (indicating that an event in the hardware
/*           occurred) is entered into the EVENt part.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_Base_StatOperPtr (ViSession instrSession,
                                          ViInt32   positiveTranstionPart,
                                          ViChar    errorMessage[])
{
    return RSCMU_Base_StatOperPtr(instrSession, positiveTranstionPart,
                                errorMessage);
}

/*===========================================================================*/
/* Function: Set Negative Part
/* Purpose : This Function sets a number to be interpreted as a bit pattern
/*           in the NTRansition part of the STATus:OPERation register. If a
/*           bit is set the corresponding 0-to-1 transition in the CONDition
/*           part (indicating that an event in the hardware disappeared) is
/*           entered into the EVENt part.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_Base_StatOperNtr (ViSession instrSession,
                                          ViInt32   negativeTranstionPart,
                                          ViChar    errorMessage[])
{
    return RSCMU_Base_StatOperNtr(instrSession, negativeTranstionPart,
                                errorMessage);
}

/*===========================================================================*/
/* Function: Set Enable Part
/* Purpose : This Function sets a number to be interpreted as a bit pattern
/*           in the ENABLe part of the STATus:OPERation register. If a bit is
/*           set the corresponding event is reported in the summary bit of
/*           the status byte.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_Base_StatOperEnab (ViSession instrSession,
                                           ViInt32   enablePart,
                                           ViChar    errorMessage[])
{
    return RSCMU_Base_StatOperEnab(instrSession, enablePart, errorMessage);
}

/*
 *-----------------------------------------------------------------------------
 *      STATus:OPERation:CMU:SUM1|2 Registers
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Event Part
/* Purpose : This function queries and deletes the contents of the EVENt part
/*           of the STATus:OPERation:CMU:SUM1|2 register.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_Base_StatOperCmuSum (ViSession  instrSession,
                                             ViInt32    Register,
                                             ViInt32   *eventPart,
                                             ViChar     errorMessage[])
{
    return RSCMU_Base_StatOperCmuSum (instrSession, Register, eventPart,
                                    errorMessage);
}

/*===========================================================================*/
/* Function: Condition Part
/* Purpose : This function queries the contents of the CONDition part of the
/*           STATus:OPERation:CMU:SUM1|2 register.
/*           Reading this register is nondestructive.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_Base_StatOperCmuSumCond (ViSession  instrSession,
                                                 ViInt32    Register,
                                                 ViInt32   *conditionPart,
                                                 ViChar     errorMessage[])
{
    return RSCMU_Base_StatOperCmuSumCond (instrSession, Register,
                                        conditionPart, errorMessage);
}

/*===========================================================================*/
/* Function: Set Positive Part
/* Purpose : This Function sets a number to be interpreted as a bit pattern
/*           in the PTRansition part of the STATus:OPERation:CMU:SUM1|2
/*           register.
/*           If a bit is set the corresponding 0-to-1 transition in the
/*           CONDition part (indicating that an event in the hardware
/*           occurred) is entered into the EVENt part.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_Base_StatOperCmuSumPtr (ViSession instrSession,
                                                ViInt32   Register,
                                                ViInt32   positiveTranstionPart,
                                                ViChar    errorMessage[])
{
    return RSCMU_Base_StatOperCmuSumPtr (instrSession, Register,
                                        positiveTranstionPart, errorMessage);
}

/*===========================================================================*/
/* Function: Set Negative Part
/* Purpose : This Function sets a number to be interpreted as a bit pattern
/*           in the NTRansition part of the STATus:OPERation:CMU:SUM1|2
/*           register. If a bit is set the corresponding 0-to-1 transition in
/*           the CONDition part (indicating that an event in the hardware
/*           disappeared) is entered into the EVENt part.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_Base_StatOperCmuSumNtr (ViSession instrSession,
                                                ViInt32   Register,
                                                ViInt32   negativeTranstionPart,
                                                ViChar    errorMessage[])
{
    return RSCMU_Base_StatOperCmuSumNtr (instrSession, Register,
                                        negativeTranstionPart, errorMessage);
}

/*===========================================================================*/
/* Function: Set Enable Part
/* Purpose : This command sets a number to be interpreted as a bit pattern in
/*           the ENABle part of the STATus:OPERation:CMU:SUM1|2 register. If
/*           a bit is set the corresponding event is reported in the summary
/*           bit of the status byte.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_Base_StatOperCmuSumEnab (ViSession instrSession,
                                                 ViInt32   Register,
                                                 ViInt32   enablePart,
                                                 ViChar    errorMessage[])
{
    return RSCMU_Base_StatOperCmuSumEnab (instrSession, Register,
                                        enablePart, errorMessage);
}

/*
 *-----------------------------------------------------------------------------
 *        STATus:OPERation:CMU:SUM1|2:CMU1|to|15 Registers
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Event Part
/* Purpose : This function queries and deletes the contents of the EVENt part
/*           of the STATus:OPERation:CMU:SUM1|2:CMU1|to|15 register.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_Base_StatOperCmuSumCmu (ViSession  instrSession,
                                                ViInt32    Register,
                                                ViInt32    SubRegister,
                                                ViInt32   *eventPart,
                                                ViChar     errorMessage[])
{
    return RSCMU_Base_StatOperCmuSumCmu (instrSession, Register,
                                        SubRegister, eventPart, errorMessage);
}

/*===========================================================================*/
/* Function: Condition Part
/* Purpose : This function queries the contents of the CONDition part of the
/*           STATus:OPERation:CMU:SUM1|2:CMU1|to|15 register.
/*           Reading this register is nondestructive.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_Base_StatOperCmuSumCmuCond (ViSession  instrSession,
                                                    ViInt32    Register,
                                                    ViInt32    SubRegister,
                                                    ViInt32   *conditionPart,
                                                    ViChar     errorMessage[])
{
    return RSCMU_Base_StatOperCmuSumCmuCond (instrSession, Register,
                                            SubRegister, conditionPart,
                                            errorMessage);
}

/*===========================================================================*/
/* Function: Set Positive Part
/* Purpose : This Function sets a number to be interpreted as a bit pattern
/*           in the PTRansition part of the
/*           STATus:OPERation:CMU:SUM1|2:CMU1|to|15 register.
/*           If a bit is set the corresponding 0-to-1 transition in the
/*           CONDition part (indicating that an event in the hardware
/*           occurred) is entered into the EVENt part.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_Base_StatOperCmuSumCmuPtr (ViSession instrSession,
                                                   ViInt32   Register,
                                                   ViInt32   SubRegister,
                                                   ViInt32   positiveTranstionPart,
                                                   ViChar    errorMessage[])
{
    return RSCMU_Base_StatOperCmuSumCmuPtr (instrSession, Register,
                                            SubRegister, positiveTranstionPart,
                                            errorMessage);
}

/*===========================================================================*/
/* Function: Set Negative Part
/* Purpose : This Function sets a number to be interpreted as a bit pattern
/*           in the NTRansition part of the
/*           STATus:OPERation:CMU:SUM1|2:CMU1|to|15 register. If a bit is set
/*           the corresponding 0-to-1 transition in the CONDition part
/*           (indicating that an event in the hardware disappeared) is
/*           entered into the EVENt part.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_Base_StatOperCmuSumCmuNtr (ViSession instrSession,
                                                   ViInt32   Register,
                                                   ViInt32   SubRegister,
                                                   ViInt32   negativeTranstionPart,
                                                   ViChar    errorMessage[])
{
    return RSCMU_Base_StatOperCmuSumCmuNtr (instrSession, Register,
                                            SubRegister, negativeTranstionPart,
                                            errorMessage);
}

/*===========================================================================*/
/* Function: Set Enable Part
/* Purpose : This Function sets a number to be interpreted as a bit pattern
/*           in the ENABLe part of the STATus:OPERation:CMU:SUM1|2:CMU1|to|15
/*           register. If a bit is set the corresponding event is reported in
/*           the summary bit of the status byte.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_Base_StatOperCmuSumCmuEnab (ViSession instrSession,
                                                    ViInt32   Register,
                                                    ViInt32   SubRegister,
                                                    ViInt32   enablePart,
                                                    ViChar    errorMessage[])
{
    return RSCMU_Base_StatOperCmuSumCmuEnab (instrSession, Register,
                                            SubRegister, enablePart,
                                            errorMessage);
}

/*===========================================================================*/
/* Function: Query All Operation Registers
/* Purpose : This command queries the EVENt parts of all
/*           STATus:OPERation:CMU:SUM1|2:CMU1| to |15 registers. The result
/*           is returned as a list of 30 integer values separated by commas.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_Base_StatOperCmuAll (ViSession instrSession,
                                             ViInt32   eventParts[],
                                             ViChar    errorMessage[])
{
    return RSCMU_Base_StatOperCmuAll (instrSession, eventParts, errorMessage);
}

/*===========================================================================*/
/* Function: Clear All Operation Registers
/* Purpose : This command clears the EVENt parts of all
/*           STATus:OPERation:CMU:SUM1|2:CMU1| to |15 registers.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_Base_StatOperCmuCle (ViSession instrSession,
                                             ViChar    errorMessage[])
{
    return RSCMU_Base_StatOperCmuCle (instrSession, errorMessage);
}

/*
 *-----------------------------------------------------------------------------
 *        Questionnable Register
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Event Part
/* Purpose : This function queries and deletes the contents of the EVENt part
/*           of the STATus:QUEStionable register.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_Base_StatQues (ViSession  instrSession,
                                       ViInt32   *eventPart,
                                       ViChar     errorMessage[])
{
    return RSCMU_Base_StatQues (instrSession, eventPart, errorMessage);
}

/*===========================================================================*/
/* Function: Condition Part
/* Purpose : This function queries the contents of the CONDition part of the
/*           STATus:QUEStionable register.
/*           Reading this register is nondestructive.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_Base_StatQuesCond (ViSession  instrSession,
                                           ViInt32   *conditionPart,
                                           ViChar     errorMessage[])
{
    return RSCMU_Base_StatQuesCond (instrSession, conditionPart, errorMessage);
}

/*===========================================================================*/
/* Function: Set Positive Part
/* Purpose : This Function sets a number to be interpreted as a bit pattern
/*           in the PTRansition part of the STATus:QUEStionable register.
/*           If a bit is set the corresponding 0-to-1 transition in the
/*           CONDition part (indicating that an event in the hardware
/*           occurred) is entered into the EVENt part.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_Base_StatQuesPtr (ViSession instrSession,
                                          ViInt32   positiveTranstionPart,
                                          ViChar    errorMessage[])
{
    return RSCMU_Base_StatQuesPtr (instrSession, positiveTranstionPart,
                                    errorMessage);
}

/*===========================================================================*/
/* Function: Set Negative Part
/* Purpose : This Function sets a number to be interpreted as a bit pattern
/*           in the NTRansition part of the STATus:QUEStionable register. If
/*           a bit is set the corresponding 0-to-1 transition in the
/*           CONDition part (indicating that an event in the hardware
/*           disappeared) is entered into the EVENt part.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_Base_StatQuesNtr (ViSession instrSession,
                                          ViInt32   negativeTranstionPart,
                                          ViChar    errorMessage[])
{
    return RSCMU_Base_StatQuesNtr (instrSession, negativeTranstionPart,
                                    errorMessage);
}

/*===========================================================================*/
/* Function: Set Enable Part
/* Purpose : This Function sets a number to be interpreted as a bit pattern
/*           in the ENABLe part of the STATus:QUEStionable register. If a bit
/*           is set the corresponding event is reported in the summary bit of
/*           the status byte.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_Base_StatQuesEnab (ViSession instrSession,
                                           ViInt32   enablePart,
                                           ViChar    errorMessage[])
{
    return RSCMU_Base_StatQuesEnab (instrSession, enablePart, errorMessage);
}

/*===========================================================================*/
/* Function: Reset Status Registers
/* Purpose : This command sets the edge detectors (PTRansition and
/*           NTRansition parts) and the ENABle registers of the
/*           STATus:OPERation and the STATus:QUEStionable registers to
/*           defined values:
/*           * PTRansition is set to 32767 (0x7FFF), i.e. all hardware events
/*           are detected and transferred to the EVENt register.
/*           * NTRansition is set to 0, i.e. a hardware event that disappears
/*           does not cause any change in the EVENt register.
/*           * The ENABle registers are also set to 0 so that events are not
/*           reported in the status byte.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_Base_StatPres (ViSession instrSession,
                                                 ViChar    errorMessage[])
{
    return RSCMU_Base_StatPres (instrSession, errorMessage);
}

/*
 *-----------------------------------------------------------------------------
 *        Symbolic Status Event Register Evaluation
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function:
/* Purpose : This function returns the next function group where a event was
/*           reported
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_Base_StatOperEvenSadd (ViSession instrSession,
                                               ViInt32   *nextsecondaryaddress,
                                               ViChar    functiongroupname[],
                                               ViChar    errorMessage[])
{
    return RSCMU_Base_StatOperEvenSadd (instrSession, nextsecondaryaddress,
                                        functiongroupname, errorMessage);
}

/*===========================================================================*/
/* Function:
/* Purpose : This function returns the next function group where an event was
/*           reported
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_Base_StatOperSymb (ViSession instrSession,
                                           ViChar    events[],
                                           ViChar    errorMessage[])
{
    return RSCMU_Base_StatOperSymb (instrSession, events, errorMessage);
}

/*===========================================================================*/
/* Function:
/* Purpose : This function enables event reporting for one or several events
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_Base_StatOperSymbEnab (ViSession instrSession,
                                               ViChar    event[],
                                               ViChar    errorMessage[])
{
    return RSCMU_Base_StatOperSymbEnab (instrSession, event, errorMessage);
}

/*===========================================================================*/
/* Function: Synchronization
/* Purpose : This function sets the reference frequency
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_Base_ConfSyncFreqRef (ViSession  instrSession,
                                              ViReal64   Frequency,
                                              ViInt32    Mode,
                                              ViChar     errorMessage[])
{
    return RSCMU_Base_ConfSyncFreqRef (instrSession, Frequency, Mode,
                                        errorMessage);
}

/*
 *-----------------------------------------------------------------------------
 * SETUP - BASIC DEVICE SETTINGS
 * ------------------
 * The SETup subsystem contains the functins for global
 * configuration of the remote control parameters, the serial
 * interfaces, the options, date and time, the keyboard and beeper.
 * It corresponds to the Setup menu opened via the SETUP key on the
 * front panel.
 *-----------------------------------------------------------------------------
 *  REMOTE
 *  The REMote subsystem contains the functions for configuration of
 *  the remote control parameters.
 *  It corresponds to the Remote index card in the Setup menu opened
 *  via the SETUP key on the front panel.
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set Primary Address
/* Purpose : This function sets the primary address of the GPIB driver which
/*           is used to address the device (CMU).
/*           It is equivalent to SYSTem:COMMunicate:GPIB[:SELF]:ADDRess (see
/*           after).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_Base_SystRemAddrPrim (ViSession instrSession,
                                              ViInt32   primaryAddress,
                                              ViChar    errorMessage[])
{
    return RSCMU_Base_SystRemAddrPrim (instrSession, primaryAddress,
                                        errorMessage);
}

/*===========================================================================*/
/* Function: Set Secondary Address
/* Purpose : This function assigns the secondary addresses to the remote
/*           control modes (function groups) of the GPIB driver (compare next
/*           command).
/*           If a secondary address is successively assigned to different
/*           function groups the previous assignments are overwritten.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_Base_SystRemAddrSec (ViSession instrSession,
                                             ViInt32   secondaryAddress,
                                             ViInt32   functionGroupName,
                                             ViChar    errorMessage[])
{
    return RSCMU_Base_SystRemAddrSec ( instrSession, secondaryAddress,
                                       functionGroupName, errorMessage );
}

/*
 * ----------------------------------------------------------------------------
 *  COMMUNICATE
 *  The COMMunicate subsystem contains the functions for
 *  configuration of the remote serial interfaces.
 *  It corresponds to the Communicate index card in the Setup menu
 *  opened via the SETUP key on the front panel. The parameters set
 *  in this subsystem are explained in more detail in chapter 8,
 *  section Hardware Interfaces.
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set Primary Address
/* Purpose : This function sets the primary address of the GPIB driver which
/*           is used to address the device (CMU).
/*           It is equivalent to SYSTem:REMote:ADDRess:PRIMary (see above).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_Base_SystCommGpibAddr (ViSession instrSession,
                                               ViInt32   primaryAddress,
                                               ViChar    errorMessage[])
{
    return RSCMU_Base_SystCommGpibAddr (instrSession, primaryAddress,
                                        errorMessage);
}

/*===========================================================================*/
/* Function: Application
/* Purpose : This function returns the current application (connection) of
/*           the serial interface. The numeric suffix distinguishes the two
/*           interfaces COM1 and COM2.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_Base_SystCommSerAppl (ViSession  instrSession,
                                              ViInt32    interface,
                                              ViInt32   *currentConnection,
                                              ViChar     errorMessage[])
{
    return RSCMU_Base_SystCommSerAppl (instrSession, interface,
                                        currentConnection, errorMessage);
}

/*===========================================================================*/
/* Function: Set Baud Rate
/* Purpose : This function sets the baud rate of the serial interface no. 1
/*           or 2 (connectors COM1 or COM2).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_Base_SystCommSerBaud (ViSession instrSession,
                                              ViInt32   interface,
                                              ViInt32   baudRate,
                                              ViChar    errorMessage[])
{
    return RSCMU_Base_SystCommSerBaud (instrSession, interface, baudRate,
                                        errorMessage);
}

/*===========================================================================*/
/* Function: Set Data & Stop Bits
/* Purpose : This function sets the numbers of data bits and stop bits for
/*           the serial interface no. 1 or 2 (connectors COM 1 or COM 2).
/*           The sum of data bits and stop bits numbers must be equal to 9.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_Base_SystCommSerBit (ViSession instrSession,
                                             ViInt32   interface,
                                             ViInt32   dataBitsNumber,
                                             ViInt32   stopBitsNumber,
                                             ViChar    errorMessage[])
{
    return RSCMU_Base_SystCommSerBit (instrSession, interface,
                                        dataBitsNumber, stopBitsNumber,
                                        errorMessage);
}

/*===========================================================================*/
/* Function: Set Parity
/* Purpose : This function sets the parity of the serial interface no. 1 or 2
/*           (connectors COM 1 or COM 2).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_Base_SystCommSerPar (ViSession instrSession,
                                             ViInt32   interface,
                                             ViInt32   parity,
                                             ViChar    errorMessage[])
{
    return RSCMU_Base_SystCommSerPar (instrSession, interface, parity,
                                        errorMessage);
}

/*===========================================================================*/
/* Function: Set protocol
/* Purpose : This function sets the handshake protocol of the serial
/*           interface no. 1 or 2 (connectors COM 1 or COM 2).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_Base_SystCommSerTranPace (ViSession instrSession,
                                                  ViInt32   interface,
                                                  ViInt32   protocol,
                                                  ViChar    errorMessage[])
{
    return RSCMU_Base_SystCommSerTranPace (instrSession, interface,
                                            protocol, errorMessage);
}

/*
 * ----------------------------------------------------------------------------
 *  OPTIONS
 *  The Options subsystem contains the functions for querying
 *  information on the instrument and the available options.
 *  It corresponds to the Options index card in the Setup menu
 *  opened via the SETUP key on the front panel.
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Device Informations
/* Purpose : This function returns the information on the device comprising
/*           the manufacturer, model, serial number and firmware version.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_Base_SystOptInf (ViSession instrSession,
                                         ViChar    deviceInformation[],
                                         ViChar    errorMessage[])
{
    return RSCMU_Base_SystOptInf (instrSession, deviceInformation,
                                    errorMessage);
}

/*===========================================================================*/
/* Function: Options
/* Purpose : This function returns a list of all options and equipment
/*           available in the instrument. It is always a query.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_Base_SystOpt (ViSession instrSession,
                                      ViChar    options[],
                                      ViChar    errorMessage[])
{
    return RSCMU_Base_SystOpt (instrSession, options, errorMessage);
}

/*
 * ----------------------------------------------------------------------------
 *  TIME
 *  The Time subsystem contains the functions for the current time
 *  and date.
 *  It corresponds to the Time index card in the Setup menu opened
 *  via the SETUP key on the front panel.
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set Time
/* Purpose : This function defines the current time and date.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_Base_SystTim (ViSession instrSession,
                                      ViInt32   timeZone,
                                      ViChar    currentTime[],
                                      ViChar    date[],
                                      ViChar    errorMessage[])
{
    return RSCMU_Base_SystTim (instrSession, timeZone, currentTime,
                                date, errorMessage);
}

/*
 * ----------------------------------------------------------------------------
 *  MISCELLANEOUS
 *  The Miscellaneous subsystem contains the functions for setting
 *  the acoustic signal and selecting the external keyboard
 *  assignment.
 *  It corresponds to the Misc. index card in the Setup menu opened
 *  via the SETUP key on the front panel.
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set KeyBeep (ON/OFF)
/* Purpose : This function switches the acoustic signal of the CMU on or off.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_Base_SystMiscKbe (ViSession instrSession,
                                          ViInt32   beeper,
                                          ViChar    errorMessage[])
{
    return RSCMU_Base_SystMiscKbe (instrSession, beeper, errorMessage);
}

/*
 * ----------------------------------------------------------------------------
 *  GTRMode
 *  The Time subsystem determines the behavior of the CMU in a local remote transition.
 *  the sub-sytem has no equivalent in manual control.
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set GTRMode
/* Purpose : This command defines the behavior of the CMU in a local to remote transition.
 * The command is valid for all function groups and test modes, however,
 * its effect depends on the test mode (Signalling or Non Signalling tests):
 *      Signalling In the ON setting:
 *           the connection or call is dropped and the CMU returns to its default
 *           signalling state (e.g. SOFF in the GSMxxx-MS function groups).
 *      Signalling In the OFF setting:
 *           all signalling states are maintained. This makes it possible to switch the instrument
 *           to remote control without dropping a call or connection.
 *           See also operating manual for the different network tests.
 *      Non Signalling In the ON setting:
 *           all generators are switched off.
 *      Non Signalling In the OFF setting, the current operating state of all generators is maintained.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_Base_SystGtrmComp (ViSession instrSession,
                                           ViInt32   enable,
                                           ViChar    errorMessage[])
{
    return RSCMU_Base_SystGtrmComp (instrSession, enable, errorMessage);
}

/*===========================================================================*/
/* Function: Set Keyboard Assignment
/* Purpose : This function selects the driver for the external keyboard.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_Base_SystMiscKeyb (ViSession instrSession,
                                           ViInt32   keyboard,
                                           ViChar    errorMessage[])
{
    return RSCMU_Base_SystMiscKeyb (instrSession, keyboard, errorMessage);
}

/*===========================================================================*/
/* Function: Get complete measurement queue
/* Purpose : This function selects the driver for the external keyboard.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_Base_SystMqu (ViSession instrSession,
                                      ViChar    fctgrp[],
                                      ViChar    rdymeas[],
                                      ViChar    errorMessage[])
{
    return RSCMU_Base_SystMqu (instrSession, fctgrp, rdymeas, errorMessage);
}

/*===========================================================================*/
/* Function: Get next measurement queue
/* Purpose : This function selects the driver for the external keyboard.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_Base_SystMquItem (ViSession instrSession,
                                          ViChar    fctgrp[],
                                          ViChar    rdymeas[],
                                          ViChar    errorMessage[])
{
    return RSCMU_Base_SystMquItem (instrSession, fctgrp, rdymeas, errorMessage);
}

/*===========================================================================*/
/* Function: Sense Temperature System
/* Purpose : This function get the internal tempearture of CMU.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_Base_SensTempSyst (ViSession instrSession,
                                           ViReal64  *temperature,
                                           ViChar    errorMessage[])
{
    return RSCMU_Base_SensTempSyst (instrSession, temperature,
                                    errorMessage);
}

/*
 * ----------------------------------------------------------------------------
 * Reset
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Reset
/* Purpose : This function sets all parameters of the instrument to their
/*           default values.
/*           It corresponds to the Reset menu opened via the RESET key on the
/*           front panel.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_Base_SystPres (ViSession instrSession, ViChar errorMessage[])
{
    return RSCMU_Base_SystPres (instrSession, errorMessage);
}

/*
 * ----------------------------------------------------------------------------
 * Reset
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Close
/* Purpose : This function close the Basic Unit session and release the
/*           resources
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_Close_Base (ViSession BaseSession, ViChar errorMessage[])
{
    return RSCMU_Close_Base (BaseSession, errorMessage);
}

/*****************************************************************************/
/*****************************************************************************/
/*========== Class: RFNonSignalling =========================================*/
/*****************************************************************************/
/*****************************************************************************/
/*
 * ----------------------------------------------------------------------------
 * Initialize
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Initialize
/* Purpose : This function can be called only after the initialization
/*           of the "Basic Unit".It opens the instrument, queries the
/*           instrument for its ID, and initializes the instrument
/*           to a known state.
/*===========================================================================*/
/* This function can't call CMU200 (RSCMU_Init_RF_NSig) function.
    The function RSCMU300_Base_SystRemAddrSec is total different             */

ViStatus _VI_FUNC RSCMU300_Init_RF_NSig (ViSession   BaseSession,
                                      ViPSession  RFNSigSession,
                                      ViChar      errorMessage[])
{
    return RSCMU_Init_RF_NSig ( BaseSession, RFNSigSession, errorMessage );
}

/*
 *-----------------------------------------------------------------------------
 * GROUP CONFIGURATION
 * ------------------
 * The functions presented in this section configure the
 * measurements in the function group RF Non Signalling globally,
 * i.e. for all subsequent measurements.
 * They correspond to the settings in the popup menu of the Group
 * Config. softkey located to the left of the header of each main
 * menu.
 *
 *-----------------------------------------------------------------------------
 *    INPUT LEVEL
 *    This subsystem contains the functions for determination or
 *    modification of the input level for the currently used input.
 *    It corresponds to the index card Input Level in the popup menu
 *    Group Configuration.
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set Input Lev - Maximum
/* Purpose : This Function sets the maximum input level. The permissible
/*           value range depends on the RF input used and the external
/*           attenuation set.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_RF_NSig_SensLevMax (ViSession instrSession,
                                            ViReal64  Level,
                                            ViChar    errorMessage[])
{
    return RSCMU_RF_NSig_SensLevMax (instrSession, Level, errorMessage);
}

/*===========================================================================*/
/* Function: Input Level - Reference
/* Purpose : This Function sets the reference input level. The permissible
/*           value range depends on the RF input used and the external
/*           attenuation set.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_RF_NSig_SensLevRef (ViSession  instrSession,
                                            ViReal64   ReferenceLevel,
                                            ViChar     errorMessage[])
{
    return RSCMU_RF_NSig_SensLevRef (instrSession, ReferenceLevel, errorMessage);
}

/*===========================================================================*/
/* Function: Input level - Attenuation
/* Purpose : This function sets the attenuation or gain factor for the
/*           input measurement Path.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_RF_NSig_SensLevAtt (ViSession instrSession,
                                            ViInt32   Mode,
                                            ViChar    errorMessage[])
{
    return RSCMU_RF_NSig_SensLevAtt (instrSession, Mode, errorMessage);
}

/*===========================================================================*/
/* Function: Input level - Mode
/* Purpose : This function sets the attenuation or gain factor for the
/*           input measurement Path.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_RF_NSig_SensLevMode (ViSession instrSession,
                                             ViInt32   mode,
                                             ViChar    errorMessage[])
{
    return RSCMU_RF_NSig_SensLevMode (instrSession, mode, errorMessage);
}

/*
 *-----------------------------------------------------------------------------
 *    TRIGGER MODE
 *    The subsystem TRIGger contains the functions for determination
 *    of the trigger mode.
 *    It corresponds to the index card Trigger in the popup menu Group
 *    Configuration.
 * ----------------------------------------------------------------------------
 */


/*===========================================================================*/
/* Function: Trigger Mode
/* Purpose : This function defines the trigger mode.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_RF_NSig_TrigSour (ViSession instrSession,
                                          ViInt32   Source,
                                          ViChar    errorMessage[])
{
    return RSCMU_RF_NSig_TrigSour (instrSession, Source, errorMessage);
}

/*===========================================================================*/
/* Function: Set Threshold
/* Purpose : This function sets the threshold at which the trigger signal
/*           triggers the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_RF_NSig_TrigThr (ViSession  instrSession,
                                         ViInt32    TriggerThreshold,
                                         ViChar     errorMessage[])
{
    return RSCMU_RF_NSig_TrigThr (instrSession, TriggerThreshold, errorMessage);
}

/*===========================================================================*/
/* Function: Set Trigger Slope
/* Purpose : This Function sets the trigger slope. It is enabled for
/*           trigger Source RFPower and IFPower only.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_RF_NSig_TrigSlop (ViSession instrSession,
                                          ViInt32   slope,
                                          ViChar    errorMessage[])
{
    return RSCMU_RF_NSig_TrigSlop (instrSession, slope, errorMessage);
}

/* ----------------------------------------------------------------------------
 *      LEVEL
 *      This subsystem  contains the functions for determining the level
 *      of the generated RF signals.
 *      It corresponds to the input field RF Level of the panel RF
 *      Generator in the index card Signal in the popup menu Connect.
 *      Control.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set RF level
/* Purpose : This function sets the RF generator level in the used
/*           timeslot. The permissible value range depends on the used
/*           RF output of the CMU and the external attenuation set.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_RF_NSig_SourRfgLev (ViSession  instrSession,
                                            ViReal64   RFLevel,
                                            ViChar     errorMessage[])
{
    return RSCMU_RF_NSig_SourRfgLev (instrSession, RFLevel, errorMessage);
}

/* ----------------------------------------------------------------------------
 *      FREQUENCY
 *      The subsystem POWer:FREQuency contains the functions for setting
 *      the frequency.
 *      It corresponds to the hotkey assignment Frequency in the
 *      graphical measurement menu Power versus Time.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set RF Frequency
/* Purpose : This function defines the RF generator output frequency.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_RF_NSig_SourRfgFreq (ViSession instrSession,
                                             ViReal64  RFFrequency,
                                             ViInt32   FreqUnit,
                                             ViChar    errorMessage[])
{
    return RSCMU_RF_NSig_SourRfgFreq (instrSession, RFFrequency, FreqUnit,
                                        errorMessage);
}

/* ----------------------------------------------------------------------------
 *      FREQUENCY MODULATION
 *      The subsystem RFGenerator:FM contains the functions for
 *      determination of the internal RF generator frequency modulation.
 *      It corresponds to the Mode and Offset settings in the Generator
 *      panel (in Connection Control, index card Signal and in the
 *      Analyzer/Generator menu).
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set FM state
/* Purpose : This function sets whether the output signal is modulated
/*           i.e. whether the modulation specified with CONF:RFG:FM:DEV
/*           has an effect.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_RF_NSig_SourRfgMod (ViSession instrSession,
                                            ViInt32   modulation,
                                            ViChar    errorMessage[])
{
    ViString    list[]= {"OFF", "SSB", VI_NULL};
    ViStatus    RSCMU_Status = VI_SUCCESS;

    CHECKRET (RSCMU_checkIndexInList (instrSession, modulation, list,
                                        RSCMU_ERROR_PARAMETER2));
    return  RSCMU_RF_NSig_SourRfgMod (instrSession, modulation, errorMessage);
}

/*===========================================================================*/
/* Function: Set SSB frequency
/* Purpose : This function defines the (single side band) offset
/*           frequency for RF generator modulation.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_RF_NSig_SourRfgModSsbFreq (ViSession instrSession,
                                                   ViReal64  FrequencyOffset,
                                                   ViChar    errorMessage[])
{
    return RSCMU_RF_NSig_SourRfgModSsbFreq (instrSession, FrequencyOffset,
                                            errorMessage);
}

/*===========================================================================*/
/* Function:
/* Purpose : Sets ouput hopping frequency
/*
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_RF_NSig_SourRfgFhopStat (ViSession instrSession,
                                                 ViBoolean mode,
                                                 ViChar    errorMessage[])
{
    return RSCMU_RF_NSig_SourRfgFhopStat (instrSession, mode, errorMessage);
}

/*===========================================================================*/
/* Function: sets hopping frequency
/* Purpose : This command defines the hopping output frequency of the RF
/*           generator
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_RF_NSig_SourRfgFhopFreq (ViSession instrSession,
                                                 ViReal64  frequencyValue,
                                                 ViInt32   unit,
                                                 ViChar    errorMessage[])
{
    return RSCMU_RF_NSig_SourRfgFhopFreq (instrSession, frequencyValue,
                                            unit, errorMessage);
}

/*===========================================================================*/
/* Function: Sets frequency hopping mode
/* Purpose : This function selects whether the frequency set is meant to be
/*           relative  or absolute
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_RF_NSig_SourRfgFhopFreqMode (ViSession instrSession,
                                                     ViBoolean mode,
                                                     ViChar    errorMessage[])
{
    return RSCMU_RF_NSig_SourRfgFhopFreqMode (instrSession, mode, errorMessage);
}

/*===========================================================================*/
/* Function: Sets ramping setting
/* Purpose : This function determines whether the RF generator generates a CW
/*           signal or a GSM-like burst signal
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_RF_NSig_SourRfgPulsStat (ViSession instrSession,
                                                 ViBoolean mode,
                                                 ViChar    errorMessage[])
{
    return RSCMU_RF_NSig_SourRfgPulsStat (instrSession, mode, errorMessage);
}

/* ----------------------------------------------------------------------------
 *      GENERATOR CONFIGURATION
 *      The subsystem RFGenerator:BANDwidth contains the function for
 *      determination of the modulation filterbandwidth.
 *      It corresponds to the Modulation Filter setting in the popup
 *      menu Generator Config. in the index card Modulation.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set Modulation Filter Bandwidth
/* Purpose : This function defines the modulation filter value.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_RF_NSig_SourRfgBand (ViSession instrSession,
                                             ViInt32   modulationFilter,
                                             ViChar    errorMessage[])
{
    return RSCMU_RF_NSig_SourRfgBand (instrSession, modulationFilter,
                                        errorMessage);
}

/*
 *-----------------------------------------------------------------------------
 *    MEASUREMENT OBJECT RF GENERATOR
 *    The subsystem RFGenerator contains the functions for
 *    determination of the parameters for internal RF generator
 *    control.
 *    It corresponds to the RF Generator panel in the index card
 *    Signal in the popup menu Connect. Control and in the measurement
 *    menu Analyzer/Generator.
 * ----------------------------------------------------------------------------
 *      GENERATOR CONTROL
 *      This class contains the functions for general control of the RF
 *      generator.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Start RF Generator
/* Purpose : Starts RF Generator and reserves ressources
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_RF_NSig_InitRfg (ViSession instrSession, ViChar errorMessage[])
{
    return RSCMU_RF_NSig_InitRfg (instrSession, errorMessage);

}

/*===========================================================================*/
/* Function: Switch Off RF Generator
/* Purpose : Switches off RF Generator and releases resources
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_RF_NSig_AborRfg (ViSession instrSession, ViChar errorMessage[])
{
    return RSCMU_RF_NSig_AborRfg (instrSession, errorMessage);
}

/*===========================================================================*/
/* Function: Generator Status
/* Purpose : This function returns the current generator status.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_RF_NSig_FetcRfgStat (ViSession  instrSession,
                                             ViPInt32   RFGeneratorStatus,
                                             ViChar     errorMessage[])
{
    return RSCMU_RF_NSig_FetcRfgStat (instrSession, RFGeneratorStatus,
                                        errorMessage);
}

/*
 *-----------------------------------------------------------------------------
 * CONNECTION CONTROL
 * ------------------
 * The functions presented in this section define the analyzer and
 * generator settings, the inputs and outputs used as well as the
 * reference frequency.
 * They correspond to the settings in the popup menu of the
 * Connect. Control softkey located to the right of the header of
 * each main menu.
 *-----------------------------------------------------------------------------
 *    ANALYSER SETTINGS
 *    The subsystem RFANalyzer contains the functions for
 *    determination of the parameters for analyzer control.
 *    It corresponds to the Analyzer Settings panel in the index card
 *    Signal in the popup menu Connect. Control.
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set RF Frequency
/* Purpose : This function defines the analyzer input frequency.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_RF_NSig_RfanFreq (ViSession instrSession,
                                          ViReal64  RFFrequency,
                                          ViInt32   FreqUnit,
                                          ViChar    errorMessage[])
{
    return RSCMU_RF_NSig_RfanFreq (instrSession, RFFrequency,
                                    FreqUnit, errorMessage);
}

/*===========================================================================*/
/* Function: Set Analyser Bandwidth
/* Purpose : This function defines the analyzer bandwidth. If WIDE is
/*           set no restriction is placed on the input frequency.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_RF_NSig_RfanBandRes (ViSession  instrSession,
                                             ViInt32    Bandwidth,
                                             ViChar     errorMessage[])
{
    return RSCMU_RF_NSig_RfanBandRes (instrSession, Bandwidth, errorMessage);
}

/*===========================================================================*/
/* Function: Set measurement Duration
/* Purpose : This function sets the time period during which the peak
/*           power is determined.
/*           With the time 0, the power is immediately measured on the
/*           measurement start,i.e. the instantaneous value is measured.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_RF_NSig_ConfRfanPowRtim (ViSession instrSession,
                                                 ViReal64  Duration,
                                                 ViChar    errorMessage[])
{
    return RSCMU_RF_NSig_ConfRfanPowRtim (instrSession, Duration, errorMessage);
}

/*===========================================================================*/
/* Function: Set Tests Repetition
/* Purpose : This function sets the number of statistics cycles,the stop
/*           condition and the stepping mode for the RF-Analysis.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_RF_NSig_ConfRfanContRep (ViSession  instrSession,
                                                 ViInt32    Repetition,
                                                 ViInt32    StopCondition,
                                                 ViInt32    StepMode,
                                                 ViChar     errorMessage[])
{
    return RSCMU_RF_NSig_ConfRfanContRep (instrSession, Repetition,
                                            StopCondition, StepMode,
                                            errorMessage);
}


/*
 *-----------------------------------------------------------------------------
 * STATISTICS
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set Statistics Cycles
/* Purpose : This function sets the number of statistics cycles,the stop
/*           condition and the stepping mode for the RF Analysis.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_RF_NSig_ConfRfanContRepStat (ViSession  instrSession,
                                                       ViInt32    NbRepetition,
                                                       ViInt32    StopCondition,
                                                       ViInt32    StepMode,
                                                       ViChar     errorMessage[])
{
    return RSCMU_RF_NSig_ConfRfanContRepStat (instrSession, NbRepetition, StopCondition,
                                                StepMode, errorMessage);
}

/*
 *-----------------------------------------------------------------------------
 *    MEASUREMENT OBJECT RF ANALYSER
 *    The subsystem RFANalyzer contains the functions for
 *    determination of the parameters for analyzer control.
 *    It corresponds to the Analyzer Settings panel in the index card
 *    Signal in the popup menu Connect. Control.
 * ----------------------------------------------------------------------------
 *      MEASUREMENT CONTROL
 *      The subsystem RFANalyzer contains the functions for general
 *      control of the RF analysis.
 *-----------------------------------------------------------------------------
 */

/*===========================================================================*/
/* Function: Start RF_analysis
/* Purpose : This function start a new RF_analysis measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_RF_NSig_InitRfan (ViSession instrSession, ViChar errorMessage[])
{
    return RSCMU_RF_NSig_InitRfan (instrSession, errorMessage);
}

/*===========================================================================*/
/* Function: Abort RF_analysis
/* Purpose : This function abort running RF-Analysis measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_RF_NSig_AborRfan (ViSession instrSession, ViChar errorMessage[])
{
    return RSCMU_RF_NSig_AborRfan (instrSession, errorMessage);
}

/*===========================================================================*/
/* Function: Stop RF_analysis
/* Purpose : This function stops the RF Analysis after current statistic
/*           cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_RF_NSig_StopRfan (ViSession instrSession, ViChar errorMessage[])
{
    return RSCMU_RF_NSig_StopRfan (instrSession, errorMessage);
}

/*===========================================================================*/
/* Function: Run next RF_analysis Step
/* Purpose : This function runs next RF-Analysis measurement step.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_RF_NSig_ContRfan (ViSession instrSession, ViChar errorMessage[])
{
    return RSCMU_RF_NSig_ContRfan (instrSession, errorMessage);
}

/*===========================================================================*/
/* Function: RF Analyser Measurement Status
/* Purpose : This function returns the status of the current RF Analyser
/*           measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_RF_NSig_FetcRfanStat (ViSession  RFNSigSession,
                                              ViInt32   *MeasurementStatus,
                                              ViInt32   *CountingNo,
                                              ViChar     _VI_FAR errorMessage[])
{
    return RSCMU_RF_NSig_FetcRfanStat (RFNSigSession, MeasurementStatus,
                                        CountingNo, errorMessage);
}

/*===========================================================================*/
/* Function: Event reporting of the measurement
/* Purpose : This function defines the events generated when the
/*           RF-Analysis is terminated or stopped.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_RF_NSig_ConfRfanErep (ViSession  instrSession,
                                              ViInt32    Mode,
                                              ViChar     errorMessage[])
{
    return RSCMU_RF_NSig_ConfRfanErep (instrSession, Mode, errorMessage);
}

/*
 *-----------------------------------------------------------------------------
 *      RESULTS: MEASUREMENT VALUE
 *      The subsystem RFANalyzer:POWer[:RESULT] contains the function
 *      for reading the analyzer power.
 *      The subsystem corresponds to the Analyzer Power panel in the
 *      Analyzer / Generator menu.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Read scalar measured values
/* Purpose : This function  starts a measurement and output the RF power
/*           analysed by the CMU.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_RF_NSig_ReadRfanPow (ViSession  instrSession,
                                             ViReal64  *RFPower,
                                             ViChar     errorMessage[])
{
    return RSCMU_RF_NSig_ReadRfanPow (instrSession, RFPower, errorMessage);
}

/*===========================================================================*/
/* Function: Fetch Measured Values
/* Purpose : This function  reads out unsynchronized measurement result:
/*           the RF power analysed by the CMU.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_RF_NSig_FetcRfanPow (ViSession  instrSession,
                                             ViReal64  *RFPower,
                                             ViChar     errorMessage[])
{
    return RSCMU_RF_NSig_FetcRfanPow (instrSession, RFPower, errorMessage);
}

/*===========================================================================*/
/* Function: Sample Measured Values
/* Purpose : This function  reads out synchronized measurement result:
/*           the RF power analysed by the CMU.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_RF_NSig_SampRfanPow (ViSession  instrSession,
                                             ViReal64  *RFPower,
                                             ViChar     errorMessage[])
{
    return RSCMU_RF_NSig_SampRfanPow (instrSession, RFPower, errorMessage);
}

/* ----------------------------------------------------------------------------
 *      INPUT AND OUTPUT CONNECTORS
 *      The subsystem IOConnector contains the commands for
 *      configuration of the input and output connectors.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Selection of input connector
/* Purpose : This command determines the connector to be used for incoming
/*           RF signals. The bidirectional connectors RF 1 and RF 2 can be
/*           used both as input and output connectors in the very same
/*           measurement (see OUTPut[:STATe]).
/*           Only one input and one output may be active at a time, which
/*           is why the cur-rently active one is automatically deactivated
/*           on switchover.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_RF_NSig_Inp (ViSession  instrSession,
                                     ViInt32    State,
                                     ViChar     errorMessage[])
{
    return RSCMU_RF_NSig_Inp (instrSession, State, errorMessage);
}

/*===========================================================================*/
/* Function: Selection of output connector
/* Purpose : This function determines the connector to be used for
/*           outgoing RF signals. The bidirectional connectors RF 1 and
/*           RF 2 can be used both as input and output connectors in the
/*           very same measurement.
/*           Only one input and one output may be active at a time, which
/*           is why the cur-rently active one is automatically deactivated
/*           on switchover.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_RF_NSig_Outp (ViSession  instrSession,
                                      ViInt32    State,
                                      ViChar     errorMessage[])
{
    return RSCMU_RF_NSig_Outp (instrSession, State, errorMessage);
}

/*===========================================================================*/
/* Function: External attenuation at the input
/* Purpose : This command assigns an external attenuation value to the
/*           inputs of the instrument (RF 1, RF 2, RF 4 IN).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_RF_NSig_SensCorrLossInp (ViSession  instrSession,
                                                 ViInt32    InputNr,
                                                 ViReal64   Absorption,
                                                 ViChar     errorMessage[])
{
    return RSCMU_RF_NSig_SensCorrLossInp (instrSession, InputNr, Absorption,
                                            errorMessage);
}

/*===========================================================================*/
/* Function: External attenuation at the output
/* Purpose : This command assigns an external attenuation value to the
/*           outputs of the instrument (RF 1, RF 2, RF 3 OUT).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_RF_NSig_SourCorrLossOutp (ViSession  instrSession,
                                                  ViInt32    OutputNr,
                                                  ViReal64   Absorption,
                                                  ViChar     errorMessage[])
{
    return RSCMU_RF_NSig_SourCorrLossOutp (instrSession, OutputNr, Absorption,
                                            errorMessage);
}

/*
 *-----------------------------------------------------------------------------
 *      SYNCHRONISATION
 *      Subsystem REFerence (Synchronization)
 *      The subsystem REFerence contains the commands for setting a system clock
 *      specific to the network. This frquency is set in the index card Synch. in
 *      the popup menu Connect. Control.
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Switching on/off and setting the system clock
/* Purpose : This commands switches the system clock specific to the
/*           network at the REF OUT 2 connector on or off, and determines
/*           the system clock frequency applied to REF OUT 2.
/*           The frequency entered is internally rounded to one of a
/*           discrete values defined in the operating manual.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_RF_NSig_SourDmCloc (ViSession  instrSession,
                                            ViInt32    Mode,
                                            ViReal64   Frequency,
                                            ViChar     errorMessage[])
{
    return RSCMU_RF_NSig_SourDmCloc (instrSession, Mode, Frequency,
                                    errorMessage);
}

/*
 *-----------------------------------------------------------------------------
 *    INPUT LEVEL
 *    This subsystem contains the function for setting the input level
 *    range.
 *    It corresponds to the hotkey assignment Input Level in the
 *    graphical measurement menu Power versus Time.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Sense Input Level Range
/* Purpose : This function defines the level range of the Power vs Time
/*           measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_RF_NSig_SensPowLevRang (ViSession instrSession,
                                                ViInt32   Range,
                                                ViChar    errorMessage[])
{
    return RSCMU_RF_NSig_SensPowLevRang (instrSession, Range, errorMessage);
}

/*
 *-----------------------------------------------------------------------------
 *    FREQUENCY
 *    This subsystem contains the functions for setting the frequency.
 *    It corresponds to the hotkey assignment Frequency in the
 *    graphical measurement menu Power versus Time.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Sense RF Center Frequency
/* Purpose : This function defines the input frequency of the analyzer.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_RF_NSig_SensPowFreqCent (ViSession instrSession,
                                                 ViReal64  CenterFreq,
                                                 ViInt32   FreqUnit,
                                                 ViChar    errorMessage[])
{
    return RSCMU_RF_NSig_SensPowFreqCent (instrSession, CenterFreq,
                                            FreqUnit, errorMessage);
}

/*===========================================================================*/
/* Function: Set BRW
/* Purpose : This function defines the power measurement bandwidth.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_RF_NSig_SensPowFreqBand (ViSession instrSession,
                                                           ViInt32   Bandwidth,
                                                           ViChar    errorMessage[])
{
    return RSCMU_RF_NSig_SensPowFreqBand (instrSession, Bandwidth, errorMessage);
}

/*
 *-----------------------------------------------------------------------------
 *    TIME
 *    This subsystem contains the functions for setting the time
 *    modes.
 *    It corresponds to the hotkey assignment Time in the graphical
 *    measurement menu Power versus Time.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Sense Time Delay
/* Purpose : This function defines the time when the measurement is
/*           relative to the trigger time.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_RF_NSig_SensPowTimeDel (ViSession instrSession,
                                                ViReal64  timeDelay,
                                                ViInt32   Unit,
                                                ViChar    errorMessage[])
{
    return RSCMU_RF_NSig_SensPowTimeDel (instrSession, timeDelay,
                                            Unit, errorMessage);
}

/*===========================================================================*/
/* Function: Sense Pow Time Span
/* Purpose : This function sets the span (i.e.the total evaluation time)
/*           of the Power vs Time measurement.
/*           The permissible spans depend on the selected bandwidth.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_RF_NSig_SensPowTimeSpan (ViSession instrSession,
                                                 ViReal64  Span,
                                                 ViInt32   Unit,
                                                 ViChar    errorMessage[])
{
    return RSCMU_RF_NSig_SensPowTimeSpan (instrSession, Span, Unit, errorMessage);
}

/*===========================================================================*/
/* Function: Sense Triggered Meas. Timeout
/* Purpose : This function sets a timeout period after which the power
/*           measurement is aborted (e.g. if no trigger event could be
/*           detected).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_RF_NSig_SensPowContTim (ViSession instrSession,
                                                ViReal64  timeOut,
                                                ViChar    errorMessage[])
{
    return RSCMU_RF_NSig_SensPowContTim (instrSession, timeOut, errorMessage);
}

/*===========================================================================*/
/* Function: Set Tests Repetition
/* Purpose : This function sets the number of statistics cycles, the
/*           stop condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_RF_NSig_ConfPowContRep (ViSession  instrSession,
                                                ViInt32    Repetition,
                                                ViInt32    StopCondition,
                                                ViInt32    StepMode,
                                                ViChar     errorMessage[])
{
    return RSCMU_RF_NSig_ConfPowContRep (instrSession, Repetition, StopCondition,
                                        StepMode, errorMessage);
}

/*===========================================================================*/
/* Function: Set Grid (ON/OFF)
/* Purpose : This function switches the grid lines in the test diagrams
/*           on or off.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_RF_NSig_DispPowContGrid (ViSession instrSession,
                                                 ViInt32   gridLines,
                                                 ViChar    errorMessage[])
{
    return RSCMU_RF_NSig_DispPowContGrid (instrSession, gridLines, errorMessage);
}

/*
 *-----------------------------------------------------------------------------
 * STATISTICS
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set Statistic Cycles
/* Purpose : This function sets the number of statistics cycles, the
/*           stop condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_RF_NSig_ConfPowContRepStat (ViSession  instrSession,
                                                    ViInt32    NbRepetition,
                                                    ViInt32    StopCondition,
                                                    ViInt32    StepMode,
                                                    ViChar     errorMessage[])
{
    return RSCMU_RF_NSig_ConfPowContRepStat (instrSession, NbRepetition,
                                            StopCondition, StepMode,
                                            errorMessage);
}

//*===========================================================================*/
/* Function: Set Measurement Range
/* Purpose : This function configures the 3 functions Read, Fetc, Samp
/*           _ArrPow by defining the test points on the time axis.
/*           the permissible range for the initial time and the test points
/*           number depends the span and the bandwidth set.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_RF_NSig_ConfArrPowRang (ViSession instrSession,
                                                ViReal64  Time,
                                                ViInt32   Unit,
                                                ViInt32   TestPtsNb,
                                                ViChar    errorMessage[])
{
    return RSCMU_RF_NSig_ConfArrPowRang (instrSession, Time, Unit,
                                        TestPtsNb, errorMessage);
}

/*
 *-----------------------------------------------------------------------------
 *    MEASUREMENT OBJECT NARROW-BAND POWER
 *
 * The subsystem NPOWer measures the power of the signal transmitted by the
 * mobile phone using the RF analyzer configuration of the POWer measurement.
 * Compared to WPOWer, the NPOWer measurement uses a narrow-band (500 kHz Gauss)
 * filter. The narrow-band NPOWer measurement yields the average, maximum and
 * minimum burst power of the current burst (display mode Current) and of the
 * averaged measurement curve (display mode Average).
 * The entire measurement curves (arrays) are not available, and no limit check
 * is performed. NPOWer is a quick and precise alternative to the WPOWer or
 * POWer measurements if only scalar results are needed.
 * Note: A Free Run trigger (TRIGger[:SEQuence]:SOURce FRUN) should be avoided
 * because it delays the NPOWer measurement.
 * ----------------------------------------------------------------------------
 *      MEASUREMENT CONTROL
 *      This subsystem contains the functions for general control of the
 *      narrow-band power measurement.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Start new measurement
/* Purpose : This function starts the narrow-band power measurement, setting it
/*           to the status "RUN"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_RF_NSig_InitNpow (ViSession instrSession,
                                         ViChar    errorMessage[])
{
    return RSCMU_RF_NSig_InitNpow (instrSession, errorMessage);
}



/*===========================================================================*/
/* Function: Abort running measurement and switch off
/* Purpose : This function stops the narrow-band power measurement, setting it
/*           to the status "OFF"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_RF_NSig_AborNpow (ViSession instrSession,
                                         ViChar    errorMessage[])
{
    return RSCMU_RF_NSig_AborNpow (instrSession, errorMessage);
}

/*===========================================================================*/
/* Function: stop measurement after current statistic cycle
/* Purpose : This function stops the narrow-band power measurement, setting it
/*           to the status "STOP"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_RF_NSig_StopNpow (ViSession instrSession,
                                             ViChar    errorMessage[])
{
    return RSCMU_RF_NSig_StopNpow (instrSession, errorMessage);
}

/*===========================================================================*/
/* Function: Next Measurement Step
/* Purpose : This function continues the narrow-band power measurement, setting
/*           it to the status "RUN"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_RF_NSig_ContNpow (ViSession instrSession,
                                         ViChar errorMessage[])
{
    return RSCMU_RF_NSig_ContNpow (instrSession, errorMessage);
}

/*===========================================================================*/
/* Function: Event reporting of the measurement
/* Purpose : This function defines the events generated when the measurement
/*           is terminated or stopped.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_RF_NSig_ConfNpowErep (ViSession  instrSession,
                                             ViInt32    Report,
                                             ViChar     errorMessage[])
{
    return RSCMU_RF_NSig_ConfNpowErep (instrSession, Report, errorMessage);
}

/*===========================================================================*/
/* Function: Power/t Measurement Status
/* Purpose : This function returns the status of the current narrow-band power
/*           measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_RF_NSig_FetcNpowStat (ViSession  instrSession,
                                             ViInt32   *MeasurementStatus,
                                             ViInt32   *CountingNo,
                                             ViInt32   *StatisticNo,
                                             ViChar     errorMessage[])
{
    return RSCMU_RF_NSig_FetcNpowStat (instrSession, MeasurementStatus,
                                        CountingNo, StatisticNo, errorMessage);
}

/*
 * ----------------------------------------------------------------------------
 *      CONTROL
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set the filter bandwidth of the narrow-band power measurement
/* Purpose : This function defines the bandwidth of the power measurement.
/*           The TDMA filter is a matched (root-raised cosine) filter
/*           specified in standard TIA-EIA-136xxx for the test of modulation
/*           parameters. The CDMA filter is a 1.4 MHz bandpass filter
/*           specified for cdmaOne  and CDMA2000 tests.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_RF_NSig_SensNpowBwid (ViSession instrSession,
                                              ViInt32   Bandwidth,
                                              ViChar    errorMessage[])
{
    return RSCMU_RF_NSig_SensNpowBwid (instrSession, Bandwidth, errorMessage);
}

/*===========================================================================*/
/* Function: Set Scope of Measurement
/* Purpose : This function defines the statistic count, repetition mode, stop
             condition, and stepping mode for measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_RF_NSig_ConfNpowCont (ViSession instrSession,
                                              ViInt32   NbBurst,
                                              ViInt32   repetition,
                                              ViInt32   NbRepetition,
                                              ViInt32   StopCondition,
                                              ViInt32   StepMode,
                                              ViChar    errorMessage[])
{
    return RSCMU_RF_NSig_ConfNpowCont (instrSession, NbBurst, repetition,
                                        NbRepetition, StopCondition,
                                        StepMode, errorMessage);
}

/*===========================================================================*/
/* Function: Test Cycles
/* Purpose : This function sets the repetition mode, the stop condition and
/*           the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_RF_NSig_ConfNpowContRep (ViSession  instrSession,
                                                 ViInt32    Repetition,
                                                 ViInt32    StopCondition,
                                                 ViInt32    StepMode,
                                                 ViChar     errorMessage[])
{
    return RSCMU_RF_NSig_ConfNpowContRep (instrSession, Repetition, StopCondition,
                                            StepMode, errorMessage);
}

/*
 * ----------------------------------------------------------------------------
 *      STATISTICS
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Statistic Count
/* Purpose : This function sets the number of evaluation periods that
/*           represent one statistics cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_RF_NSig_ConfNpowContStat (ViSession instrSession,
                                                  ViInt32   NbBurst,
                                                  ViChar    errorMessage[])
{
    return RSCMU_RF_NSig_ConfNpowContStat (instrSession, NbBurst, errorMessage);
}

/*===========================================================================*/
/* Function: Set Statistic Cycles
/* Purpose : This function sets the number of statistics cycles, the
/*           stop condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_RF_NSig_ConfNpowContRepStat (ViSession instrSession,
                                                     ViInt32   NbRepetition,
                                                     ViInt32   StopCondition,
                                                     ViInt32   StepMode,
                                                     ViChar    errorMessage[])
{
    return RSCMU_RF_NSig_ConfNpowContRepStat (instrSession, NbRepetition, StopCondition,
                                            StepMode, errorMessage);
}

/*
 * ----------------------------------------------------------------------------
 *      RESULTS
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Read Scalar
/* Purpose : This function starts the NPOWer measurement and returns the
/*           results.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_RF_NSig_ReadNpow (ViSession  instrSession,
                                          ViReal64  *AvgPowCurr,
                                          ViReal64  *MinPowCurr,
                                          ViReal64  *MaxPowCurr,
                                          ViReal64  *AvgPowAvg,
                                          ViReal64  *MinPowAvg,
                                          ViReal64  *MaxPowAvg,
                                          ViReal64  *Frequency,
                                          ViChar     errorMessage[])
{
    return RSCMU_RF_NSig_ReadNpow (instrSession, AvgPowCurr, MinPowCurr, MaxPowCurr,
                               AvgPowAvg, MinPowAvg, MaxPowAvg, Frequency, errorMessage);
}

/*===========================================================================*/
/* Function: Fetch Scalar
/* Purpose : This function reads out measurements (unsynchronized) and returns
/*           the results.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_RF_NSig_FetcNpow (ViSession  instrSession,
                                          ViReal64  *AvgPowCurr,
                                          ViReal64  *MinPowCurr,
                                          ViReal64  *MaxPowCurr,
                                          ViReal64  *AvgPowAvg,
                                          ViReal64  *MinPowAvg,
                                          ViReal64  *MaxPowAvg,
                                          ViReal64  *Frequency,
                                          ViChar     errorMessage[])
{
    return RSCMU_RF_NSig_FetcNpow (instrSession, AvgPowCurr, MinPowCurr, MaxPowCurr,
                               AvgPowAvg, MinPowAvg, MaxPowAvg, Frequency, errorMessage);
}

/*===========================================================================*/
/* Function: Sample Scalar
/* Purpose : This function reads out measurements (synchronized) and returns
/*           the results.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_RF_NSig_SampNpow (ViSession  instrSession,
                                          ViReal64  *AvgPowCurr,
                                          ViReal64  *MinPowCurr,
                                          ViReal64  *MaxPowCurr,
                                          ViReal64  *AvgPowAvg,
                                          ViReal64  *MinPowAvg,
                                          ViReal64  *MaxPowAvg,
                                          ViReal64  *Frequency,
                                          ViChar     errorMessage[])
{
    return RSCMU_RF_NSig_SampNpow (instrSession, AvgPowCurr, MinPowCurr, MaxPowCurr,
                               AvgPowAvg, MinPowAvg, MaxPowAvg, Frequency, errorMessage);
}

/*
/*
 *-----------------------------------------------------------------------------
 *    MEASUREMENT OBJECT POWER/T
 *    This subsystem POWer contains the functions for measurement of
 *    the signal power.
 *    It corresponds to the measurement menu Power versus Time and the
 *    associated popup menu Power vs Time Configuration.
 * ----------------------------------------------------------------------------
 *      MEASUREMENT CONTROL
 *      This subsystem contains the functions for general control of the
 *      power measurement.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Start new measurement
/* Purpose : This function starts the power measurement, setting it to
/*           the status "RUN"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_RF_NSig_InitPow (ViSession  instrSession,
                                         ViChar     errorMessage[])
{
    return RSCMU_RF_NSig_InitPow (instrSession, errorMessage);
}

/*===========================================================================*/
/* Function: Abort running measurement and switch off
/* Purpose : This function stops the power measurement, setting it to
/*           the status "OFF"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_RF_NSig_AborPow (ViSession  instrSession,
                                         ViChar     errorMessage[])
{
    return RSCMU_RF_NSig_AborPow (instrSession, errorMessage);
}

/*===========================================================================*/
/* Function: stop measurement after current statistic cycle
/* Purpose : This function stops the power measurement, setting it to
/*           the status "STOP"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_RF_NSig_StopPow (ViSession  instrSession,
                                         ViChar     errorMessage[])
{
    return RSCMU_RF_NSig_StopPow (instrSession, errorMessage);
}

/*===========================================================================*/
/* Function: Next Measurement Step
/* Purpose : This function continue the power measurement, setting it to
/*           the status "RUN"
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_RF_NSig_ContPow (ViSession  instrSession,
                                         ViChar     errorMessage[])
{
    return RSCMU_RF_NSig_ContPow (instrSession, errorMessage);
}

/*===========================================================================*/
/* Function: RF Power/t Measurement Status
/* Purpose : This function returns the status of the current RF Power/t
/*           measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_RF_NSig_FetcPowStat (ViSession  RFNSigSession,
                                             ViInt32   *MeasurementStatus,
                                             ViInt32   *CountingNo,
                                             ViChar     _VI_FAR errorMessage[])
{
    return RSCMU_RF_NSig_FetcPowStat (RFNSigSession, MeasurementStatus,
                                        CountingNo, errorMessage);
}

/*===========================================================================*/
/* Function: Event reporting of the measurement
/* Purpose : This function defines the events generated when the
/*           measurement is terminated or stopped.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_RF_NSig_ConfPowErep (ViSession  instrSession,
                                             ViInt32    Mode,
                                             ViChar     errorMessage[])
{
    return RSCMU_RF_NSig_ConfPowErep (instrSession, Mode, errorMessage);
}

/*
 *-----------------------------------------------------------------------------
 *    MEASURED VALUES
 *    This subsystem contains the functions for measurement and output
 *    of the measured power versus the time.
 *    It corresponds to the graphical measurement menu Power versus
 *    Time.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Read Measured Values
/* Purpose : This function returns the power values versus the time.
/*           Starting point of the measurement and number of measurement
/*           results are defined in the function "Set Measurement Range".
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_RF_NSig_ReadArrPow (ViSession  instrSession,
                                            ViReal64  *initTime,
                                            ViInt32   *TestPtsNb,
                                            ViReal64   powerValues[],
                                            ViChar     errorMessage[])
{
    return RSCMU_RF_NSig_ReadArrPower (instrSession, RSCMU_CURRENT, initTime, TestPtsNb,
                                        powerValues, errorMessage);
}

/*===========================================================================*/
/* Function: Fetch Measured Values
/* Purpose : This function reads out (unsynch.) the power values versus
/*           the time. Measurement starting point and number of
/*           measurement results are defined in the function
/*           "Set Measurement Range".
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_RF_NSig_FetcArrPow (ViSession  instrSession,
                                            ViReal64  *initTime,
                                            ViInt32   *TestPtsNb,
                                            ViReal64   powerValues[],
                                            ViChar     errorMessage[])
{
    return RSCMU_RF_NSig_FetcArrPower (instrSession, RSCMU_CURRENT, initTime, TestPtsNb,
                                        powerValues, errorMessage);
}

/*===========================================================================*/
/* Function: Sample Measured Values
/* Purpose : This function reads out (synch.) the power values versus
/*           the time. Measurement starting point and number of
/*           measurement results are defined in the function
/*           "Set Measurement Range".
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_RF_NSig_SampArrPow (ViSession  instrSession,
                                            ViReal64   *initTime,
                                            ViInt32   *TestPtsNb,
                                            ViReal64   powerValues[],
                                            ViChar     errorMessage[])
{
    return RSCMU_RF_NSig_SampArrPower (instrSession, RSCMU_CURRENT, initTime, TestPtsNb,
                                        powerValues, errorMessage);
}

/*
 * ----------------------------------------------------------------------------
 *      FREQUENCY / RBW
 *      This class contains the functions for setting the frequency.
 *      It corresponds to the hotkey assignment Frequency/RBW in the
 *      graphical measurement menu Spectrum.
 * ----------------------------------------------------------------------------
 */

/*===========================================================================*/
/* Function: Sense Frequency
/* Purpose : This function sets the center frequency and span or the
/*           start and spectrum analyzer stop frequency.
/*           Start and stop frequency are used for calculation of the
/*           other two frequencies.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_RF_NSig_SensSpecFreqStartStop (ViSession instrSession,
                                                       ViReal64  StartFreq,
                                                       ViInt32   Unit1,
                                                       ViReal64  StopFreq,
                                                       ViInt32   Unit2,
                                                       ViChar    errorMessage[])
{
    return RSCMU_RF_NSig_SensSpecFreqStartStop (instrSession, StartFreq,
                                                Unit1, StopFreq, Unit2,
                                                errorMessage);
}

/*===========================================================================*/
/* Function: Sense Frequency
/* Purpose : This function sets the center frequency and span or the
/*           start and spectrum analyzer stop frequency.
/*           Start and stop frequency are used for calculation of the
/*           other two frequencies.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_RF_NSig_SensSpecFreqCentSpan (ViSession instrSession,
                                                      ViReal64  CenterFreq,
                                                      ViInt32   Unit1,
                                                      ViReal64  Span,
                                                      ViInt32   Unit2,
                                                      ViChar    errorMessage[])
{
    return RSCMU_RF_NSig_SensSpecFreqCentSpan (instrSession, CenterFreq,
                                                Unit1, Span, Unit2, errorMessage);
}

/*===========================================================================*/
/* Function: Sense RBW
/* Purpose : This function defines the spectrum measurement bandwidth.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_RF_NSig_SensSpecFreqBand (ViSession instrSession,
                                                  ViInt32   RBW,
                                                  ViChar    errorMessage[])
{
    return RSCMU_RF_NSig_SensSpecFreqBand (instrSession, RBW, errorMessage);
}

/*
 * ----------------------------------------------------------------------------
 *      INPUT LEVEL
 *      This class contains the functions for setting the level.
 *      It corresponds to the hotkey assignment Input Level in the
 *      graphical measurement menu Spectrum.
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Sense Level Range
/* Purpose : This function defines the level range for the spectrum
/*           measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_RF_NSig_SensSpecLevRang (ViSession instrSession,
                                                 ViInt32   Range,
                                                 ViChar    errorMessage[])
{
    return RSCMU_RF_NSig_SensSpecLevRang (instrSession, Range, errorMessage);
}

/*===========================================================================*/
/* Function: Set Tests Repetition
/* Purpose : This function sets the number of statistics cycles, the
/*           stop condition and the stepping mode for the spectrum
/*           measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_RF_NSig_ConfSpecContRep (ViSession  instrSession,
                                                 ViInt32    Repetition,
                                                 ViInt32    StopCondition,
                                                 ViInt32    StepMode,
                                                 ViChar     errorMessage[])
{
    return RSCMU_RF_NSig_ConfSpecContRep (instrSession, Repetition, StopCondition,
                                            StepMode, errorMessage);
}

/*===========================================================================*/
/* Function: Set Grid (ON/OFF)
/* Purpose : This function switches the grid lines in the test diagrams
/*           on or off.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_RF_NSig_DispSpecContGrid (ViSession instrSession,
                                                  ViInt32   gridLines,
                                                  ViChar    errorMessage[])
{
    return RSCMU_RF_NSig_DispSpecContGrid (instrSession, gridLines, errorMessage);
}

/*
 * ----------------------------------------------------------------------------
 *      STATISTICS
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Set Statistic Cycles
/* Purpose : This function sets the number of statistics cycles, the
/*           stop condition and the stepping mode for the spectrum
/*           measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_RF_NSig_ConfSpecContRepStat (ViSession  instrSession,
                                                     ViInt32    NbRepetition,
                                                     ViInt32    StopCondition,
                                                     ViInt32    StepMode,
                                                     ViChar     errorMessage[])
{
    return  RSCMU_RF_NSig_ConfSpecContRepStat (instrSession, NbRepetition,
                                                StopCondition, StepMode,
                                                errorMessage);
}

/*===========================================================================*/
/* Function: Set Measurement Range
/* Purpose :
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_RF_NSig_ConfArrSpecRang (ViSession instrSession,
                                                 ViReal64  initialFreq,
                                                 ViInt32   Unit,
                                                 ViInt32   TestPtsNb,
                                                 ViChar    errorMessage[])
{
    return RSCMU_RF_NSig_ConfArrSpecRang (instrSession, initialFreq, Unit,
                                            TestPtsNb, errorMessage);
}

/*
 *-----------------------------------------------------------------------------
 *    MEASUREMENT OBJECT SPECTRUM
 *    This subsystem contains the functions for frequency spectrum
 *    measurement .
 *    The subsystem corresponds to the measurement menu Spectrum and
 *    the associated popup menu Spectrum Config.
 * ----------------------------------------------------------------------------
 *      MEASUREMENT CONTROL
 *      This subsystem  contains the functions for general control of
 *      the spectrums.
 *      It corresponds to the Spectrum. softkey in the measurement menu
 *      Spectrum.
 *-----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Start new measurement
/* Purpose : This function start a new Spectrum measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_RF_NSig_InitSpec (ViSession instrSession, ViChar errorMessage[])
{
    return RSCMU_RF_NSig_InitSpec (instrSession, errorMessage);
}

/*===========================================================================*/
/* Function: Abort running measurement and switch off
/* Purpose : this function abort running Spectrum measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_RF_NSig_AborSpec (ViSession instrSession, ViChar errorMessage[])
{
    return RSCMU_RF_NSig_AborSpec (instrSession, errorMessage);
}

/*===========================================================================*/
/* Function: stop measurement
/* Purpose : This function stops Spectrum measurement after current
/*           statistic cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_RF_NSig_StopSpec (ViSession instrSession, ViChar errorMessage[])
{
    return RSCMU_RF_NSig_StopSpec (instrSession, errorMessage);
}

/*===========================================================================*/
/* Function: Next Measurement Step
/* Purpose : This function runs next Spectrum measurement step.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_RF_NSig_ContSpec (ViSession instrSession, ViChar errorMessage[])
{
    return RSCMU_RF_NSig_ContSpec (instrSession, errorMessage);
}

/*===========================================================================*/
/* Function: RF Spectrum Measurement Status
/* Purpose : This function returns the status of the current RF spectrum
/*           measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_RF_NSig_FetcSpecStat (ViSession  RFNSigSession,
                                              ViInt32   *MeasurementStatus,
                                              ViInt32   *CountingNo,
                                              ViChar     _VI_FAR errorMessage[])
{
    return RSCMU_RF_NSig_FetcSpecStat (RFNSigSession, MeasurementStatus, CountingNo,
                                        errorMessage);
}

/*===========================================================================*/
/* Function: Event reporting of the measurement
/* Purpose : This function defines the events generated when the
/*           spectrum measurement is terminated or stopped.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_RF_NSig_ConfSpecErep (ViSession  instrSession,
                                              ViInt32    Mode,
                                              ViChar     errorMessage[])
{
    return RSCMU_RF_NSig_ConfSpecErep (instrSession, Mode, errorMessage);
}

/*
 * ----------------------------------------------------------------------------
 *      MEASURED VALUES
 *      This class contains the functions for measurement and output of
 *      the spectrum measurement.
 *      It corresponds to the various output elements in the graphical
 *      measurement menu Spectrum.
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Read Measurement Values
/* Purpose : This function returns the  Spectrum measurement results.
/*           Starting point of the measurement and number of measurement
/*           results are defined in the function "Set Measurement Range".
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_RF_NSig_ReadArrSpec (ViSession  instrSession,
                                             ViReal64  *initFreq,
                                             ViInt32   *TestPtsNb,
                                             ViReal64   powerValues[],
                                             ViChar     errorMessage[])
{
    return RSCMU_RF_NSig_ReadArrSpectrum (instrSession, RSCMU_CURRENT, initFreq,
                                            TestPtsNb, powerValues, errorMessage);
}

/*===========================================================================*/
/* Function: Fetch Measurement Values
/* Purpose : This function reads out the  Spectrum measurement results. (unsynch)
/*           Starting point of the measurement and number of measurement
/*           results are defined in the function "Set Measurement Range".
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_RF_NSig_FetcArrSpec (ViSession  instrSession,
                                             ViReal64   *initFreq,
                                             ViInt32   *TestPtsNb,
                                             ViReal64   powerValues[],
                                             ViChar     errorMessage[])
{
    return RSCMU_RF_NSig_FetcArrSpectrum (instrSession, RSCMU_CURRENT, initFreq,
                                            TestPtsNb, powerValues, errorMessage);
}

/*===========================================================================*/
/* Function: Sample Measurement Values
/* Purpose : This function reads out the  Spectrum measurement results. (synch)
/*           Starting point of the measurement and number of measurement
/*           results are defined in the function "Set Measurement Range".
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_RF_NSig_SampArrSpec (ViSession  instrSession,
                                             ViReal64   *initFreq,
                                             ViInt32   *TestPtsNb,
                                             ViReal64   powerValues[],
                                             ViChar     errorMessage[])
{
    return RSCMU_RF_NSig_SampArrSpectrum (instrSession, RSCMU_CURRENT, initFreq,
                                            TestPtsNb, powerValues, errorMessage);
}

/*
 * ----------------------------------------------------------------------------
 * CLOSE
 * ----------------------------------------------------------------------------
 */
/*===========================================================================*/
/* Function: Close
/* Purpose : This function close the Basic Unit session and release the
/*           resources
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_Close_RF_NSig (ViSession RFNSigSession, ViChar errorMessage[])
{
    return RSCMU_Close_RF_NSig (RFNSigSession, errorMessage);
}


/*****************************************************************************/
/*= CLASS: UTILITY ==========================================================*/
/*****************************************************************************/

/*===========================================================================*/
/* Function: Reset
/* Purpose : This function resets the instrument.
/*===========================================================================*/
ViStatus _VI_FUNC  RSCMU300_Reset (ViSession instrSession,
                                ViChar    errorMessage[])
{
    return RSCMU_Reset (instrSession, errorMessage);
}

/*===========================================================================*/
/* Function: Error Query
/* Purpose : This function queries the instrument error queue, and returns
/*           the result.
/*===========================================================================*/
ViStatus _VI_FUNC  RSCMU300_ErrorQuery (ViSession  instrSession,
                                     ViInt32    *errorCode,
                                     ViChar      errorMessage[])
{
    return  RSCMU_ErrorQuery (instrSession, errorCode, errorMessage);
}

/*===========================================================================*/
/* Function: Current Version
/* Purpose : This function translates the Current Version value from the CMU
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_CurrentVersion (ViSession instrSession, ViInt32 *CurrentVersion, ViChar _VI_FAR  message[])
{
    return RSCMU_CurrentVersion (instrSession, CurrentVersion, message);
}

/*===========================================================================*/
/* Function: RSCMU300_SetCmuVersion
/* Purpose : Forces the type of CMU and its Firmware version -
/*       to use only to deturn engineering version compatibility
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_SetCmuVersion (ViSession  BaseSession,
                                      ViInt32    CmuType,
                                      ViString   CmuFWVersion,
                                      ViChar     errorMessage[])
{
    return RSCMU_SetCmuVersion (BaseSession, CmuType, CmuFWVersion, errorMessage);
}

/*===========================================================================*/
/* Function: Error Message
/* Purpose : This function translates the error return value from the
/*           instrument driver into a user-readable string.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_Base_errorMessage (ViSession       instrSession,
                                           ViStatus        statusCode,
                                           ViChar _VI_FAR  message[])
{
    return RSCMU_Base_errorMessage (instrSession, statusCode, message);
}

/*===========================================================================*/
/* Function: RSCMU300_Delay
/* Purpose : With a call to RSCMU300_Delay, the current program is suspended
/*           from execution for the number of milliseconds specified by the
/*           argument seconds. RSCMU300_Delay is accurate to a millisecond.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_Delay (ViReal64 Number_Of_seconds)
{
    return RSCMU_Delay (Number_Of_seconds);
}

/*===========================================================================*/
/* Function: SCPI Version
/* Purpose : This function queries the instrument error queue, and returns
/*           the result.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_SCPIVersionQuery (ViSession instrSession,
                                          ViChar    ScpiVersion[],
                                          ViChar    errorMessage[])
{
    return RSCMU_SCPIVersionQuery (instrSession, ScpiVersion, errorMessage);
}

/*===========================================================================*/
/* Purpose :
/*===========================================================================*/
ViStatus _VI_FUNC  RSCMU300_Base_RevisionQuery (ViSession instrSession,
                                             ViChar    instrDriverRev[],
                                             ViChar    instrRev[],
                                             ViChar    errorMessage[])
{

    ViStatus    RSCMU_Status = VI_SUCCESS;

    CHECKERR (RSCMU_Base_RevisionQuery (instrSession, instrDriverRev, instrRev,
                errorMessage));

    /*-----------------------------------------------------------------------*/
    /* Instrument driver revision:
    /* The format for instrDriverRev is a string with four fields separated by
    /* commas, the first field is the revision of the instrument driver, the
    /* second field is the month and year of the version's release, the third
    /* field is the time of the version's release, and the four field is the
    /* version of CVI used to write the current version.
    /*-----------------------------------------------------------------------*/
    strcpy (instrDriverRev, RSCMU300_BASE_REVISION);
    strcat (instrDriverRev, ", ");
    /* From the complilation date of the current file */
    strcat (instrDriverRev, __DATE__);
    strcat (instrDriverRev, ", ");
    /* From the complilation time of the current file */
    strcat (instrDriverRev, __TIME__);
    //strcat (instrDriverRev, ", LW/CVI 5.01");

    return RSCMU_Status;
}

/*===========================================================================*/
/* Function: RSCMU300_Trace_ON
/* Purpose : Set the trace referenced by 'filename' ON
/*===========================================================================*/
ViStatus _VI_FUNC  RSCMU300_Trace_ON (ViSession  BaseSession,
                                   ViString   filename,
                                   ViChar     errorMessage[])
{
    return RSCMU_Trace_ON (BaseSession, filename, errorMessage);
}

/*===========================================================================*/
/* Function: RSCMU300_Trace_OFF
/* Purpose : Set the trace referenced by 'filename' OFF
/*===========================================================================*/
ViStatus _VI_FUNC  RSCMU300_Trace_OFF (ViSession  BaseSession,
                                    ViChar     errorMessage[])
{
    return RSCMU_Trace_OFF (BaseSession, errorMessage);
}

/*=========================================================================*/
/* Function: RSCMU300_SetTimeoutAttribute
/* Purpose : This function specifies the minimum timeout value to use (in
/*           milliseconds) when accessing the device associated with the
/*           given session.
/*=========================================================================*/
ViStatus _VI_FUNC  RSCMU300_SetTimeoutAttribute (ViSession instrSession,
                                              ViUInt32  Timeout,
                                              ViChar    errorMessage[])
{
    return RSCMU_SetTimeoutAttribute (instrSession, Timeout, errorMessage);
}

/*===========================================================================*/
/* Function: RSCMU300_WriteExtTrace
/* Purpose : Write a buffer to the current trace file
/*===========================================================================*/
ViStatus _VI_FUNC  RSCMU300_WriteExtTrace (ViSession  instrSession,
                                          ViChar     Buffer[],
                                          ViChar     errorMessage[])
{
    return RSCMU_WriteExtTrace (instrSession, Buffer, errorMessage);
}

/*===========================================================================*/
/* Function: Go to remote without call drop                                  */
/* Purpose:  This function causes the signalling state to be maintained upon */
/*           a local to remote transition.                                   */
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_SystGtrmComp (ViSession instrSession,
                                      ViBoolean enable,
                                      ViChar    errorMessage[])
{
    return RSCMU_SystGtrmComp (instrSession, enable, errorMessage);
}

/*****************************************************************************/
/*= UTILITY ROUTINES (Non-Exportable Functions) =============================*/
/*****************************************************************************/

/*===========================================================================*/
/* Function: Check Version                                                   */
/* Purpose:  This function checks the current CMU version                    */
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_checkVersion (ViSession vi,
                             ViInt32    version,
                             ViStatus   errorCode)
{
    return RSCMU_checkVersion (vi, version, errorCode);
}

/*===========================================================================*/
/* Function: String to float                                                 */
/* Purpose:  This function converts the string to ViReal64 value with NAN    */
/*           checking.                                                       */
/*===========================================================================*/
ViReal64 _VI_FUNC RSCMU300_atof(ViString _VI_FAR str)
{
    return RSCMU_atof(str);
}

/*===========================================================================*/
/* Function: String to float array                                           */
/* Purpose:  This function converts the string to array of ViReal64 values   */
/*           with NAN checking. Values must be separated by commas           */
/*===========================================================================*/
void _VI_FUNC RSCMU300_atofArray(ViString _VI_FAR string, ViReal64 arr[])
{
    RSCMU_atofArray(string, arr);
}
/*===========================================================================*/
/* Function: Set ViInt32                                                     */
/* Purpose:  This function sets command with integer parameter.              */
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_setViInt32 (ViSession vi,
                           ViString cmd,
                           ViInt32 value,
                           ViInt32 min,
                           ViInt32 max,
                           ViStatus parameterErrorCode)
{
    return RSCMU_setViInt32 (vi, cmd, value, min, max, parameterErrorCode);
}

/*===========================================================================*/
/* Function: Get ViInt32                                                     */
/* Purpose:  This function gets command with integer parameter.              */
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_getViInt32 (ViSession vi,
                           ViString cmd,
                           ViInt32 *value,
                           ViStatus parameterErrorCode)
{
    return RSCMU_getViInt32 (vi, cmd, value, parameterErrorCode);
}

/*===========================================================================*/
/* Function: Set ViReal64                                                    */
/* Purpose:  This function sets command with double parameter.               */
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_setViReal64 (ViSession vi,
                            ViString cmd,
                            ViReal64 value,
                            ViReal64 min,
                            ViReal64 max,
                            ViStatus parameterErrorCode)
{
    return RSCMU_setViReal64 (vi, cmd, value, min, max, parameterErrorCode);
}

/*===========================================================================*/
/* Function: Set ViReal64 with units                                         */
/* Purpose:  This function sets command with double parameter and with the   */
/*           unit .                                                          */
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_setViReal64Unit (ViSession  vi,
                                       ViString cmd,
                                       ViReal64 value,
                                       ViReal64 min[],
                                       ViReal64 max[],
                                       ViInt32  unit,
                                       ViString unitArr[],
                                       ViStatus parameterErrorCode)
{
    return RSCMU_setViReal64Unit (vi, cmd, value, min, max, unit, unitArr,
                                    parameterErrorCode);
}

/*===========================================================================*/
/* Function: Get ViReal64                                                    */
/* Purpose:  This function gets command with double parameter.               */
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_getViReal64 (ViSession vi,
                            ViString cmd,
                            ViReal64 *value,
                             ViStatus parameterErrorCode)
{
    return RSCMU_getViReal64 (vi, cmd, value, parameterErrorCode);
}

/*===========================================================================*/
/* Function: Send Command                                                    */
/* Purpose:  This function sends command to the instrument with error check. */
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_sendCmd (ViSession vi,
                        ViString cmd)
{
    return RSCMU_sendCmd (vi, cmd);
}

/*===========================================================================*/
/* Function: Set String                                                      */
/* Purpose:  This function sets command with string parameter.               */
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_setViString (ViSession vi,
                            ViString cmd,
                            ViString value,
                            ViStatus parameterErrorValue)
{
    return RSCMU_setViString (vi, cmd, value, parameterErrorValue);
}

/*===========================================================================*/
/* Function: Get String                                                      */
/* Purpose:  This function gets command with string parameter.               */
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_getViString (ViSession vi,
                            ViString _VI_FAR cmd,
                            ViString _VI_FAR value,
                            ViInt32 buffer_size,
                            ViStatus parameterErrorCode)
{
    return RSCMU_getViString (vi, cmd, value, buffer_size,
                            parameterErrorCode);
}

/*===========================================================================*/
/* Function: Set Enum                                                        */
/* Purpose:  This function sets command with enumerated parameter.           */
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_setEnum (ViSession vi,
                        ViString cmd,
                        ViInt32 value,
                        ViString _VI_FAR list[],
                        ViStatus parameterErrorCode)
{
    return RSCMU_setEnum (vi, cmd, value, list, parameterErrorCode);
}

/*===========================================================================*/
/* Function: Get Enum                                                        */
/* Purpose:  This function sets command with enumerated parameter.           */
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_getEnum (ViSession vi,
                        ViString cmd,
                        ViInt32 *value,
                        ViString _VI_FAR list[],
                        ViStatus parameterErrorCode)
{
    return RSCMU_getEnum (vi, cmd, value, list, parameterErrorCode);
}

/*===========================================================================*/
/* Function: Check Index List                                                */
/* Purpose:  This function checks if the passed index is valid for given list*/
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_checkIndexInList (ViSession vi,
                                 ViInt32 index,
                                 ViString list[],
                                 ViStatus statusIfError)

{
    return RSCMU_checkIndexInList (vi, index, list, statusIfError);
}

/*===========================================================================*/
/* Function: Check Index List                                                */
/* Purpose:  This function checks if the passed index is valid for given list*/
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_checkIndexInRealList (ViSession vi,
                                 ViInt32 index,
                                 ViReal64 list[],
                                 ViStatus statusIfError)

{
    return RSCMU_checkIndexInRealList (vi, index, list, statusIfError);
}

/*===========================================================================*/
/* Function: Get Index From String                                           */
/* Purpose:  This function returns index for string.                         */
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_getIndexFromString (ViSession vi,
                                   ViString string,
                                   ViString *list,
                                   ViInt32 *index)
{
    return RSCMU_getIndexFromString (vi, string, list, index);
}

/*=========================================================================*/
/* Function: Write to winbatch file                                        */
/* Purpose:  This function writes the string sent to the instrument to the */
/*           winbatch log file                                             */
/*=========================================================================*/
ViStatus _VI_FUNC RSCMU300_WinBatchWrite (ViSession instrSession,
                         ViString _VI_FAR command)
{
    return RSCMU_WinBatchWrite (instrSession, command);
}

/*=========================================================================*/
/* Function: Write to winbatch file                                        */
/* Purpose:  This function writes the response from the instrument to the  */
/*           winbatch log file                                             */
/*=========================================================================*/
ViStatus _VI_FUNC RSCMU300_WinBatchRead (ViSession instrSession,
                         ViString _VI_FAR buffer)
{
    return  RSCMU_WinBatchRead (instrSession, buffer);
}

/*=========================================================================*/
/* Function: Set Check Status                                              */
/* Purpose:  This function sets the bit for status checking                */
/*=========================================================================*/
ViStatus _VI_FUNC RSCMU300_setCheckStatus(ViSession instrSession, ViBoolean checkStatus)
{
    return RSCMU_setCheckStatus(instrSession, checkStatus);
}

/*=========================================================================*/
/* Function: Status                                                        */
/* Purpose:  This function reads the system status byte.                   */
/*=========================================================================*/
ViStatus _VI_FUNC RSCMU300_sysStatus (ViSession instrSession, ViUInt16* stb)
{
    return RSCMU_sysStatus (instrSession, stb);
}

/******************************************************************************
 * Function: Read Data With Unknown length
 * Description: This function allocate buffer and read data from the instrument
 * WARNING:  You must deallocate buffer, if any pointer has been returned.
 *           This function does not work correctly, when you read bin data via
 *           serial interface
 *****************************************************************************/
ViStatus _VI_FUNC RSCMU300_ReadDataUnknownLength(ViSession instrSession,
                                            ViChar **outBuffer,
                                            ViUInt32 *count)
{
    return RSCMU_ReadDataUnknownLength(instrSession, outBuffer, count);
}

/*===========================================================================*/
/* Function: RSCMU300_viWrite
/* Purpose : Send the data to the instrument and to the WinBatch file
/*
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_viWrite (ViSession  instrSession,
                                 ViChar     writeBuf[],
                                 ViUInt32   cnt)
{
    return RSCMU_viWrite (instrSession, writeBuf, cnt);
}

/*===========================================================================*/
/* Function: RSCMU300_viRead
/* Purpose : Reads the response from the instrument and puts it to the
/*           WinBatch file
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_viRead (ViSession  instrSession,
                                ViChar     readBuf[],
                                ViUInt32   cnt)
{
    return RSCMU_viRead (instrSession, readBuf, cnt);
}

/*===========================================================================*/
/* Function: RSCMU300_getTabSecAdd
/* Purpose : Query at CMU to obtain a string containing Secondary Addresses
/*           and options associed to these addresses. This string is breaked
/*           into tokens and putted in the Globals of BASIC UNIT Session
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_getTabSecAdd (ViSession instrSession, ViChar errorMessage[])
{
    return RSCMU_getTabSecAdd (instrSession, errorMessage);
}

/*===========================================================================*/
/* Function: RSCMU300_WriteFile
/* Purpose : Write a buffer given by the instrument to a specified file
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_WriteFile (ViSession instrSession,
                                   ViAddr    ptTargetFile,
                                   ViChar    Buffer[],
                                   ViChar    errorMessage[])
{
    return RSCMU_WriteFile (instrSession, ptTargetFile, Buffer, errorMessage);
}

/*===========================================================================*/
/* Function: Initialize Clean Up
/* Purpose :
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_initCleanUp (ViSession  openRMSession,
                                     ViSession  openInstrSession,
                                     ViStatus   currentStatus)
{
    return RSCMU_initCleanUp (openRMSession, openInstrSession, currentStatus);
}

/*===========================================================================*/
/* Function: Boolean Value Out Of Range - ViBoolean
/* Purpose : This function checks a Boolean to see if it is equal to VI_TRUE
/*           or VI_FALSE. If the value is out of range, the return value is
/*           VI_TRUE, otherwise the return value is VI_FALSE.
/*===========================================================================*/
ViBoolean _VI_FUNC RSCMU300_invalidViBooleanRange (ViBoolean val)
{
  return RSCMU_invalidViBooleanRange (val);
}

/*===========================================================================*/
/* Function: Short Unsigned Integer Value Out Of Range - ViUInt16
/* Purpose : This function checks a short unsigned integer value to see if it
/*           lies between a minimum and maximum value.  If the value is out
/*           of range,  the return value is VI_TRUE, otherwise the return
/*           value is VI_FALSE.
/*===========================================================================*/
ViBoolean _VI_FUNC RSCMU300_invalidViUInt16Range (ViUInt16 val, ViUInt16 min, ViUInt16 max)
{
  return RSCMU_invalidViUInt16Range (val, min, max);
}

ViBoolean _VI_FUNC RSCMU300_invalidViInt16Range (ViInt16 val, ViInt16 min, ViInt16 max)
{
  return RSCMU_invalidViInt16Range (val, min, max);
}

/*===========================================================================*/
/* Function: Long Signed Integer Value Out Of Range - ViInt32
/* Purpose : This function checks a long signed integer value to see if it
/*           lies between a minimum and maximum value.  If the value is out
/*           of range,  the return value is VI_TRUE, otherwise the return
/*           value is VI_FALSE.
/*===========================================================================*/
ViBoolean _VI_FUNC RSCMU300_invalidViInt32Range (ViInt32 val, ViInt32 min, ViInt32 max)
{
  return RSCMU_invalidViInt32Range (val, min, max);
}

/*===========================================================================*/
/* Function: Long Unsigned Integer Value Out Of Range - ViUInt32
/* Purpose : This function checks a long unsigned integer value to see if it
/*           lies between a minimum and maximum value.  If the value is out
/*           of range,  the return value is VI_TRUE, otherwise the return
/*           value is VI_FALSE.
/*===========================================================================*/
ViBoolean _VI_FUNC RSCMU300_invalidViUInt32Range (ViUInt32 val, ViUInt32 min, ViUInt32 max)
{
  return RSCMU_invalidViUInt32Range (val, min, max);
}

/*===========================================================================*/
/* Function: Real (Float) Value Out Of Range - ViReal32
/* Purpose : This function checks a real (float) value to see if it lies
/*           between a minimum and maximum value.  If the value is out of
/*           range, the return value is VI_TRUE, otherwise the return value
/*           is VI_FALSE.
/*===========================================================================*/
ViBoolean _VI_FUNC RSCMU300_invalidViReal32Range (ViReal32 val, ViReal32 min, ViReal32 max)
{
  return RSCMU_invalidViReal32Range (val, min, max);
}

/*===========================================================================*/
/* Function: Real (Double) Value Out Of Range - ViReal64
/* Purpose : This function checks a real (double) value to see if it lies
/*           between a minimum and maximum value.  If the value is out of
/*           range, the return value is VI_TRUE, otherwise the return value
/*           is VI_FALSE.
/*===========================================================================*/
ViBoolean _VI_FUNC RSCMU300_invalidViReal64Range (ViReal64 val, ViReal64 min, ViReal64 max)
{
  return RSCMU_invalidViReal64Range (val, min, max);
}

/*===========================================================================*/
/* Function: RSCMU300_RF_NSig_GetResourceName                                   */
/* Purpose:  This function returns resource descriptor for TDMA option.      */
/*           Session parameter must contain at least 256 elements ViChar[256]*/
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_RF_NSig_GetResourceName (ViSession instrSession,
                                                 ViSession instrSessionBase,
                                                 ViChar _VI_FAR sessionName[])
{
    return RSCMU_RF_NSig_GetResourceName (instrSession, instrSessionBase,
                                            sessionName);
}

/*===========================================================================*/
/* Function: RSCMU300_Audio_NSig_GetResourceName                                */
/* Purpose:  This function returns resource descriptor for TDMA option.      */
/*           Session parameter must contain at least 256 elements ViChar[256]*/
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_Audio_NSig_GetResourceName (ViSession instrSession,
                                                    ViSession instrSessionBase,
                                                    ViChar _VI_FAR sessionName[])
{
    return RSCMU_Audio_NSig_GetResourceName (instrSession, instrSessionBase,
                                            sessionName);
}

/*===========================================================================*/
/* Function: RSCMU300_SendControlCommand
/* Purpose : This function send a command to the CMU
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_SendControlCommand (ViSession instrSession,
                                            ViInt32   StartCmd,
                                            ViInt32   Object,
                                            ViInt32   Modulation,
                                            ViChar    errorMessage[])

{
    return RSCMU_SendControlCommand (instrSession, StartCmd, Object,
                                    Modulation, errorMessage);
}

/*===========================================================================*/
/* Function: Event reporting of the measurement
/* Purpose : This function defines the events generated when the
/*           measurement is terminated or stopped.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_ConfReporting (ViSession  instrSession,
                                       ViInt32    Object,
                                       ViInt32    Modulation,
                                       ViInt32    Report,
                                       ViChar     errorMessage[])
{
    return RSCMU_ConfReporting (instrSession, Object, Modulation,
                                Report, errorMessage);
}

/*===========================================================================*/
/* Function: Power/t Measurement Status
/* Purpose : This function returns the status of the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_FetcStatus (ViSession  instrSession,
                                    ViInt32    Object,
                                    ViInt32    Modulation,
                                    ViInt32   *MeasurementStatus,
                                    ViInt32   *CountingNo,
                                    ViInt32   *StatisticNo,
                                    ViChar     errorMessage[])
{
    return  RSCMU_FetcStatus (instrSession, Object, Modulation,
                                MeasurementStatus, CountingNo,
                                StatisticNo, errorMessage);
}

/*===========================================================================*/
/* Function: Set Scope of Measurement
/* Purpose : This function restricts the type of measured values and
/*           determines the number of bursts within a statistics cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_ConfControl (ViSession instrSession,
                                     ViInt32   Object,
                                     ViInt32   Modulation,
                                     ViInt32   MeasuredValuesType,
                                     ViInt32   NbBurst,
                                     ViChar    errorMessage[])
{
    return RSCMU_ConfControl (instrSession, Object, Modulation, MeasuredValuesType,
                                NbBurst, errorMessage);
}

/*===========================================================================*/
/* Function: Set Tests Repetition
/* Purpose : This function sets the number of statistics cycles,the stop
/*           condition and the stepping mode for the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_ConfControlRep (ViSession  instrSession,
                                        ViInt32    Object,
                                        ViInt32    Modulation,
                                        ViInt32    Repetition,
                                        ViInt32    StopCondition,
                                        ViInt32    StepMode,
                                        ViChar     errorMessage[])
{
    return RSCMU_ConfControlRep (instrSession, Object, Modulation, Repetition,
                                StopCondition, StepMode, errorMessage);
}

/*===========================================================================*/
/* Function: Repetition Mode
/* Purpose : This function defines the number of test cycles and, if
/*           required, an abort condition for the measurement.
/*           Note: In the case of READ commands (READ:...), the <Repetition>
/*           parameter has no effect; the measurement is always aborted after
/*           a single shot.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_ConfContRepStat (ViSession  instrSession,
                                         ViInt32    Object,
                                         ViInt32    Modulation,
                                         ViInt32    NbRepetition,
                                         ViInt32    StopCondition,
                                         ViInt32    StepMode,
                                         ViChar     errorMessage[])
{
    return RSCMU_ConfContRepStat (instrSession, Object, Modulation, NbRepetition,
                                    StopCondition, StepMode, errorMessage);
}

/*===========================================================================*/
/* Function: Default Settings
/* Purpose : If used with ON, this function sets all the parameters of the
/*           subsystem to their default values. (OFF has no effect).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_ConfContDef (ViSession instrSession,
                                     ViInt32   Object,
                                     ViInt32   Modulation,
                                     ViInt32   DefaultValues,
                                     ViChar    errorMessage[])
{
    return RSCMU_ConfContDef (instrSession, Object, Modulation, DefaultValues,
                                errorMessage);
}

/*===========================================================================*/
/* Function: Measurement scalar for narrow-band power
/* Purpose : This function starts the measurement and outputs the results.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_RF_NSig_Npow (ViSession  instrSession,
                                      ViInt32    command,
                                      ViReal64  *AvgPowCurr,
                                      ViReal64  *MinPowCurr,
                                      ViReal64  *MaxPowCurr,
                                      ViReal64  *AvgPowAvg,
                                      ViReal64  *MinPowAvg,
                                      ViReal64  *MaxPowAvg,
                                      ViReal64  *Frequency,
                                      ViChar     errorMessage[])
{
    return RSCMU_RF_NSig_Npow (instrSession, command, AvgPowCurr,
                                MinPowCurr, MaxPowCurr, AvgPowAvg,
                                MinPowAvg, MaxPowAvg, Frequency,
                                errorMessage);
}

/*###########################################################################*/
/*                                                                           */
/*  VXI PLUG & PLAY COMPATIBILITY FUNCTIONS                                  */
/*                                                                           */
/*  These functions provide a VXIplug&play compatibily of this instrument    */
/*  driver with regard to the following documents:                           */
/*                                                                           */
/*  VPP-3.1: Instrument Drivers                                              */
/*      Architecture and Design                                              */
/*      Specification                                                        */
/*      Revision 4.0                                                         */
/*      February 5, 1996                                                     */
/*                                                                           */
/*  VPP-3.2: Instrument Driver                                               */
/*      Functional Body Specification                                        */
/*      Revision 4.0                                                         */
/*      February 2, 1996                                                     */
/*                                                                           */
/*  By: Jan Sima, ELCOM, a.s., Czech Republic                                */
/*                                                                           */
/*###########################################################################*/
#ifndef _REMOVE_VXIPNP_FUNCTIONS_

/*===========================================================================*/
/* Function: Initialize                                                      */
/* Purpose:  This function opens the instrument, queries the instrument      */
/*           for its ID, and initializes the instrument to a known state.    */
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_init (ViRsrc     resourceName,
                              ViBoolean  IDQuery,
                              ViBoolean  resetDevice,
                              ViPSession instrSession)
{
    return RSCMU_init ( resourceName, IDQuery, resetDevice, instrSession );
}

/*===========================================================================*/
/* Function: Init RF Non Signalling                                          */
/* Purpose:  This function initializes the RF non signalling module's        */
/*           global data structures. This function is used in VEE where this */
/*           can not be a part of the VXIpnp init function.                  */
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_initRFNSig (ViSession RFNSigSession,
                                    ViSession BaseSession)
{
    return RSCMU_initRFNSig (RFNSigSession, BaseSession);
}

/*===========================================================================*/
/* Function: Init Audio Non Signalling                                       */
/* Purpose:  This function initializes the Audio non signalling module's     */
/*           global data structures. This function is used in VEE where this */
/*           can not be a part of the VXIpnp init function.                  */
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_initAudioNSig (ViSession AudioNSigSession,
                                   ViSession BaseSession)
{
    return RSCMU_initAudioNSig (AudioNSigSession, BaseSession);
}

/*===========================================================================*/
/* Function: Get Instrument Handle                                           */
/* Purpose:  This function passes the instrument handle from the first       */
/*           parameter to the second parameter. This function is used in VEE */
/*           where it allows to get the current instrument handle.           */
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GetInstrumentHandle (ViSession instrumentHandle,
                                             ViSession *instrumentHandleOut)
{
    return RSCMU_GetInstrumentHandle (instrumentHandle, instrumentHandleOut);
}

/*===========================================================================*/
/* Function: Reset                                                           */
/* Purpose:  This function resets the instrument.  If the reset function     */
/*           is not supported by the instrument, this function returns       */
/*           the warning VI_WARN_NSUP_RESET.                                 */
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_reset (ViSession instrSession)
{
    return RSCMU_reset (instrSession);
}

/*===========================================================================*/
/* Function: Self-Test                                                       */
/* Purpose:  This function executes the instrument self-test and returns     */
/*           the result. If the self test function is not supported by the   */
/*           instrument, this function returns the warning                   */
/*           VI_WARN_NSUP_SELF_TEST.                                         */
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_self_test (ViSession instrSession,
                                    ViPInt16 testResult,
                                    ViChar _VI_FAR testMessage[])
{
    return RSCMU_self_test (instrSession, testResult, testMessage);
}

/*===========================================================================*/
/* Function: Error Query                                                     */
/* Purpose:  This function queries the instrument error queue, and returns   */
/*           the result.                                                     */
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_error_query (ViSession instrSession,
                                      ViPInt32 errorCode,
                                      ViChar _VI_FAR errorMessage[])
{
    return RSCMU_error_query (instrSession, errorCode, errorMessage);
}

/*===========================================================================*/
/* Function: Error Message                                                   */
/* Purpose:  This function translates the error return value from the        */
/*           instrument driver into a user-readable string.                  */
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_error_message (ViSession instrSession,
                                        ViStatus statusCode,
                                        ViChar _VI_FAR errMessage[])
{
    return RSCMU_error_message (instrSession, statusCode, errMessage);
}

/*===========================================================================*/
/* Function: Revision Query                                                  */
/* Purpose:  This function returns the driver and instrument revisions.      */
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_revision_query (ViSession instrSession,
                    ViChar _VI_FAR driverRev[], ViChar _VI_FAR instrRev[])
{
    return RSCMU_revision_query (instrSession, driverRev, instrRev);
}

/*===========================================================================*/
/* Function: Close                                                           */
/* Purpose:  This function closes the instrument.                            */
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_close (ViSession instrSession)
{
    return RSCMU_close (instrSession);
}
#endif


/*###########################################################################*/
/*                                                                           */
/*  UNSUPPORTED FUNCTIONS                                                    */
/*                                                                           */
/*  These functions provide backwards compatibility with old driver versions */
/*  and are no longer supported.                                             */
/*                                                                           */
/*###########################################################################*/
/*=========================================================================*/
/* Function: RSCMU300_Query
/* Purpose : Writes command string to the CMU and reads the resulting output,
/*           this write/read function is intended for use with commands that
/*           generate a response from the instrument.
/*           The operation first: writes the command string designated by the
/*           RSCMU300_Write function to the instrument; then read the data from
/*           the instrument's response by the RSCMU300_Read function.
/*=========================================================================*/
ViStatus _VI_FUNC  RSCMU300_Query (ViSession  instrSession,
                                ViChar     wrtBuf[],
                                ViChar     rdBuf[],
                                ViBoolean  STBQuery,
                                ViChar     errorMessage[])
{
    return RSCMU_Query (instrSession, wrtBuf, rdBuf, STBQuery, errorMessage);
}

/*=========================================================================*/
/* Function: RSCMU300_Query_Array
/* Purpose : Writes command string to the CMU and reads the resulting output,
/*           this write/read function is intended for use with commands that
/*           generate a response from the instrument.
/*           The operation first: writes the command string designated by the
/*           RSCMU300_Write function to the instrument; then read the array data
/*           from the instrument's response by the RSCMU300_Read function.
/*========================================================================*/
ViStatus _VI_FUNC RSCMU300_Query_Array (ViSession instrSession,
                                     ViChar    wrtBuf[],
                                     ViChar    rdBuf[],
                                     ViBoolean STBQuery,
                                     ViChar    errorMessage[])
{
    return RSCMU_Query_Array (instrSession, wrtBuf, rdBuf, STBQuery, errorMessage);
}

/*=========================================================================*/
/* Function: RSCMU300_WriteToRSCMU
/* Purpose : This function send the specified data string to the instrument.
/*=========================================================================*/
ViStatus _VI_FUNC RSCMU300_WriteToRSCMU (ViSession  instrSession,
                                      ViChar     wrtBuf[],
                                      ViChar     errorMessage[])
{
    return RSCMU_WriteToRSCMU (instrSession, wrtBuf, errorMessage);
}

/*=========================================================================*/
/* Function: RSCMU300_ReadFromRSCMU
/* Purpose : This function reads the instrument read buffer.
/*=========================================================================*/
ViStatus _VI_FUNC  RSCMU300_ReadFromRSCMU (ViSession  instrSession,
                                        ViChar     rdBuf[],
                                        ViChar     errorMessage[])
{
    return RSCMU_ReadFromRSCMU (instrSession, rdBuf, errorMessage);
}

/*===========================================================================*/
/* Function: RSCMU300_SepBufSTB
/* Purpose : this function extract from 'Buffer' the response to *STB? and
/*           returns it.
/*===========================================================================*/
/*
static ViStatus _VI_FUNC RSCMU300_SepBufSTB  (ViSession  instrSession,
                                            ViChar     Buffer[],
                                            ViChar     BufSTB[])
{
    return RSCMU_SepBufSTB (instrSession, Buffer, BufSTB);
}
*/
/*===========================================================================*/
/* Function: RSCMU300_Write
/* Purpose : Add to the user's command the request ;*STB? to see if an error
/*           occurs. It puts the resulted command in a WinBatch file to
/*           record the User's scenario. (= TRACE)
/*           This function is called instead of viWrite. (everytime we
/*           need it.)
/*===========================================================================*/
ViStatus _VI_FUNC  RSCMU300_Write (ViSession  instrSession,
                               ViChar     writeBuf[],
                               ViBoolean  QuerySTB,
                               ViUInt32   cnt,
                               ViChar _VI_FAR errorMessage[])
{
    return RSCMU_Write (instrSession, writeBuf, QuerySTB, cnt, errorMessage);
}


/*===========================================================================*/
/* Function: RSCMU300_Read
/* Purpose : This function reads the response given by the CMU after a call
/*           at RSCMU300_Write ("user's command; *STB?")
/*           It puts this response in a WinBatch file to record the User's
/*           scenario, and returns the statusbyte. The statusbyte is then
/*           evaluated by a call to "RSCMU300_register"
/*           This function is called instead of viRead. (everytime we
/*           need it.)
/*===========================================================================*/
ViStatus _VI_FUNC  RSCMU300_Read  (ViSession  instrSession,
                               ViChar     rdBuf[],
                               ViUInt32   cnt,
                               ViChar     _VI_FAR errorMessage[])
{
    return RSCMU_Read  (instrSession, rdBuf, cnt, errorMessage);
}

/*===========================================================================*/
/* Function: Separate Data Values
/* Purpose : This function splits multiple data in a string into a table of
/*           data values, which are separated by one specified delimiter
/*           character.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_SeparateDataValues (ViChar     StringToSeparate[],
                                           ViChar     Delimiters[],
                                           ViChar     TableOfDataValues[100][100])
{
  return RSCMU_SeparateDataValues (StringToSeparate, Delimiters, TableOfDataValues);
}

/*===========================================================================*/
/* Function: RSCMU300_ReturnCMUResponse
/* Purpose : This function is call to return the values of CMU respone
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_ReturnCMUResponse (ViInt32  count,
                                          ViChar   valuesTmp[669][20],
                                          ViReal64 values[])
{
    return RSCMU_ReturnCMUResponse (count, valuesTmp, values);
}

/*===========================================================================*/
/* Function:
/* Purpose :
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GetViInt32Value (ViChar    TableOfDataValues[100][100],
                                         ViInt32   Index,
                                         ViInt32   *dValue)
{
  ViReal64  lfValue;

  if (strcmp (TableOfDataValues[Index], "NAN") != 0)
  {
    if (sscanf (TableOfDataValues[Index], "%le", &lfValue) < 0)
      return RSCMU_ERROR_EOF;

    lfValue += 0.001; // To avoid a problem due to the fraction part
    *dValue = (ViInt32) lfValue;
  }
  else
    *dValue = RSCMU300_NAN_VI_INT32;

  return VI_SUCCESS;
}

/*===========================================================================*/
/* Function: RSCMU300_GetViReal64Value
/* Purpose :
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GetViReal64Value (ViChar     TableOfDataValues[100][100],
                                          ViInt32    Index,
                                          ViReal64   *Value)
{
  if (strcmp (TableOfDataValues[Index], "NAN") != 0)
  {
    if (sscanf (TableOfDataValues[Index], "%le", Value) < 0)
      return RSCMU_ERROR_EOF;
  }
  else
    *Value = RSCMU300_NAN;

  return VI_SUCCESS;
}

/*===========================================================================*/
/* Function: RSCMU300_GetLimitCheckValue
/* Purpose :
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GetLimitCheckValue (ViChar     TableOfDataValues[100][100],
                                            ViInt32    Index,
                                            ViInt32    *LimitCheckValue)

{
  ViStatus      RSCMU300_Status = VI_SUCCESS;

  if (strcmp (TableOfDataValues[Index], "NMAU") == 0)
    *LimitCheckValue = RSCMU300_NMAU;
  else if (strcmp (TableOfDataValues[Index], "NMAL") == 0)
    *LimitCheckValue = RSCMU300_NMAL;
  else if (strcmp (TableOfDataValues[Index], "INV") == 0)
    *LimitCheckValue = RSCMU300_INV;
  else if (strcmp (TableOfDataValues[Index], "OK") == 0)
    *LimitCheckValue = RSCMU300_OK;
  else
    return RSCMU_ERROR_INVALID_LIMIT_CHECK;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: Measurement Status
/* Purpose : This function is call to get the status of the measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GetMeasStatVal (ViInt32 *MeasurementStatus,
                                        ViChar   TableOfDataValues[100][100],
                                        ViInt32  Index)
{
  if (strncmp ("OFF", TableOfDataValues[Index], 3) == 0)
    *MeasurementStatus = RSCMU300_MEAS_STAT_OFF;
  else if (strncmp ("RUN",  TableOfDataValues[Index], 3) == 0)
    *MeasurementStatus = RSCMU300_MEAS_STAT_RUN;
  else if (strncmp ("STOP", TableOfDataValues[Index], 4) == 0)
    *MeasurementStatus = RSCMU300_MEAS_STAT_STOP;
  else if (strncmp ("ERR",  TableOfDataValues[Index], 3) == 0)
    *MeasurementStatus = RSCMU300_MEAS_STAT_ERR;
  else if (strncmp ("STEP", TableOfDataValues[Index], 4) == 0)
    *MeasurementStatus = RSCMU300_MEAS_STAT_STEP;
  else if (strncmp ("RDY",  TableOfDataValues[Index], 3) == 0)
    *MeasurementStatus = RSCMU300_MEAS_STAT_RDY;
  else
    return RSCMU_ERROR_MEAS_STAT_UNKNOWN;

  return VI_SUCCESS;
}

/*===========================================================================*/
/* Function: Sensitivity Measurement Status
/* Purpose : This function is call to get the status of the sensitivity
/*           measurement.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GetSensMeasStatVal (ViInt32 *MeasurementStatus,
                                            ViChar   TableOfDataValues[100][100],
                                            ViInt32  Index)
{
  if (strncmp ("PASS", TableOfDataValues[Index], 4) == 0)
    *MeasurementStatus = RSCMU300_MEAS_STAT_PASS;
  else if (strncmp ("FAIL", TableOfDataValues[Index], 4) == 0)
    *MeasurementStatus = RSCMU300_MEAS_STAT_FAIL;
  else if (strncmp ("INV",  TableOfDataValues[Index], 3) == 0)
    *MeasurementStatus = RSCMU300_MEAS_STAT_INV;
  else if (strncmp ("TMER", TableOfDataValues[Index], 4) == 0)
    *MeasurementStatus = RSCMU300_MEAS_STAT_TMER;
  else if (strncmp ("TLOW", TableOfDataValues[Index], 4) == 0)
    *MeasurementStatus = RSCMU300_MEAS_STAT_TMER;  // keep compatibility with FW < 3.05
  else if (strncmp ("IMP",  TableOfDataValues[Index], 3) == 0)
    *MeasurementStatus = RSCMU300_MEAS_STAT_IMP;
  else
    return RSCMU_ERROR_MEAS_STAT_UNKNOWN;

  return VI_SUCCESS;
}

/*===========================================================================*/
/* Function: Counting No
/* Purpose : This function is call to get the number of the current statistics
/*           cycle.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GetCountingNo (ViInt32 *CountingNo,
                                      ViChar   TableOfDataValues[100][100],
                                      ViInt32  Index)
{
  // Get the number of the current statistics cycle:
  if (strcmp (TableOfDataValues[Index], "NONE") != 0)
    sscanf (TableOfDataValues[Index], "%ld", CountingNo);
  else
    *CountingNo = RSCMU300_NONE;

  return VI_SUCCESS;
}

/*===========================================================================*/
/* Function: Statistic No
/* Purpose : This function is call to get the number of the current evaluation
/*           period.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GetStatisticNo (ViInt32  *StatisticNo,
                                        ViChar    TableOfDataValues[100][100],
                                        ViInt32   Index)
{
  // Get the counter for current evaluation period within a cycle
  if (strcmp (TableOfDataValues[Index], "NONE") != 0)
    sscanf (TableOfDataValues[Index], "%ld", StatisticNo);
  else
    *StatisticNo = RSCMU300_NONE;

    return VI_SUCCESS;
}

/*===========================================================================*/
/* Function: RSCMU300_GetMatchingValue
/* Purpose : This function returns the value matching.
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_GetMatchingValue (ViInt32 *Matching,
                                         ViChar   tab[100][100],
                                         ViInt32  Index)
{
  ViStatus      RSCMU300_Status = VI_SUCCESS;

  // For All Measured Values
  if (strncmp ("NMAU", tab[Index], 4) == 0)
    *Matching = RSCMU300_NMAU;
  else if (strncmp ("NAN", tab[Index], 3) == 0)
    *Matching = RSCMU300_NAN_VI_INT32;
  else if (strncmp ("NMAL", tab[Index], 4) == 0)
    *Matching = RSCMU300_NMAL;
  else if (strncmp ("INV", tab[Index], 3) == 0)
    *Matching = RSCMU300_INV;
  else if (strncmp ("OK", tab[Index], 2) == 0)
    *Matching = RSCMU300_OK;
  // The following messages may be output for the value Matching:
  else if (strncmp ("MATC", tab[Index], 4) == 0)
    *Matching = RSCMU300_MATCH_MATC;
  else if (strncmp ("NMAT", tab[Index], 4) == 0)
    *Matching = RSCMU300_MATCH_NMAT;
  else if (strncmp ("INV", tab[Index], 3) == 0)
    *Matching = RSCMU300_MATCH_INV;
  else if (strncmp ("NTSC", tab[Index], 4) == 0)
    *Matching = RSCMU300_MATCH_NTSC;
  else if (strncmp ("OUT", tab[Index], 3) == 0)
    *Matching = RSCMU300_MATCH_OUT;
  else if (strncmp ("NTR", tab[Index], 3) == 0)
    *Matching = RSCMU300_MATCH_NTR;
  else if (strncmp ("BNF", tab[Index], 3) == 0)
    *Matching = RSCMU300_MATCH_BNF;
  else if (strncmp ("OFF", tab[Index], 3) == 0)
    *Matching = RSCMU300_MATCH_OFF;
  else if (strncmp ("NRAM", tab[Index], 4) == 0)
    *Matching = RSCMU300_MATCH_NRAM;
  else if (strncmp ("OFLW", tab[Index], 4) == 0)
    *Matching = RSCMU300_MATCH_OFLOW;
  else if (strncmp ("UFLW", tab[Index], 4) == 0)
    *Matching = RSCMU300_MATCH_UFLOW;

  return RSCMU300_Status;
}

/*===========================================================================*/
/* Function: RSCMU300_GetGenStatVal
/* Purpose : This function returns the generator status integer value.
/*===========================================================================*/
ViInt32 _VI_FUNC RSCMU300_GetGenStatVal (ViChar _VI_FAR  GeneratorStatus[])
{
  // Return the generator status integer value:
  if (strncmp ("OFF", GeneratorStatus, 3) == 0)
    return RSCMU300_GEN_STAT_OFF; // Generator is in the OFF state
  else if (strncmp ("RUN", GeneratorStatus, 3) == 0)
    return RSCMU300_GEN_STAT_RUN; // Generator is running
  else if (strncmp ("ERR", GeneratorStatus, 3) == 0)
    return RSCMU300_GEN_STAT_ERR; // Generator is in the OFF state because it could
                               // not be started.
  // Here, generator status unknown:
  return -1;
}

/*===========================================================================*/
/* Function: RSCMU300_GetStatVal
/* Purpose : This function returns the status integer value. (identical to
/*           RSCMU300_GetGenStatVal but used more generally)
/*===========================================================================*/
ViInt32 _VI_FUNC RSCMU300_GetStatVal (ViChar _VI_FAR  Status[])
{
  // Return the status integer value:
  if (strncmp ("OFF", Status, 3) == 0)
    return RSCMU300_STAT_OFF; // OFF state
  else if (strncmp ("RUN", Status, 3) == 0)
    return RSCMU300_STAT_RUN; // running
  else if (strncmp ("ERR", Status, 3) == 0)
    return RSCMU300_STAT_ERR; // OFF state because it could not be started.
  // Here, status unknown:
  return -1;
}

/*===========================================================================*/
/* Function: RSCMU300_scanStringBurst
/* Purpose : This function is call to extract Values of Bursts...
/*           It breaks a string into tokens, which are separated
/*           by a comma.
/*           The resulted strings are putted in 'tabResponse'.
/*===========================================================================*/
ViInt32 _VI_FUNC RSCMU300_scanStringBurst (ViChar Buffer[],
                                        ViChar tabResponse[669][20])
{
  ViInt16       count = 0;
  ViChar        *adr;

  adr = strtok(Buffer, ",");

  while (adr)
  {
    strcpy (tabResponse[count], adr);
    adr = strtok (NULL, ",");
    count++;
  }
  return count;
}

/*===========================================================================*/
/* Function: RSCMU300_copyString
/* Purpose : Copy "Maximum_Bytes" Bytes from a Source_String (and from a
/*             Source_Index) to a Target_String (from the Index 0).
/*===========================================================================*/
ViStatus _VI_FUNC RSCMU300_copyString  (ViChar   Target_String[],
                                     ViChar   Source_String[],
                                     ViUInt32 Source_Index,
                                     ViUInt32 Maximum_Bytes)
{
  ViStatus  RSCMU300_Status = VI_SUCCESS;
  ViUInt16 i;

  for (i=0 ; i < (Maximum_Bytes); i++)
    Target_String[i] = Source_String[Source_Index+i];

  return RSCMU300_Status;
}
