/****************************************************************************/
/* WARNING:                                                                 */
/* ======================================================================== */
/* When using the new functinality of the status checking please try to not */
/* use the RSMU_Read and RSMU_Write functions. If it is neccessary call     */
/* RSCMU300_setCheckStatus function to restore your desired checking status.   */
/* After each call of the RSCMU300_Read function the status checking is always */
/* off. This note does not regards to RSCMU300_Query and RSCMU300_QueryArray      */
/* functions.                                                               */
/****************************************************************************/
#ifndef __RSCMU300_HEADER
#define __RSCMU300_HEADER

/*=  Include File     =======================================================*/
#include <vpptype.h>

#if defined(_MSC_VER) || defined(_CVI_)
#define _OUTSIDEVEE_
#endif

#ifndef _DLL
#define _REMOVE_VXIPNP_FUNCTIONS_
#endif

#if defined(__cplusplus) || defined(__cplusplus__)
extern "C" {
#endif


/*****************************************************************************/
/*= Define Instrument Specific Error/Warning Codes Here =====================*/
/*****************************************************************************/
/*---------------------------------------------------------------------------*/
/* The codes for instrument specific ERRORS must be in the range             */
/* 0xBFFC0900 to 0xBFFC0FFF and defined as follows:                          */
/* #define PREFIX_SPECIFIC_ERROR (VI_INSTR_ERROR_OFFSET + n)                 */
/*                                                                           */
/* The codes for instrument specific WARNINGS must be in the range           */
/* 0x3FFC0900 to 0x3FFC0FFF and defined as follows:                          */
/* #define PREFIX_SPECIFIC_WARNING (VI_INSTR_WARNINGS_OFFSET + n)            */
/*                                                                           */
/* Where n represents each instrument specific error/warning number.         */
/* The valid range for n is 0x000 to 0x0FF  for CMU Base                     */
/* The valid range for n is 0x100 to 0x17F  for K2G Option (GSM MS)          */
/* The valid range for n is 0x180 to 0x1FF  for K3G Option (GSM BS)          */
/* The valid range for n is 0x200 to 0x27F  for IS136 Option (MS)            */
/* The valid range for n is 0x280 to 0x2FF  for IS136 Option (BS)            */
/* For ease of use the lower 16 bits of warnings and errors should not       */
/* overlap in the same driver.                                               */
/*                                                                           */
/*---------------------------------------------------------------------------*/

#ifdef _OUTSIDEVEE_

//defined in CMU200
#define VI_INSTR_WARNING_OFFSET                          (0x3FFC0900L)
#define VI_INSTR_ERROR_OFFSET                  (_VI_ERROR+0x3FFC0900L)


#ifndef __RSCMU_HEADER
  #ifdef _OUTSIDEVEE_
    #define RSCMU_LIST_OF_SPECIFIC_ERROR_MESSAGES \
    EXPAND(RSCMU_ERROR_FAIL_ID_QUERY,            (VI_ERROR_FAIL_ID_QUERY),         "Identification query failed") \
    EXPAND(RSCMU_ERROR_STATUS_BYTE,              (VI_INSTR_ERROR_OFFSET + 0x000L), "Status Byte register error occurred") \
    EXPAND(RSCMU_ERROR_INVALID_STATUS_DEV,       (VI_INSTR_ERROR_OFFSET + 0x001L), "The RSCMU is in an internal state where the query is not allowed") \
    EXPAND(RSCMU_ERROR_TIMEOUT,                  (VI_INSTR_ERROR_OFFSET + 0x002L), "Timeout expired before operation is completed") \
    EXPAND(RSCMU_ERROR_NAN,                      (VI_INSTR_ERROR_OFFSET + 0x003L), "The value returned is not a number (NAN) because the CMU 200\nis in a state where the query is not allowed.") \
    EXPAND(RSCMU_ERROR_INF,                      (VI_INSTR_ERROR_OFFSET + 0x004L), "The value returned is overflowed (positive INFinity: +9.9E37)") \
    EXPAND(RSCMU_ERROR_NINF,                     (VI_INSTR_ERROR_OFFSET + 0x005L), "The value returned is overflowed (Negative INFinity: -9.9E37)") \
    EXPAND(RSCMU_ERROR_INTERPRETING_RESPONSE,    (VI_INSTR_ERROR_OFFSET + 0x006L), "Unable to interpret the instrument response") \
    EXPAND(RSCMU_ERROR_MEMORY_ALLOCATION,        (VI_INSTR_ERROR_OFFSET + 0x007L), "Unable to allocate memory block of the requested size") \
    EXPAND(RSCMU_ERROR_INVALID_FCT_GRP,          (VI_INSTR_ERROR_OFFSET + 0x008L), "The function group is not assigned to a secondary address") \
    EXPAND(RSCMU_ERROR_INVALID_MEAS_STATUS,      (VI_INSTR_ERROR_OFFSET + 0x009L), "The RSCMU is in an internal measurement status where the command is not allowed") \
    EXPAND(RSCMU_ERROR_GEN_STAT_UNKNOWN,         (VI_INSTR_ERROR_OFFSET + 0x00AL), "The generator status is unknown") \
    EXPAND(RSCMU_ERROR_MEAS_STAT_UNKNOWN,        (VI_INSTR_ERROR_OFFSET + 0x00BL), "The measurement status is unknown") \
    EXPAND(RSCMU_ERROR_INVALID_LIMIT_CHECK,      (VI_INSTR_ERROR_OFFSET + 0x00CL), "Unable to interpret the instrument limit check response") \
    EXPAND(RSCMU_ERROR_EOF,                      (VI_INSTR_ERROR_OFFSET + 0x00DL), "sscanf attempts to read at end-of-string") \
    EXPAND(RSCMU_ERROR_FILE_EXISTS,              (VI_INSTR_ERROR_OFFSET + 0x00EL), "File exists, cannot overwrite") \
    EXPAND(RSCMU_ERROR_OPEN_FILE,                (VI_INSTR_ERROR_OFFSET + 0x00FL), "Opening the specified file") \
    EXPAND(RSCMU_ERROR_WRITE_FILE,               (VI_INSTR_ERROR_OFFSET + 0x010L), "A file write error is encountered") \
    EXPAND(RSCMU_ERROR_PARAMETER1,               (VI_INSTR_ERROR_OFFSET + 0x011L), "Parameter 1 out of range") \
    EXPAND(RSCMU_ERROR_PARAMETER2,               (VI_INSTR_ERROR_OFFSET + 0x012L), "Parameter 2 out of range") \
    EXPAND(RSCMU_ERROR_PARAMETER3,               (VI_INSTR_ERROR_OFFSET + 0x013L), "Parameter 3 out of range") \
    EXPAND(RSCMU_ERROR_PARAMETER4,               (VI_INSTR_ERROR_OFFSET + 0x014L), "Parameter 4 out of range") \
    EXPAND(RSCMU_ERROR_PARAMETER5,               (VI_INSTR_ERROR_OFFSET + 0x015L), "Parameter 5 out of range") \
    EXPAND(RSCMU_ERROR_PARAMETER6,               (VI_INSTR_ERROR_OFFSET + 0x016L), "Parameter 6 out of range") \
    EXPAND(RSCMU_ERROR_PARAMETER7,               (VI_INSTR_ERROR_OFFSET + 0x017L), "Parameter 7 out of range") \
    EXPAND(RSCMU_ERROR_PARAMETER8,               (VI_INSTR_ERROR_OFFSET + 0x018L), "Parameter 8 out of range") \
    EXPAND(RSCMU_ERROR_PARAMETER9,               (VI_INSTR_ERROR_OFFSET + 0x019L), "Parameter 9 out of range") \
    EXPAND(RSCMU_ERROR_PARAMETER10,              (VI_INSTR_ERROR_OFFSET + 0x01AL), "Parameter 10 out of range") \
    EXPAND(RSCMU_ERROR_PARAMETER11,              (VI_INSTR_ERROR_OFFSET + 0x01BL), "Parameter 11 out of range") \
    EXPAND(RSCMU_ERROR_PARAMETER12,              (VI_INSTR_ERROR_OFFSET + 0x01CL), "Parameter 12 out of range") \
    EXPAND(RSCMU_ERROR_PARAMETER13,              (VI_INSTR_ERROR_OFFSET + 0x01DL), "Parameter 13 out of range") \
    EXPAND(RSCMU_ERROR_PARAMETER14,              (VI_INSTR_ERROR_OFFSET + 0x01EL), "Parameter 14 out of range") \
    EXPAND(RSCMU_ERROR_PARAMETER15,              (VI_INSTR_ERROR_OFFSET + 0x01FL), "Parameter 15 out of range") \
    EXPAND(RSCMU_ERROR_PARAMETER16,              (VI_INSTR_ERROR_OFFSET + 0x020L), "Parameter 16 out of range") \
    EXPAND(RSCMU_ERROR_PARAMETER17,              (VI_INSTR_ERROR_OFFSET + 0x021L), "Parameter 17 out of range") \
    EXPAND(RSCMU_ERROR_PARAMETER18,              (VI_INSTR_ERROR_OFFSET + 0x022L), "Parameter 18 out of range") \
    EXPAND(RSCMU_ERROR_PARAMETER19,              (VI_INSTR_ERROR_OFFSET + 0x023L), "Parameter 19 out of range") \
    EXPAND(RSCMU_ERROR_PARAMETER20,              (VI_INSTR_ERROR_OFFSET + 0x024L), "Parameter 20 out of range") \
    EXPAND(RSCMU_ERROR_PARAMETER21,              (VI_INSTR_ERROR_OFFSET + 0x025L), "Parameter 21 out of range") \
    EXPAND(RSCMU_ERROR_PARAMETER22,              (VI_INSTR_ERROR_OFFSET + 0x026L), "Parameter 22 out of range") \
    EXPAND(RSCMU_DO_FAIL_IF_NO_QUERY,            (VI_INSTR_ERROR_OFFSET + 0x027L), "Do Identification to determine type of CMU") \
    EXPAND(RSCMU_ERROR_NO_DC_ALLOWED,            (VI_INSTR_ERROR_OFFSET + 0x028L), "No DC allowed for AC bandpass") \
    EXPAND(RSCMU_ERROR_FW_VERSION,               (VI_INSTR_ERROR_OFFSET + 0x029L), "Incompatible CMU Firmware - CMU FW V2.10 or higher required") \
    EXPAND(RSCMU_ERROR_FW_VERSION_2_15,          (VI_INSTR_ERROR_OFFSET + 0x02AL), "Incompatible CMU Firmware - CMU FW V2.15 or higher required") \
    EXPAND(RSCMU_ERROR_FW_VERSION_2_16,          (VI_INSTR_ERROR_OFFSET + 0x02BL), "Incompatible CMU Firmware - CMU FW V2.16 or higher required") \
    EXPAND(RSCMU_ERROR_FW_VERSION_2_50,          (VI_INSTR_ERROR_OFFSET + 0x02CL), "Incompatible CMU Firmware - CMU FW V2.50 or higher required") \
    EXPAND(RSCMU_ERROR_FW_VERSION_2_53,          (VI_INSTR_ERROR_OFFSET + 0x02DL), "Incompatible CMU Firmware - CMU FW V2.53 or higher required") \
    EXPAND(RSCMU_ERROR_FW_VERSION_2_62,          (VI_INSTR_ERROR_OFFSET + 0x02EL), "Incompatible CMU Firmware - CMU FW V2.62 or higher required") \
    EXPAND(RSCMU_ERROR_FW_VERSION_3_00,          (VI_INSTR_ERROR_OFFSET + 0x02FL), "Incompatible CMU Firmware - CMU FW V3.00 or higher required") \
    EXPAND(RSCMU_ERROR_FW_VERSION_3_01,          (VI_INSTR_ERROR_OFFSET + 0x030L), "Incompatible CMU Firmware - CMU FW V3.01 or higher required") \
    EXPAND(RSCMU_ERROR_FW_VERSION_3_05,          (VI_INSTR_ERROR_OFFSET + 0x031L), "Incompatible CMU Firmware - CMU FW V3.05 or higher required") \
    EXPAND(RSCMU_ERROR_FW_VERSION_3_07,          (VI_INSTR_ERROR_OFFSET + 0x032L), "Incompatible CMU Firmware - CMU FW V3.07 or higher required") \
    EXPAND(RSCMU_ERROR_FW_VERSION_3_08,          (VI_INSTR_ERROR_OFFSET + 0x033L), "Incompatible CMU Firmware - CMU FW V3.08 or higher required") \
    EXPAND(RSCMU_ERROR_FW_VERSION_3_10,          (VI_INSTR_ERROR_OFFSET + 0x034L), "Incompatible CMU Firmware - CMU FW V3.10 or higher required") \
    EXPAND(RSCMU_ERROR_FW_VERSION_3_09,          (VI_INSTR_ERROR_OFFSET + 0x035L), "Incompatible CMU Firmware - CMU FW V3.09 or higher required") \
    EXPAND(RSCMU_ERROR_FW_VERSION_2_66,          (VI_INSTR_ERROR_OFFSET + 0x036L), "Incompatible CMU Firmware - CMU FW V2.66 or higher required") \
    EXPAND(RSCMU_ERROR_INSTRUMENT_ERROR,         (VI_INSTR_ERROR_OFFSET + 0x037L), "ESR Byte Error Occured") \
    EXPAND(RSCMU_ERROR_PARAMETER23,              (VI_INSTR_ERROR_OFFSET + 0x038L), "Parameter 23 out of range") \
    EXPAND(RSCMU_ERROR_PARAMETER24,              (VI_INSTR_ERROR_OFFSET + 0x039L), "Parameter 24 out of range") \
    EXPAND(RSCMU_ERROR_PARAMETER25,              (VI_INSTR_ERROR_OFFSET + 0x03AL), "Parameter 25 out of range") \
    EXPAND(RSCMU_ERROR_PARAMETER26,              (VI_INSTR_ERROR_OFFSET + 0x03BL), "Parameter 26 out of range") \
    EXPAND(RSCMU_ERROR_PARAMETER27,              (VI_INSTR_ERROR_OFFSET + 0x03CL), "Parameter 27 out of range") \
    EXPAND(RSCMU_ERROR_PARAMETER28,              (VI_INSTR_ERROR_OFFSET + 0x03DL), "Parameter 28 out of range") \
    EXPAND(RSCMU_ERROR_PARAMETER29,              (VI_INSTR_ERROR_OFFSET + 0x03EL), "Parameter 29 out of range") \
    EXPAND(RSCMU_ERROR_PARAMETER30,              (VI_INSTR_ERROR_OFFSET + 0x03FL), "Parameter 30 out of range") \
    EXPAND(RSCMU_ERROR_PARAMETER31,              (VI_INSTR_ERROR_OFFSET + 0x040L), "Parameter 31 out of range") \
    EXPAND(RSCMU_ERROR_PARAMETER32,              (VI_INSTR_ERROR_OFFSET + 0x041L), "Parameter 32 out of range") \
    EXPAND(RSCMU_ERROR_PARAMETER33,              (VI_INSTR_ERROR_OFFSET + 0x042L), "Parameter 33 out of range") \
    EXPAND(RSCMU_ERROR_PARAMETER34,              (VI_INSTR_ERROR_OFFSET + 0x043L), "Parameter 34 out of range") \
    EXPAND(RSCMU_ERROR_STAT_UNKNOWN,             (VI_INSTR_ERROR_OFFSET + 0x046L), "Status is unknown") \
    EXPAND(RSCMU_ERROR_FW_VERSION_INCOMPATIBLE,  (VI_INSTR_ERROR_OFFSET + 0x047L), "Incompatible CMU Firmware")

    typedef enum RSCMU_ErrorList{
        #define EXPAND(id, value, text) id = value,
          RSCMU_LIST_OF_SPECIFIC_ERROR_MESSAGES
        #undef EXPAND
    } RSCMU_ErrorList;
  #endif // _OUTSIDEVEE_
#endif


/*****************************************************************************/
/*                                 DEFINES                                   */
/*****************************************************************************/
/*---------------------------------------------------------------------------*/
/* Available CMU300 Versions
/*---------------------------------------------------------------------------*/
#ifdef RSCMU_LIST_OF_AVAILABLE_CMU200_FW_VERSIONS
    #undef RSCMU_LIST_OF_AVAILABLE_CMU200_FW_VERSIONS
#endif
//The name RSCMU_LIST_OF_AVAILABLE_CMU200_FW_VERSIONS allows using of
//CMU200 functions
#define RSCMU_LIST_OF_AVAILABLE_CMU200_FW_VERSIONS \
EXPAND2 (RSCMU300_V2_80, 280, "V2.80") \
EXPAND2 (RSCMU300_V2_82, 282, "V2.82") \
EXPAND2 (RSCMU300_V3_06, 306, "V3.06") \
EXPAND2 (RSCMU300_V3_07, 307, "V3.07") \
EXPAND2 (RSCMU300_V3_08, 308, "V3.08") \
EXPAND2 (RSCMU300_V3_22, 322, "V3.22") \
EXPAND2 (RSCMU300_V3_25, 325, "V3.25") \
EXPAND2 (RSCMU300_V3_26, 326, "V3.26") \
EXPAND2 (RSCMU300_V3_63, 363, "V3.63") \
EXPAND2 (RSCMU300_V3_65, 365, "V3.65") \
EXPAND2 (RSCMU300_V3_66, 366, "V3.66") \
EXPAND2 (RSCMU300_V3_82, 382, "V3.82")

typedef enum RSCMU200_FWVersionList{
#define EXPAND2(id, value, text) id = value,
    RSCMU_LIST_OF_AVAILABLE_CMU200_FW_VERSIONS
#undef EXPAND2
} RSCMU300_FWVersionList;

#endif // _OUTSIDEVEE_

/*---------------------------------------------------------------------------*/
/* File I/O buffer size:
/*---------------------------------------------------------------------------*/
#define WR_BUFFER_SIZE             512L
#define RD_BUFFER_SIZE             512L
#define MID_BUFFER_SIZE           2048L
#define RD_BUFFER_SIZE_ARRAY     32767L
#define RD_BUFFER_SIZE_ARRAY_BIG 131068L

#define RSCMU300_200          1
#define RSCMU300_300          2

#define RSCMU300_SECONDARY_ADDRESS_INVALID  -1
#define RSCMU300_SECONDARY_ADDRESS_MIN  1
#define RSCMU300_SECONDARY_ADDRESS_MAX 30

#define RSCMU300_TMO_VALUE           10000

#ifdef _OUTSIDEVEE_

// Logical values:
#define RSCMU300_FALSE (0!=0)
#define RSCMU300_TRUE  (0==0)

// On/Off values:
#define RSCMU300_ON      VI_ON
#define RSCMU300_OFF     VI_OFF
#define RSCMU300_VAL_ON  VI_ON
#define RSCMU300_VAL_OFF VI_OFF

// None value:
#define RSCMU300_NONE    VI_OFF

#endif

#ifndef _OUTSIDEVEE_

// Logical values:
#define RSCMU300_FALSE 0
#define RSCMU300_TRUE  1

// On/Off values:
#define RSCMU300_ON      1
#define RSCMU300_OFF     0
#define RSCMU300_VAL_ON  1
#define RSCMU300_VAL_OFF 0

// None value:
#define RSCMU300_NONE    0

#endif

// Mathematical Values
#define RSCMU300_NAN                 9.91e+37
#define RSCMU300_NAN_VI_INT32        0x80000000

//Function Group Names FW2.0
#define RSCMU300_NOT_MAPPED         -1
#define RSCMU300_BASE                0
#define RSCMU300_RF_NSIG             1
#define RSCMU300_GSM400BS_NSIG       4
#define RSCMU300_GSM400BS_SIG        5
#define RSCMU300_GSM850BS_NSIG       6
#define RSCMU300_GSM850BS_SIG        7
#define RSCMU300_GSM900BS_NSIG       8
#define RSCMU300_GSM900BS_SIG        9
#define RSCMU300_GSM1800BS_NSIG      12
#define RSCMU300_GSM1800BS_SIG       13
#define RSCMU300_GSM1900BS_NSIG      16
#define RSCMU300_GSM1900BS_SIG       17
#define RSCMU300_AUDIO_NSIG          22
#define RSCMU300_AMPSMS_NSIG         23
#define RSCMU300_AMPSMS_SIG          24
#define RSCMU300_CDMA800MS_NSIG      25
#define RSCMU300_CDMA800MS_SIG       26
#define RSCMU300_CDMA1900MS_NSIG     27
#define RSCMU300_CDMA1900MS_SIG      28
#define RSCMU300_BLUETOOTH_NSIG      29
#define RSCMU300_BLUETOOTH_SIG       30

//Units
#define RSCMU300_HZ                  0
#define RSCMU300_KHZ                 1
#define RSCMU300_MHZ                 2
#define RSCMU300_GHZ                 3
#define RSCMU300_US                  0
#define RSCMU300_MS                  1
#define RSCMU300_S                   2

#define RSCMU300_10HZ                0
#define RSCMU300_20HZ                1
#define RSCMU300_30HZ                2
#define RSCMU300_50HZ                3
#define RSCMU300_100HZ               4
#define RSCMU300_200HZ               5
#define RSCMU300_300HZ               6
#define RSCMU300_500HZ               7
#define RSCMU300_1KHZ                8
#define RSCMU300_2KHZ                9
#define RSCMU300_3KHZ               10
#define RSCMU300_5KHZ               11
#define RSCMU300_10KHZ              12
#define RSCMU300_20KHZ              13
#define RSCMU300_30KHZ              14
#define RSCMU300_50KHZ              15
#define RSCMU300_100KHZ             16
#define RSCMU300_200KHZ             17
#define RSCMU300_300KHZ             18
#define RSCMU300_500KHZ             19
#define RSCMU300_1MHZ               20
#define RSCMU300_WIDE               21
#define RSCMU300_FREQ_AUTO          21
#define RSCMU300_TDMA               21
#define RSCMU300_CDMA               22

//SCPI Connection
#define RSCMU300_GPIB                0
#define RSCMU300_COM                 1
#define RSCMU300_COM1                1
#define RSCMU300_COM2                2

//Parity
#define RSCMU300_PARITY_NONE         0
#define RSCMU300_PARITY_ODD          1
#define RSCMU300_PARITY_EVEN         2

//Protocol
#define RSCMU300_PROTOCOL_NONE       0
#define RSCMU300_PROTOCOL_XON        1
#define RSCMU300_PROTOCOL_ACK        2

// Status byte
#define RSCMU300_STB_OFF             0
#define RSCMU300_STB_ON              1

//Query
#define RSCMU300_DO_QUERY            1
#define RSCMU300_SKIP_QUERY          0

//Reset
#define RSCMU300_RESET_ON            1
#define RSCMU300_RESET_OFF           0

//Reference Frequency
#define RSCMU300_INTERNAL            0
#define RSCMU300_EXTERNAL            1
#define RSCMU300_REF_FRQ_MIN         1.2190
#define RSCMU300_REF_FRQ_MAX         39.0

//Attenuation
#define RSCMU300_NORM                0
#define RSCMU300_LNO                 1
#define RSCMU300_LDIS                2
#define RSCMU300_LOW_NOISE           1
#define RSCMU300_LOW_DIST            2

//Trigger Condition
#define RSCMU300_IMM                 0
#define RSCMU300_FRUN                0
#define RSCMU300_RFP                 1
#define RSCMU300_IFP                 2
#define RSCMU300_EXT                 3
#define RSCMU300_SIGN                3

//Trigger Condition
#define RSCMU300_LOW                 0
#define RSCMU300_MED                 1
#define RSCMU300_HIGH                2

//Trigger Source External
#define RSCMU300_PIN2                 0
#define RSCMU300_PIN3                 1
#define RSCMU300_PIN4                 2
#define RSCMU300_PIN5                 3

//Trigger Source External
#define RSCMU300_PIN6                 0
#define RSCMU300_PIN7                 1
#define RSCMU300_PIN8                 2

//I/Q-IF Enums
#define RSCMU300_BYP                  0
#define RSCMU300_BYIQ                 1
#define RSCMU300_XOIO                 2
#define RSCMU300_IOIO                 3
#define RSCMU300_IOXO                 4
#define RSCMU300_FPAT                 5
#define RSCMU300_UDEF                 6

//Measurement Repetition
#define RSCMU300_STOP_ON             1
#define RSCMU300_STOP_ALIM           1
#define RSCMU300_STOP_FLIM           2
#define RSCMU300_STEP                1
#define RSCMU300_STEP_ON             1
#define RSCMU300_ON_LIMIT_FAILURE    1

// Measurement Repetition FW 2.0
#define RSCMU300_CONTINUOUS          0
#define RSCMU300_SINGLE_SHOT         1
#define RSCMU300_MULTIPLE            2

// Event Reporting
#define RSCMU300_SRQ                 1
#define RSCMU300_SOPC                2
#define RSCMU300_SRSQ                3

// TimeOuts
#define RSCMU300_SENS_TRIG_MEAS_TMO_MIN    1.0
#define RSCMU300_SENS_TRIG_MEAS_TMO_MAX    1000.0

// Audio channels
#define RSCMU300_ALL_AF              0
#define RSCMU300_AF1                 1
#define RSCMU300_AF2                 2

// Multitone results
#define RSCMU300_RLEV                0
#define RSCMU300_TON                 1

// Measurement time mode
#define RSCMU300_LOWF                0
#define RSCMU300_EXPF                1

// Multitone level mode
#define RSCMU300_SEP                 0
#define RSCMU300_TLEV                1

// Test Object defines
#define RSCMU300_POW        0
#define RSCMU300_MOD        1
#define RSCMU300_SPEC       2
#define RSCMU300_SPOW       3
#define RSCMU300_WPOW       4
#define RSCMU300_SPECMOD    5
#define RSCMU300_SPECSWIT   6
#define RSCMU300_POWMPR     7
#define RSCMU300_POWSLOT    8
#define RSCMU300_POWXSL     9
#define RSCMU300_POWFRAM   10
#define RSCMU300_POWPCL    11
#define RSCMU300_MODXPER   12
#define RSCMU300_MODOVER   13
#define RSCMU300_MODEVM    14
#define RSCMU300_MODPERR   15
#define RSCMU300_MODMERR   16
#define RSCMU300_POWABUR   17
#define RSCMU300_POWMSL    18
#define RSCMU300_NPOW      19
#define RSCMU300_RFNPOW    20
#define RSCMU300_SPECMSW   21

// Modulation
#define RSCMU300_GMSK       0
#define RSCMU300_EPSK       1

// Command defines
#define RSCMU300_COMMAND_CONF      0
#define RSCMU300_COMMAND_INIT      1
#define RSCMU300_COMMAND_ABOR      2
#define RSCMU300_COMMAND_STOP      3
#define RSCMU300_COMMAND_CONT      4
#define RSCMU300_COMMAND_READ      5
#define RSCMU300_COMMAND_FETC      6
#define RSCMU300_COMMAND_SAMP      7
#define RSCMU300_COMMAND_CALC      8

/*===========================================================================*/
/*                          Measurement Control                              */
/*===========================================================================*/
// Generator Status
#define RSCMU300_GEN_STAT_OFF        0
#define RSCMU300_GEN_STAT_RUN        1
#define RSCMU300_GEN_STAT_ERR        2

// Status (based on Generator Status)
#define RSCMU300_STAT_OFF            0
#define RSCMU300_STAT_RUN            1
#define RSCMU300_STAT_ERR            2

// Measurement Status
#define RSCMU300_MEAS_STAT_OFF       0
#define RSCMU300_MEAS_STAT_RUN       1
#define RSCMU300_MEAS_STAT_STOP      2
#define RSCMU300_MEAS_STAT_ERR       3
#define RSCMU300_MEAS_STAT_STEP      4
#define RSCMU300_MEAS_STAT_RDY       5

// Sensitivity Measurement Status
#define RSCMU300_MEAS_STAT_PASS      0
#define RSCMU300_MEAS_STAT_INV       1
#define RSCMU300_MEAS_STAT_FAIL      2
#define RSCMU300_MEAS_STAT_TMER      3
#define RSCMU300_MEAS_STAT_IMP       4

/*===========================================================================*/
/*                                                                           */
/*===========================================================================*/
//Frequency Bandwidth
#define RSCMU300_BAND_RESTRICT       0
#define RSCMU300_BAND_WIDE           1
#define RSCMU300_BANDWIDTH_30KHZ     1
#define RSCMU300_BANDWIDTH_300KHZ    2

// Generator Modulation
#define RSCMU300_SSB                 1

//Input connectors
#define RSCMU300_INPUT_RF1           0
#define RSCMU300_INPUT_RF2           1
#define RSCMU300_INPUT_RF4           2

//Output Connectors
#define RSCMU300_OUTPUT_RF1          0
#define RSCMU300_OUTPUT_RF2          1
#define RSCMU300_OUTPUT_RF3          2

// Audio input signal
#define RSCMU300_AFAN_AFIN           0
#define RSCMU300_AFAN_AUX1           1

// Audio path coupling
#define RSCMU300_AFAN_AC             0
#define RSCMU300_AFAN_DC             1

// Audio weighting filter
//      RSCMU300_OFF
#define RSCMU300_CME                 1
#define RSCMU300_CCI                 2

// Audio fixed band pass selection
#define RSCMU300_BP01                1
#define RSCMU300_BP02                2
#define RSCMU300_BP03                3
#define RSCMU300_BP04                4
#define RSCMU300_BP05                5
#define RSCMU300_BP06                6
#define RSCMU300_BP07                7
#define RSCMU300_BP08                8
#define RSCMU300_BP09                9
#define RSCMU300_BP10               10
#define RSCMU300_BP11               11
#define RSCMU300_BP12               12
#define RSCMU300_BP13               13
#define RSCMU300_BP14               14
#define RSCMU300_BP15               15
#define RSCMU300_BP16               16
#define RSCMU300_BP17               17
#define RSCMU300_BP18               18

// Speech Encoder Input
#define RSCMU300_SPEN_HAND           0
#define RSCMU300_SPEN_GEN            1
#define RSCMU300_SPEN_AUX1           2

// Speech Decoder Output
#define RSCMU300_SPD_HAND            0
#define RSCMU300_SPD_ANAL            1
#define RSCMU300_SPD_AUX2            2

// Limit Check
#define RSCMU300_OK                  0
#define RSCMU300_INV                 1
#define RSCMU300_NMAU                2
#define RSCMU300_NMAL                3

#define RSCMU300_MATCH_MATC          0
#define RSCMU300_MATCH_INV           1
#define RSCMU300_MATCH_NMAT          2
#define RSCMU300_MATCH_NTSC          3
#define RSCMU300_MATCH_OUT           4
#define RSCMU300_MATCH_NTR           5
#define RSCMU300_MATCH_BNF           6
#define RSCMU300_MATCH_NRAM          7
#define RSCMU300_MATCH_OFF           8
#define RSCMU300_MATCH_OFLOW         9
#define RSCMU300_MATCH_UFLOW        10

#define RSCMU300_MANUAL              0
#define RSCMU300_AUTO                1
#define RSCMU300_PCL                 2
#define RSCMU300_ALWAYS              0

#define RSCMU300_CURRENT             0
#define RSCMU300_AVERAGE             1
#define RSCMU300_MAXMIN              2
#define RSCMU300_MAXIMUM             2
#define RSCMU300_MMAX                2
#define RSCMU300_MINIMUM             3
#define RSCMU300_AVERAGED            1 // Do not remove it is due to keep the compatibility

//Serial interface
#define RSCMU300_APPL_TRAN           0
#define RSCMU300_APPL_REM            1
#define RSCMU300_APPL_PRIN           2

//Input/output attenuation
#define RSCMU300_ATT_MIN           -50
#define RSCMU300_ATT_MAX           +50

//Multiple Measurement
#define RSCMU300_MULT_MEAS_MIN       1
#define RSCMU300_MULT_MEAS_MAX       10000

//Absolute level on used Timeslot
//#define RSCMU300_USEDSLOTMIN         -137.0
//#define RSCMU300_USEDSLOTMAX         +13.0

//Frequency offset
#define RSCMU300_FREQ_OFFSET_MIN     -135000
#define RSCMU300_FREQ_OFFSET_MAX     +135000

//Power Level Range
#define RSCMU300_LEV_RANGE_MIN            10
#define RSCMU300_LEV_RANGE_MAX           100

//Test Points Number
#define RSCMU300_TEST_PTS_MIN              1
#define RSCMU300_TEST_PTS_MAX            560

#define RSCMU300_REG_MAX               32767
#define RSCMU300_SUB_REG_MAX              15
#define RSCMU300_ADDR_PRIM_MAX            30
#define RSCMU300_ADDR_SEC_MAX             30

#define RSCMU300_DATABITS_MIN              7
#define RSCMU300_DATABITS_MAX              8
#define RSCMU300_STOPBITS_MIN              1
#define RSCMU300_STOPBITS_MAX              2

#define RSCMU300_SUM1                      1
#define RSCMU300_SUM2                      2

//Keyboard Assignment
#define RSCMU300_KBUS                0
#define RSCMU300_KBGR                1

//positive / negative
#define RSCMU300_POS                 1
#define RSCMU300_NEG                 0

// Frequency hopping
#define RSCMU300_REL                 0
#define RSCMU300_ABS                 1

// Mode Values
#define RSCMU300_VALUE_ALL           0
#define RSCMU300_VALUE_ARIT          1
#define RSCMU300_VALUE_MIN           2
#define RSCMU300_VALUE_MAX           3
#define RSCMU300_VALUE_IVAL          4


/*===========================================================================*/
/* RSCMU300_Base_Globals is initialized for each Session in an 'init' function
/*  and defines the Driver's global datas
/*---------------------------------------------------------------------------*/
/* Instrument driver revision:
/*---------------------------------------------------------------------------*/

#define RSCMU300_BASE_VERSION       "3.65.1"   // Instrument Driver Version String
#define RSCMU300_BASE_BETA          ""          // "BETA" or empty
#define RSCMU300_BASE_CREATIONDATE  "07/2007"   // Instrument Driver Creation Month/Year
#define RSCMU300_BASE_CVIVERSION    "8"       // Used Labwindows/CVI Version

#define RSCMU300_BASE_REVISION "Rev " RSCMU300_BASE_VERSION RSCMU300_BASE_BETA", "RSCMU300_BASE_CREATIONDATE", CVI "RSCMU300_BASE_CVIVERSION // Instrument Driver Revision

/*= Macros ==================================================================*/
#ifndef __RSCMU_HEADER
  #ifdef _OUTSIDEVEE_

#define CHECKERR(fCal) if (RSCMU300_Status >= 0) RSCMU300_Status = (fCal); \
                        else

#define CHECKRET(fCal) if (RSCMU300_Status = (fCal), RSCMU300_Status < 0)\
                            return RSCMU300_Status; \
                        else
#define CHECKRETMSG(fCal) if (RSCMU300_Status = (fCal), RSCMU300_Status < 0)\
                            return RSCMU300_Base_errorMessage (0,RSCMU300_Status,errorMessage);\
                         else

#define CHKNULLP(value,error) if (value == VI_NULL) return RSCMU300_Base_errorMessage(0,error, errorMessage)
#define RETMSG(fcal) return RSCMU300_Base_errorMessage(0,fcal, errorMessage)

#define GET_VI_REAL64(value,string) str = strtok((char*) string, ",");\
                              value = RSCMU300_atof(str)

#define GET_VI_INT32(value,string, delimiter) str = strtok((char*) string, delimiter);\
                              value = atol(str)

#define GET_VI_STRING(value,string) value = strtok((char*) string, ",");\


#define GET_WRT_BUF(vi) struct RSCMU300_SESSION_Globals* pvar_base_globals;\
                        ViChar *wrtBuf;\
                        CHECKRET(viGetAttribute(vi, VI_ATTR_USER_DATA,(ViAddr)&pvar_base_globals));\
                        wrtBuf = pvar_base_globals->wrtBuf

#define GET_RD_BUF(vi)  struct RSCMU300_SESSION_Globals* pvar_base_globals;\
                        ViChar* rdBuf;\
                        CHECKRET(viGetAttribute(vi, VI_ATTR_USER_DATA,(ViAddr)&pvar_base_globals));\
                        rdBuf = pvar_base_globals->rdBuf
#define GET_BUFS(vi)    struct RSCMU300_SESSION_Globals* pvar_base_globals;\
                        ViChar *rdBuf;\
                        ViChar *wrtBuf;\
                        CHECKRET(viGetAttribute(vi, VI_ATTR_USER_DATA,(ViAddr)&pvar_base_globals));\
                        wrtBuf = pvar_base_globals->wrtBuf;\
                        rdBuf = pvar_base_globals->rdBuf


#define REMOVE_STRING_SIGNS(string)\
    string++;\
    string[strlen(string)-1] = '\0'

  #endif // _OUTSIDEVEE_
#endif

/*===========================================================================*/
/* RSCMU300_Base_Globals is initialized for each Session in an 'init' function
/*  and defines the Driver's global datas
/*===========================================================================*/


// defined in CMU200
#ifdef _OUTSIDEVEE_

// common structure for all sessions
struct RSCMU300_SESSION_Globals
{
  ViChar        FGrp_Name [40];
  ViChar        DrvVersion [80];
  ViChar        CmuVersion [40];
  ViInt32       RSCMU300_Type;
  ViInt32       RSCMU300_FW_Version;
  ViInt32       RSCMU300_primary_address;
  ViInt32       RSCMU300_secondary_address;
  ViSession     RSCMU300_SessionNb;
  ViChar        RSCMU300_SCPIConnection[10];
  ViInt32       RSCMU300_FileHandle;
  ViAddr        RSCMU300_AddrTargetFile;
  ViInt16       RSCMU300_StateTraceFile;
  ViBoolean     RSCMU300_TRACE;
  ViBoolean     RSCMU300_Stb;
  ViSession     RSCMU300_RmSessionDefault;
  ViChar        rdBuf[RD_BUFFER_SIZE];
  ViChar        wrtBuf[WR_BUFFER_SIZE];
};

// Structure "RSCMU300_Sec_Addr" is initialized for each sesssion in the 'RSCMU300_Base_SystRemAddrSec' function
typedef struct RSCMU300_Sec_Addr
{
  ViChar        FctGrp[30];
  ViSession     SessionNb;
} RSCMU300_tSecAddr;

// Structure "RSCMU300_Base_Globals" is initialized for each Session in an 'init' function
struct  RSCMU300_Base_Globals
{
  struct RSCMU300_SESSION_Globals RSCMU300_tGlobal;
  struct RSCMU300_Sec_Addr        RSCMU300_tSecAddr[30];
};

// Structure is used to define Handover name for all signalling sessions.
typedef struct RSCMU300_HandOver
{
   ViChar HandOverSessionName[30];
} RSCMU300_tHandover;

// Structure to save the Multitone Test Tones definition (CONFigure:MULTitone:AFnChannel:TDEFinition)
struct RSCMU300_TestTones
{
  ViInt32 frequency_Hz[20];
  ViInt32 level_mV[20];
  ViInt32 enable[20];
};

// Structure to save the Multitone limit lines
struct RSCMU300_MultitoneLimits
{
  ViReal64 Upper_limits_dB[20];
  ViInt32  Upper_enable[20];
  ViReal64 Lower_limits_dB[20];
  ViInt32  Lower_enable[20];
};

// Structure "RSCMU300_RF_NSig_Globals" is initialized for each Session in an 'init' function
struct  RSCMU300_RF_NSig_Globals
{
  struct RSCMU300_SESSION_Globals RSCMU300_tGlobal;
};

// Structure "RSCMU300_Audio_NSig_Globals" is initialized for each Session in an 'init' function
struct  RSCMU300_Audio_NSig_Globals
{
  struct RSCMU300_SESSION_Globals RSCMU300_tGlobal;
  struct RSCMU300_TestTones       RSCMU300_tTestTones;
  struct RSCMU300_MultitoneLimits RSCMU300_tMultitoneLimits;
};

#endif // _OUTSIDEVEE_

/*****************************************************************************/
/* INIT Functions ===========================================================*/
/*****************************************************************************/

ViStatus _VI_FUNC RSCMU300_Init_Base               (ViPSession, ViInt32, ViInt32, ViInt32, ViBoolean, ViBoolean, ViChar[]);
ViStatus _VI_FUNC RSCMU300_Init_RF_NSig            (ViSession, ViPSession, ViChar[]);

/*****************************************************************************/
/* CLOSE Functions ===========================================================*/
/*****************************************************************************/

ViStatus _VI_FUNC RSCMU300_Close_Base              (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_Close_RF_NSig           (ViSession, ViChar[]);


//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
//      Class: Basic unit
//~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

ViStatus _VI_FUNC RSCMU300_Base_StatOper           (ViSession, ViInt32*, ViChar[]);
ViStatus _VI_FUNC RSCMU300_Base_StatOperCond       (ViSession, ViInt32*, ViChar[]);
ViStatus _VI_FUNC RSCMU300_Base_StatOperPtr        (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_Base_StatOperNtr        (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_Base_StatOperEnab       (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU300_Base_StatOperCmuSum       (ViSession, ViInt32, ViInt32*, ViChar[]);
ViStatus _VI_FUNC RSCMU300_Base_StatOperCmuSumCond   (ViSession, ViInt32, ViInt32*, ViChar[]);
ViStatus _VI_FUNC RSCMU300_Base_StatOperCmuSumPtr    (ViSession, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_Base_StatOperCmuSumNtr    (ViSession, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_Base_StatOperCmuSumEnab   (ViSession, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU300_Base_StatOperCmuSumCmu      (ViSession, ViInt32, ViInt32, ViInt32*, ViChar[]);
ViStatus _VI_FUNC RSCMU300_Base_StatOperCmuSumCmuCond  (ViSession, ViInt32, ViInt32, ViInt32*, ViChar[]);
ViStatus _VI_FUNC RSCMU300_Base_StatOperCmuSumCmuPtr   (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_Base_StatOperCmuSumCmuNtr   (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_Base_StatOperCmuSumCmuEnab  (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU300_Base_StatOperCmuAll     (ViSession, ViInt32[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_Base_StatOperCmuCle     (ViSession, ViChar[]);

ViStatus _VI_FUNC RSCMU300_Base_StatQues           (ViSession, ViInt32*, ViChar[]);
ViStatus _VI_FUNC RSCMU300_Base_StatQuesCond       (ViSession, ViInt32*, ViChar[]);
ViStatus _VI_FUNC RSCMU300_Base_StatQuesPtr        (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_Base_StatQuesNtr        (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_Base_StatQuesEnab       (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU300_Base_StatPres           (ViSession, ViChar[]);

ViStatus _VI_FUNC RSCMU300_Base_SystRemAddrPrim    (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_Base_SystRemAddrSec     (ViSession, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU300_Base_StatOperEvenSadd   (ViSession, ViInt32*, ViChar[], ViChar[]);

ViStatus _VI_FUNC RSCMU300_Base_StatOperSymb       (ViSession, ViChar[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_Base_StatOperSymbEnab   (ViSession, ViChar[], ViChar[]);

ViStatus _VI_FUNC RSCMU300_Base_ConfSyncFreqRef    (ViSession, ViReal64, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU300_Base_SystCommGpibAddr       (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_Base_SystCommSerAppl        (ViSession, ViInt32, ViInt32*, ViChar[]);
ViStatus _VI_FUNC RSCMU300_Base_SystCommSerBaud        (ViSession, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_Base_SystCommSerBit         (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_Base_SystCommSerPar         (ViSession, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_Base_SystCommSerTranPace    (ViSession, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU300_Base_SystOptInf         (ViSession, ViChar[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_Base_SystOpt            (ViSession, ViChar[], ViChar[]);

ViStatus _VI_FUNC RSCMU300_Base_SystPres           (ViSession, ViChar[]);

ViStatus _VI_FUNC RSCMU300_Base_SystGtrmComp       (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU300_Base_SystTim            (ViSession, ViInt32, ViChar[], ViChar[], ViChar[]);

ViStatus _VI_FUNC RSCMU300_Base_SystMiscKbe        (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_Base_SystMiscKeyb       (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU300_Base_SystMqu          (ViSession, ViChar[], ViChar[], ViChar[]);

ViStatus _VI_FUNC RSCMU300_Base_SystMquItem        (ViSession, ViChar[], ViChar[], ViChar[]);

ViStatus _VI_FUNC RSCMU300_Base_SensTempSyst      (ViSession, ViReal64*, ViChar[]);

// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
//      Class: RF Non Signalling
// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

ViStatus _VI_FUNC RSCMU300_RF_NSig_SensLevMax          (ViSession, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU300_RF_NSig_SensLevRef          (ViSession, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU300_RF_NSig_SensLevAtt          (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_RF_NSig_SensLevMode         (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU300_RF_NSig_TrigSour            (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_RF_NSig_TrigThr             (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_RF_NSig_TrigSlop            (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU300_RF_NSig_SensNpowBwid        (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_RF_NSig_ConfNpowCont        (ViSession, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_RF_NSig_ConfNpowContRep     (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_RF_NSig_ConfNpowContRepStat (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_RF_NSig_ConfNpowContStat    (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU300_RF_NSig_InitNpow            (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_RF_NSig_AborNpow            (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_RF_NSig_StopNpow            (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_RF_NSig_ContNpow            (ViSession, ViChar[]);

ViStatus _VI_FUNC RSCMU300_RF_NSig_FetcNpowStat        (ViSession, ViInt32*, ViInt32*, ViInt32*, ViChar[]);

ViStatus _VI_FUNC RSCMU300_RF_NSig_ConfNpowErep        (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU300_RF_NSig_ReadNpow            (ViSession, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViChar[]);
ViStatus _VI_FUNC RSCMU300_RF_NSig_FetcNpow            (ViSession, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViChar[]);
ViStatus _VI_FUNC RSCMU300_RF_NSig_SampNpow            (ViSession, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViChar[]);

ViStatus _VI_FUNC RSCMU300_RF_NSig_SourRfgLev          (ViSession, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU300_RF_NSig_SourRfgFreq         (ViSession, ViReal64, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_RF_NSig_SourRfgMod          (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_RF_NSig_SourRfgModSsbFreq   (ViSession, ViReal64, ViChar[]);

ViStatus _VI_FUNC RSCMU300_RF_NSig_SourRfgFhopStat      (ViSession, ViBoolean, ViChar[]);
ViStatus _VI_FUNC RSCMU300_RF_NSig_SourRfgFhopFreq      (ViSession, ViReal64, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_RF_NSig_SourRfgFhopFreqMode  (ViSession, ViBoolean, ViChar[]);

ViStatus _VI_FUNC RSCMU300_RF_NSig_SourRfgPulsStat     (ViSession, ViBoolean, ViChar[]);
ViStatus _VI_FUNC RSCMU300_RF_NSig_SourRfgBand         (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU300_RF_NSig_InitRfg             (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_RF_NSig_AborRfg             (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_RF_NSig_FetcRfgStat         (ViSession, ViPInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU300_RF_NSig_RfanFreq            (ViSession, ViReal64, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_RF_NSig_RfanBandRes         (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_RF_NSig_ConfRfanPowRtim     (ViSession, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU300_RF_NSig_ConfRfanContRep     (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_RF_NSig_ConfRfanContRepStat (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU300_RF_NSig_InitRfan        (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_RF_NSig_AborRfan        (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_RF_NSig_StopRfan        (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_RF_NSig_ContRfan        (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_RF_NSig_FetcRfanStat    (ViSession, ViInt32*, ViInt32*, ViChar[]);
ViStatus _VI_FUNC RSCMU300_RF_NSig_ConfRfanErep    (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU300_RF_NSig_ReadRfanPow     (ViSession, ViReal64*, ViChar[]);
ViStatus _VI_FUNC RSCMU300_RF_NSig_FetcRfanPow     (ViSession, ViReal64*, ViChar[]);
ViStatus _VI_FUNC RSCMU300_RF_NSig_SampRfanPow     (ViSession, ViReal64*, ViChar[]);

ViStatus _VI_FUNC RSCMU300_RF_NSig_Inp               (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_RF_NSig_Outp              (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_RF_NSig_SensCorrLossInp   (ViSession, ViInt32, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU300_RF_NSig_SourCorrLossOutp  (ViSession, ViInt32, ViReal64, ViChar[]);

ViStatus _VI_FUNC RSCMU300_RF_NSig_SourDmCloc      (ViSession, ViInt32, ViReal64, ViChar[]);

ViStatus _VI_FUNC RSCMU300_RF_NSig_SensPowLevRang    (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU300_RF_NSig_SensPowFreqCent   (ViSession, ViReal64, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_RF_NSig_SensPowFreqBand   (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_RF_NSig_SensPowTimeDel    (ViSession, ViReal64, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_RF_NSig_SensPowTimeSpan   (ViSession, ViReal64, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_RF_NSig_SensPowContTim    (ViSession, ViReal64, ViChar[]);
ViStatus _VI_FUNC RSCMU300_RF_NSig_ConfPowContRep    (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_RF_NSig_DispPowContGrid   (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_RF_NSig_ConfPowContRepStat  (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU300_RF_NSig_ConfArrPowRang    (ViSession, ViReal64, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU300_RF_NSig_InitPow         (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_RF_NSig_AborPow         (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_RF_NSig_StopPow         (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_RF_NSig_ContPow         (ViSession, ViChar[]);

ViStatus _VI_FUNC RSCMU300_RF_NSig_FetcPowStat     (ViSession, ViInt32*, ViInt32*, ViChar[]);
ViStatus _VI_FUNC RSCMU300_RF_NSig_ConfPowErep     (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU300_RF_NSig_ReadArrPow         (ViSession, ViReal64*, ViInt32*, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_RF_NSig_FetcArrPow        (ViSession, ViReal64*, ViInt32*, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_RF_NSig_SampArrPow        (ViSession, ViReal64*, ViInt32*, ViReal64[], ViChar[]);

ViStatus _VI_FUNC RSCMU300_RF_NSig_SensSpecFreqStartStop (ViSession, ViReal64, ViInt32, ViReal64, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_RF_NSig_SensSpecFreqCentSpan (ViSession, ViReal64, ViInt32, ViReal64, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_RF_NSig_SensSpecFreqBand    (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_RF_NSig_SensSpecLevRang   (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU300_RF_NSig_ConfSpecContRep     (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_RF_NSig_DispSpecContGrid    (ViSession, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_RF_NSig_ConfSpecContRepStat (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU300_RF_NSig_ConfArrSpecRang   (ViSession, ViReal64, ViInt32, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU300_RF_NSig_InitSpec          (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_RF_NSig_AborSpec          (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_RF_NSig_StopSpec          (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_RF_NSig_ContSpec          (ViSession, ViChar[]);

ViStatus _VI_FUNC RSCMU300_RF_NSig_FetcSpecStat      (ViSession, ViInt32*, ViInt32*, ViChar[]);

ViStatus _VI_FUNC RSCMU300_RF_NSig_ConfSpecErep      (ViSession, ViInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU300_RF_NSig_ReadArrSpec       (ViSession, ViReal64*, ViInt32*, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_RF_NSig_FetcArrSpec       (ViSession, ViReal64*, ViInt32*, ViReal64[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_RF_NSig_SampArrSpec       (ViSession, ViReal64*, ViInt32*, ViReal64[], ViChar[]);

// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
//      APPLICATION FUNCTIONS
// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
ViStatus _VI_FUNC RSCMU300_SendControlCommand (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_FetcStatus (ViSession, ViInt32, ViInt32, ViInt32*, ViInt32*, ViInt32*, ViChar[]);
ViStatus _VI_FUNC RSCMU300_ConfReporting (ViSession, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_ConfControl (ViSession, ViInt32,ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_ConfContDef (ViSession ,ViInt32 ,ViInt32 ,ViInt32 ,ViChar[]);
ViStatus _VI_FUNC RSCMU300_ConfControlRep (ViSession, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_ConfContRepStat (ViSession, ViInt32, ViInt32, ViInt32, ViInt32, ViInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_RF_NSig_Npow (ViSession, ViInt32, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViReal64*, ViChar[]);

// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
//        UTILITY ROUTINE DECLARATIONS (Exportable Functions)
// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

#ifdef _OUTSIDEVEE_ // makes sure linker in CVI does not generate a warning
                    // that these functions do not have a function panel

ViBoolean _VI_FUNC RSCMU300_invalidViBooleanRange (ViBoolean);
ViBoolean _VI_FUNC RSCMU300_invalidViUInt16Range (ViUInt16, ViUInt16, ViUInt16);
ViBoolean _VI_FUNC RSCMU300_invalidViInt16Range (ViInt16, ViInt16, ViInt16);
ViBoolean _VI_FUNC RSCMU300_invalidViInt32Range (ViInt32, ViInt32, ViInt32);
ViBoolean _VI_FUNC RSCMU300_invalidViReal64Range (ViReal64, ViReal64, ViReal64);
ViBoolean _VI_FUNC RSCMU300_invalidViUInt32Range (ViUInt32, ViUInt32, ViUInt32);
ViBoolean _VI_FUNC RSCMU300_invalidViReal32Range (ViReal32, ViReal32, ViReal32);

/* New middle level functions */
ViStatus _VI_FUNC RSCMU300_checkVersion (ViSession vi,
                             ViInt32    version,
                             ViStatus   errorCode);
ViReal64 _VI_FUNC RSCMU300_atof(ViString _VI_FAR str);
void _VI_FUNC RSCMU300_atofArray(ViString _VI_FAR string, ViReal64 arr[]);
ViStatus _VI_FUNC RSCMU300_setViInt32 (ViSession vi,
                           ViString cmd,
                           ViInt32 value,
                           ViInt32 min,
                           ViInt32 max,
                           ViStatus parameterErrorCode);
ViStatus _VI_FUNC RSCMU300_getViInt32 (ViSession vi,
                           ViString cmd,
                           ViInt32 *value,
                           ViStatus parameterErrorCode);
ViStatus _VI_FUNC RSCMU300_setViReal64 (ViSession vi,
                            ViString cmd,
                            ViReal64 value,
                            ViReal64 min,
                            ViReal64 max,
                            ViStatus parameterErrorCode);
ViStatus _VI_FUNC RSCMU300_setViReal64Unit (ViSession vi,
                                       ViString cmd,
                                       ViReal64 value,
                                       ViReal64 min[],
                                       ViReal64 max[],
                                       ViInt32  unit,
                                       ViString unitArr[],
                                       ViStatus parameterErrorCode);
ViStatus _VI_FUNC RSCMU300_getViReal64 (ViSession vi,
                            ViString cmd,
                            ViReal64 *value,
                            ViStatus parameterErrorCode);
ViStatus _VI_FUNC RSCMU300_sendCmd (ViSession vi,
                        ViString cmd);
ViStatus _VI_FUNC RSCMU300_setViString (ViSession vi,
                            ViString cmd,
                            ViString value,
                            ViStatus parameterErrorValue);
ViStatus _VI_FUNC RSCMU300_getViString (ViSession vi,
                            ViString cmd,
                            ViString value,
                            ViInt32 buffer_size,
                            ViStatus parameterErrorCode);
ViStatus _VI_FUNC RSCMU300_setEnum (ViSession vi,
                        ViString cmd,
                        ViInt32 value,
                        ViString _VI_FAR list[],
                        ViStatus parameterErrorCode);
ViStatus _VI_FUNC RSCMU300_getEnum (ViSession vi,
                        ViString cmd,
                        ViInt32 *value,
                        ViString _VI_FAR list[],
                        ViStatus parameterErrorCode);
ViStatus _VI_FUNC RSCMU300_checkIndexInList (ViSession vi,
                                 ViInt32 index,
                                 ViString list[],
                                 ViStatus statusIfError);
ViStatus _VI_FUNC RSCMU300_checkIndexInRealList (ViSession vi,
                                 ViInt32 index,
                                 ViReal64 list[],
                                 ViStatus statusIfError);
ViStatus _VI_FUNC RSCMU300_getIndexFromString (ViSession vi,
                                   ViString string,
                                   ViString *list,
                                   ViInt32 *index);
ViStatus _VI_FUNC RSCMU300_WinBatchWrite (ViSession instrSession,
                         ViString _VI_FAR command);
ViStatus _VI_FUNC RSCMU300_WinBatchRead (ViSession instrSession,
                         ViString _VI_FAR buffer);
ViStatus _VI_FUNC RSCMU300_sysStatus (ViSession vi, ViUInt16* stb);
ViStatus _VI_FUNC RSCMU300_setCheckStatus(ViSession vi, ViBoolean checkStatus);
ViStatus _VI_FUNC RSCMU300_ReadDataUnknownLength(ViSession instrSession,
                                            ViChar **outBuffer,
                                            ViUInt32 *count);
ViStatus _VI_FUNC RSCMU300_viWrite (ViSession, ViChar[], ViUInt32);
ViStatus _VI_FUNC RSCMU300_viRead (ViSession, ViChar[], ViUInt32);
/* End of new middle level functions */

ViStatus _VI_FUNC RSCMU300_Write (ViSession, ViChar[], ViBoolean, ViUInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_Read (ViSession, ViChar[], ViUInt32, ViChar[]);

ViStatus _VI_FUNC RSCMU300_SeparateDataValues (ViChar[], ViChar[], ViChar[100][100]);
ViStatus _VI_FUNC RSCMU300_ReturnCMUResponse (ViInt32, ViChar[669][20], ViReal64[]);
ViStatus _VI_FUNC RSCMU300_GetViInt32Value (ViChar[100][100], ViInt32, ViInt32*);
ViStatus _VI_FUNC RSCMU300_GetViReal64Value (ViChar[100][100], ViInt32, ViReal64*);
ViStatus _VI_FUNC RSCMU300_GetLimitCheckValue (ViChar[100][100], ViInt32, ViInt32*);
ViStatus _VI_FUNC RSCMU300_GetMeasStatVal (ViInt32*, ViChar[100][100], ViInt32);
ViStatus _VI_FUNC RSCMU300_GetSensMeasStatVal (ViInt32*, ViChar[100][100], ViInt32);
ViStatus _VI_FUNC RSCMU300_GetCountingNo (ViInt32*, ViChar[100][100], ViInt32);
ViStatus _VI_FUNC RSCMU300_GetStatisticNo (ViInt32*, ViChar[100][100], ViInt32);
ViStatus _VI_FUNC RSCMU300_GetMatchingValue (ViInt32*, ViChar[100][100], ViInt32);
ViInt32  _VI_FUNC RSCMU300_GetGenStatVal (ViChar[]);
ViInt32  _VI_FUNC RSCMU300_GetStatVal (ViChar[]);
ViInt32  _VI_FUNC RSCMU300_scanStringBurst (ViChar[], ViChar[669][20]);
ViStatus _VI_FUNC RSCMU300_copyString (ViChar[], ViChar[], ViUInt32, ViUInt32);
ViStatus _VI_FUNC RSCMU300_getTabSecAdd (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_WriteFile (ViSession, ViAddr, ViChar[],  ViChar[]);
ViStatus _VI_FUNC RSCMU300_initCleanUp (ViSession, ViSession, ViStatus);

// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
//      Function for LabVIEW 5.x and higher
// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
ViStatus _VI_FUNC RSCMU300_RF_NSig_GetResourceName (ViSession, ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_Audio_NSig_GetResourceName (ViSession, ViSession, ViChar[]);

#endif // _OUTSIDEVEE_

// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
//      VXI PLUG & PLAY COMPATIBILITY FUNCTIONS
// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

#ifndef _REMOVE_VXIPNP_FUNCTIONS_

ViStatus _VI_FUNC RSCMU300_GetInstrumentHandle (ViSession, ViSession*);
ViStatus _VI_FUNC RSCMU300_initRFNSig (ViSession, ViSession);
ViStatus _VI_FUNC RSCMU300_initAudioNSig (ViSession, ViSession);

ViStatus _VI_FUNC RSCMU300_init (ViRsrc, ViBoolean, ViBoolean, ViPSession);

ViStatus _VI_FUNC RSCMU300_reset (ViSession);
ViStatus _VI_FUNC RSCMU300_self_test (ViSession, ViPInt16, ViChar[]);
ViStatus _VI_FUNC RSCMU300_error_query (ViSession, ViPInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_error_message (ViSession, ViStatus, ViChar[]);
ViStatus _VI_FUNC RSCMU300_revision_query (ViSession, ViChar[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_close (ViSession);

#endif // _REMOVE_VXIPNP_FUNCTIONS_

// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
//      UTILITY FUNCTIONS
// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

ViStatus _VI_FUNC RSCMU300_Reset (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_Delay (ViReal64);

ViStatus _VI_FUNC RSCMU300_SCPIVersionQuery (ViSession, ViChar[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_Base_RevisionQuery (ViSession, ViChar[], ViChar[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_CurrentVersion (ViSession, ViInt32*, ViChar[]);
ViStatus _VI_FUNC RSCMU300_SetCmuVersion (ViSession, ViInt32, ViChar[], ViChar[]);

ViStatus _VI_FUNC RSCMU300_ErrorQuery (ViSession, ViInt32*, ViChar[]);

ViStatus _VI_FUNC RSCMU300_Trace_ON (ViSession, ViString, ViChar[]);
ViStatus _VI_FUNC RSCMU300_Trace_OFF (ViSession, ViChar[]);
ViStatus _VI_FUNC RSCMU300_WriteExtTrace   (ViSession, ViChar[], ViChar[]);

ViStatus _VI_FUNC RSCMU300_Query (ViSession, ViChar[], ViChar[], ViBoolean, ViChar[]);

ViStatus _VI_FUNC RSCMU300_Query_Array (ViSession, ViChar[], ViChar[], ViBoolean, ViChar[]);

ViStatus _VI_FUNC RSCMU300_WriteToRSCMU (ViSession, ViChar[], ViChar[]);
ViStatus _VI_FUNC RSCMU300_ReadFromRSCMU (ViSession, ViChar[], ViChar[]);

ViStatus _VI_FUNC RSCMU300_SetTimeoutAttribute (ViSession, ViUInt32, ViChar[]);
ViStatus _VI_FUNC RSCMU300_Base_errorMessage (ViSession, ViStatus, ViChar[]);

ViStatus _VI_FUNC RSCMU300_SystGtrmComp (ViSession, ViBoolean, ViChar[]);

// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
//      MACROS
// ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
#ifndef __RSCMU_HEADER

    #ifdef _OUTSIDEVEE_

    #define CHECK_VI_BOOLEAN_RANGE(instrSession,val,err,errorMessage) \
    if (RSCMU300_invalidViBooleanRange(val))                             \
    return RSCMU300_Base_errorMessage (instrSession,err,errorMessage);

    #define CHECK_VI_INT32_RANGE(instrSession,val,min,max,err,errorMessage) \
    if (RSCMU300_invalidViInt32Range(val, min, max))                          \
    return RSCMU300_Base_errorMessage (instrSession,err,errorMessage);

    #define CHECK_VI_REAL64_RANGE(instrSession,val,min, max, err,errorMessage) \
    if (RSCMU300_invalidViReal64Range(val, min, max))                             \
    return RSCMU300_Base_errorMessage (instrSession,err,errorMessage);

    #define CHECK_VI_UINT32_RANGE(instrSession,val,min,max,err,errorMessage) \
    if (RSCMU300_invalidViUInt32Range(val, min, max))                            \
    return RSCMU300_Base_errorMessage (instrSession,err,errorMessage);

    #endif // _OUTSIDEVEE_
#endif

#if defined(__cplusplus) || defined(__cplusplus__)
}
#endif

#endif // __RSCMU300_HEADER

/*****************************************************************************/
/*=== END INCLUDE FILE ======================================================*/
/*****************************************************************************/


